@@ -1,7 +1,7 @@
 #   This module defines and implements a class that represents
 #   a connection to a lond daemon.
 #
-# $Id: LondConnection.pm,v 1.49 2010/11/11 15:01:13 raeburn Exp $
+# $Id: LondConnection.pm,v 1.52 2011/01/24 11:02:32 foxr Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -189,7 +189,8 @@ sub new {
 		     LocalKeyFile       => "",
                      CipherKey          => "",
                      LondVersion        => "Unknown",
-                     Cipher             => undef};
+                     Cipher             => undef,
+		     ClientData         => undef};
     bless($self, $class);
     unless ($self->{Socket} = IO::Socket::INET->new(PeerHost => $self->{Host},
 					       PeerPort => $self->{Port},
@@ -200,6 +201,7 @@ sub new {
 	return undef;		# Inidicates the socket could not be made.
     }
     my $socket = $self->{Socket}; # For local use only.
+    $socket->sockopt(SO_KEEPALIVE, 1); # Turn on keepalive probes when idle.
     #  If we are local, we'll first try local auth mode, otherwise, we'll try
     #  the ssl auth mode:
 
@@ -342,6 +344,8 @@ sub Readable {
     }
     #  Append the data to the buffer.  And figure out if the read is done:
 
+    $self->{TimeoutRemaining}   = $self->{TimeoutValue}; # getting data resets the timeout period.
+
     &Debug(9,"Received from host: ".$data);
     $self->{TransactionReply} .= $data;
     if($self->{TransactionReply} =~ m/\n$/) {
@@ -501,7 +505,6 @@ sub Readable {
 		$self->{InformWritable}     = 1;
 		$self->{InformReadable}     = 0;
 		$self->{Timeoutable}        = 1;
-		$self->{TimeoutRemaining}   = $self->{TimeoutValue};
 		$self->Transition("SendingRequest");
 		return 0;
 	    } else {
@@ -563,42 +566,42 @@ sub Writable {
 	($errno == POSIX::EAGAIN)         ||
 	($errno == POSIX::EINTR)          ||
 	($errno ==  0)) {
-    $self->{TimeoutRemaining} = $self->{TimeoutValue};
+	$self->{TimeoutRemaining} = $self->{TimeoutValue};
 	substr($self->{TransactionRequest}, 0, $nwritten) = ""; # rmv written part
-      if(length $self->{TransactionRequest} == 0) {
-         $self->{InformWritable} = 0;
-         $self->{InformReadable} = 1;
-         $self->{TransactionReply} = '';
-         #
-         # Figure out the next state:
-         #
-         if($self->{State} eq "Connected") {
-            $self->Transition("Initialized");
-         } elsif($self->{State} eq "ChallengeReceived") {
-            $self->Transition("ChallengeReplied");
-         } elsif($self->{State} eq "RequestingVersion") {
-            $self->Transition("ReadingVersionString");
-         } elsif ($self->{State} eq "SetHost") {
-            $self->Transition("HostSet");
-         } elsif($self->{State} eq "RequestingKey") {
-            $self->Transition("ReceivingKey");
+	if(length $self->{TransactionRequest} == 0) {
+	    $self->{InformWritable} = 0;
+	    $self->{InformReadable} = 1;
+	    $self->{TransactionReply} = '';
+	    #
+	    # Figure out the next state:
+	    #
+	    if($self->{State} eq "Connected") {
+		$self->Transition("Initialized");
+	    } elsif($self->{State} eq "ChallengeReceived") {
+		$self->Transition("ChallengeReplied");
+	    } elsif($self->{State} eq "RequestingVersion") {
+		$self->Transition("ReadingVersionString");
+	    } elsif ($self->{State} eq "SetHost") {
+		$self->Transition("HostSet");
+	    } elsif($self->{State} eq "RequestingKey") {
+		$self->Transition("ReceivingKey");
 #            $self->{InformWritable} = 0;
 #            $self->{InformReadable} = 1;
 #            $self->{TransactionReply} = '';
-         } elsif ($self->{State} eq "SendingRequest") {
-            $self->Transition("ReceivingReply");
-            $self->{TimeoutRemaining} = $self->{TimeoutValue};
-         } elsif ($self->{State} eq "Disconnected") {
-            return -1;
-         }
-         return 0;
-      }
-   } else {			# The write failed (e.g. partner disconnected).
-      $self->Transition("Disconnected");
-      $socket->close();
-      return -1;
-   }
-	
+	    } elsif ($self->{State} eq "SendingRequest") {
+		$self->Transition("ReceivingReply");
+		$self->{TimeoutRemaining} = $self->{TimeoutValue};
+	    } elsif ($self->{State} eq "Disconnected") {
+		return -1;
+	    }
+	    return 0;
+	}
+    } else {			# The write failed (e.g. partner disconnected).
+	$self->Transition("Disconnected");
+	$socket->close();
+	return -1;
+    }
+    
 }
 =pod
 
@@ -745,6 +748,7 @@ sub Shutdown {
 	    $socket->shutdown(2);
 	}
     }
+    $self->{Timeoutable}   = 0;	# Shutdown sockets can't timeout.
 }
 
 =pod
@@ -1138,6 +1142,21 @@ sub PeerVersion {
    return $version;
 }
 
+#
+#  Manipulate the client data field
+#
+sub SetClientData {
+    my ($self, $newData) = @_;
+    $self->{ClientData} = $newData;
+}
+#
+#  Get the current client data field.
+#
+sub GetClientData {
+    my $self = shift;
+    return $self->{ClientData};
+}
+
 1;
 
 =pod
