@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Cookie Based Access Handler
 #
-# $Id: lonacc.pm,v 1.130.4.1 2010/03/19 22:22:34 raeburn Exp $
+# $Id: lonacc.pm,v 1.135 2010/10/29 20:41:49 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -156,7 +156,7 @@ sub get_posted_cgi {
 	for ($i=0;$i<=$#lines;$i++) {
 	    if ($lines[$i]=~/^--\Q$contentsep\E/) {
 		if ($name) {
-		    chomp($value);
+		    $value=~s/[\r\n]+$//;
                     if (ref($fields) eq 'ARRAY') {
                         next if (!grep(/^\Q$name\E$/,@{$fields}));
                     }
@@ -417,7 +417,7 @@ sub handler {
                 my $preserved;
                 foreach my $pair (split(/&/,$query)) {
                     my ($name, $value) = split(/=/,$pair);
-                    unless (($name eq 'symb') || ($name eq 'wrapperdisplay')) {
+                    unless ($name eq 'symb') {
                         $preserved .= $pair.'&';
                     }
                 }
@@ -501,11 +501,13 @@ sub handler {
 	    $requrl=~/\.(\w+)$/;
             my $query=$r->args;
 	    if ((&Apache::loncommon::fileembstyle($1) eq 'ssi') ||
-		($requrl=~/^\/adm\/.*\/(aboutme|navmaps|smppg|bulletinboard)(\?|$ )/x) ||
+		($requrl=~/^\/adm\/.*\/(aboutme|smppg|bulletinboard)(\?|$ )/x) ||
 		($requrl=~/^\/adm\/wrapper\//) ||
 		($requrl=~m|^/adm/coursedocs/showdoc/|) ||
 		($requrl=~m|\.problem/smpedit$|) ||
-		($requrl=~/^\/public\/.*\/syllabus$/)) {
+		($requrl=~/^\/public\/.*\/syllabus$/) ||
+                ($requrl=~/^\/adm\/(viewclasslist|navmaps)$/) ||
+                ($requrl=~/^\/adm\/.*\/aboutme\/portfolio(\?|$)/)) {
 # ------------------------------------- This is serious stuff, get symb and log
 		my $symb;
 		if ($query) {
@@ -520,7 +522,9 @@ sub handler {
 						  'last_known' =>[$murl,$mid]);
 		    } elsif ((&Apache::lonnet::symbverify($symb,$requrl)) ||
 			     (($requrl=~m|(.*)/smpedit$|) &&
-			      &Apache::lonnet::symbverify($symb,$1))) {
+			      &Apache::lonnet::symbverify($symb,$1)) ||
+                             (($requrl=~m|(.*/aboutme)/portfolio$|) &&
+                              &Apache::lonnet::symbverify($symb,$1))) {
 			my ($map,$mid,$murl)=&Apache::lonnet::decode_symb($symb);
 			&Apache::lonnet::symblist($map,$murl => [$murl,$mid],
 						  'last_known' =>[$murl,$mid]);
@@ -532,6 +536,9 @@ sub handler {
 			return HTTP_NOT_ACCEPTABLE; 
 		    }
 		} else {
+                    if ($requrl=~m{^(/adm/.*/aboutme)/portfolio$}) {
+                        $requrl = $1;
+                    }
 		    $symb=&Apache::lonnet::symbread($requrl);
 		    if (&Apache::lonnet::is_on_map($requrl) && $symb &&
 			!&Apache::lonnet::symbverify($symb,$requrl)) {
