@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Logout Handler
 #
-# $Id: lonlogout.pm,v 1.37 2009/03/16 17:07:38 bisitz Exp $
+# $Id: lonlogout.pm,v 1.38 2009/05/16 13:50:04 droeschl Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -103,7 +103,8 @@ sub handler {
 						   $switch);
     } else {
 	$start_page=&Apache::loncommon::start_page('Logged Out',undef,
-						   {'no_inline_link' => 1,});
+                           {'no_inline_link' => 1,
+                            'no_nav_bar'     => 1,});
 	
         $relogmessage.='<h1>'.&mt('Goodbye').'</h1>'
                       .'<p>'.&mt('Thank you for using LON-CAPA.').'</p>';
