@@ -1,7 +1,7 @@
 #
 # LON-CAPA helpers for cgi-bin scripts
 #
-# $Id: loncgi.pm,v 1.8 2006/09/19 21:36:31 albertel Exp $
+# $Id: loncgi.pm,v 1.11 2008/12/25 01:51:03 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -36,8 +36,8 @@ loncgi
 
 =head1 SYNOPSIS
 
-Provides subroutines for checking a LON-CAPA cookie and loading the users
-environment.
+Provides subroutines for checking a LON-CAPA cookie, loading the user's
+environment, and retrieving arguments passed in via a CGI's Query String.
 
 =head1 Subroutines
 
@@ -60,6 +60,7 @@ use Fcntl qw(:flock);
 use LONCAPA;
 use LONCAPA::Configuration();
 use GDBM_File;
+use Apache::lonlocal;
 
 my $lonidsdir;
 
@@ -69,14 +70,16 @@ BEGIN {
     $lonidsdir = $perlvar->{'lonIDsDir'};
 }
 
+
 #############################################
 #############################################
 
 =pod
 
-=item check_cookie_and_load_env
+=item check_cookie_and_load_env()
 
-Inputs: none
+Inputs: 1 ( optional). When called from a handler in mod_perl,
+        pass in the request object.
 
 Returns: 1 if the user has a LON-CAPA cookie 0 if not.
 Loads the users environment into the %env hash if the cookie is correct.
@@ -86,7 +89,13 @@ Loads the users environment into the %env hash if the cookie is correct.
 #############################################
 #############################################
 sub check_cookie_and_load_env {
-    my %cookies=fetch CGI::Cookie;
+    my ($r) = @_;
+    my %cookies;
+    if (ref($r)) {
+        %cookies = CGI::Cookie->fetch($r);    
+    } else {
+        %cookies = CGI::Cookie->fetch();
+    }
     if (exists($cookies{'lonID'}) && 
         -e "$lonidsdir/".$cookies{'lonID'}->value.".id") {
         # cookie found
@@ -103,7 +112,7 @@ sub check_cookie_and_load_env {
 
 =pod
 
-=item check_cookie
+=item check_cookie()
 
 Inputs: none
 
@@ -130,7 +139,7 @@ sub check_cookie {
 
 =pod
 
-=item transfer_profile_to_env
+=item transfer_profile_to_env()
 
 Load the users environment into the %env hash.
 
@@ -156,6 +165,63 @@ sub transfer_profile_to_env {
 #############################################
 #############################################
 
+=pod
+
+=item missing_cookie_msg()
+
+Inputs: none
+Returns: HTML for a page indicating cookie information absent. 
+
+=cut
+
+#############################################
+#############################################
+sub missing_cookie_msg {
+    my %lt = &Apache::lonlocal::texthash (
+                        cook => 'Bad Cookie',
+                        your => 'Your cookie information is incorrect.',
+             );
+    return <<END;
+<html>
+<head><title>$lt{'cook'}</title></head>
+<body>
+$lt{'your'}
+</body>
+</html>
+END
+
+}
+
+#############################################
+#############################################
+
+=pod
+
+=cgi_getitems()
+
+Inputs: $query (the CGI query string), and $getitems, a reference to a hash 
+
+Returns: nothing
+
+Side Effects: populates $getitems hash ref with key => value
+              where each key is the name of the form item in the query string
+              and value is an array of corresponding values. 
+
+=cut
+
+#############################################
+#############################################
+sub cgi_getitems {
+    my ($query,$getitems)= @_;
+    foreach (split(/&/,$query)) {
+        my ($name, $value) = split(/=/,$_);
+        $name = &unescape($name);
+        $value =~ tr/+/ /;
+        $value =~ s/%([a-fA-F0-9][a-fA-F0-9])/pack("C",hex($1))/eg;
+        push(@{$$getitems{$name}},$value);
+    }
+    return;
+}
 
 =pod
 
