@@ -1,6 +1,6 @@
 # functions to glue school database system into Lon-CAPA for 
 # automated enrollment
-# $Id: localenroll.pm,v 1.40 2010/07/12 23:55:07 raeburn Exp $
+# $Id: localenroll.pm,v 1.42 2011/05/23 19:11:41 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -233,7 +233,7 @@ sub get_sections {
  The course section or crosslisted course will only be added to the list of
  affiliates if 'ok' is returned.
 
- new_course takes three arguments -
+ new_course takes three required arguments -
  (a) the institutional courseID (in the MSU case this is a concatenation of 
  semester code, department code, course number, and section number
  e.g., fs03nop590001).
@@ -242,10 +242,14 @@ sub get_sections {
  username:domain
  (c) the LON-CAPA domain that contains the course
 
+ new_course also takes a fourth (optional) argument -
+ (d) the course co-owners, as a comma-separated list of username:domain for
+ any co-owners. 
+
 =cut
 
 sub new_course  {
-    my ($course_id,$owner,$dom) = @_;
+    my ($course_id,$owner,$dom,$coowners) = @_;
     my $outcome = 'ok';
     return $outcome;
 }
@@ -374,7 +378,7 @@ lonnet -> lond -> localenroll.pm) The domain configuration menu includes
 a table where columns are course type (official, unofficial or community) 
 and rows are institutional affiliations (e.g., Faculty, Staff, Student etc.).
 
-crsreq_checks() takes three arguments: $dom, $reqtyes, $validations.
+crsreq_checks() takes three arguments: $dom, $reqtypes, $validations.
 $dom - the domain for which validation options are needed.
 $reqtypes - ref to an ARRAY of course types (i.e., official, unofficial and community.
 $validations - ref to a hash of a hash which will determine whether "validate"
