@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # chemical equation style response
 #
-# $Id: chemresponse.pm,v 1.86 2008/12/23 18:51:44 raeburn Exp $
+# $Id: chemresponse.pm,v 1.87 2010/02/28 23:35:53 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -304,9 +304,17 @@ sub end_organicresponse {
 		    $ad='INCORRECT';
 		}
 	    }
-	    if ($ad && $Apache::lonhomework::type eq 'survey') {
-		$ad='SUBMITTED';
-	    }
+            if ($ad) {
+	        if ($Apache::lonhomework::type eq 'survey') {
+		    $ad='SUBMITTED';
+                } elsif ($Apache::lonhomework::type eq 'surveycred') {
+                    $ad='SUBMITTED_CREDIT';
+                } elsif ($Apache::lonhomework::type eq 'anonsurvey') {
+                    $ad='ANONYMOUS';
+                } elsif ($Apache::lonhomework::type eq 'anonsurveycred') {
+                    $ad='ANONYMOUS_CREDIT';
+                }
+            }
 	    &Apache::response::handle_previous(\%previous,$ad);
 	    $Apache::lonhomework::results{"resource.$partid.$id.awarddetail"}=$ad;
 	    $Apache::lonhomework::results{"resource.$partid.$id.molecule"}=$env{"form.MOLECULE_$id"};
@@ -558,9 +566,17 @@ sub end_reactionresponse {
 		    $ad='INCORRECT';
 		}
 	    }
-	    if ($ad && $Apache::lonhomework::type eq 'survey') {
-		$ad='SUBMITTED';
-	    }
+            if ($ad) {
+                if ($Apache::lonhomework::type eq 'survey') {
+		    $ad='SUBMITTED';
+	        } elsif ($ad && $Apache::lonhomework::type eq 'surveycred') {
+                    $ad='SUBMITTED_CREDIT';
+                } elsif ($ad && $Apache::lonhomework::type eq 'anonsurvey') {
+                    $ad='ANONYMOUS';
+                } elsif ($ad && $Apache::lonhomework::type eq 'anonsurveycred') {
+                    $ad='ANONYMOUS_CREDIT';
+                }
+            }
 	    &Apache::response::handle_previous(\%previous,$ad);
 	    $Apache::lonhomework::results{"resource.$partid.$id.awarddetail"}=$ad;
 	}
