@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # essay (ungraded) style responses
 #
-# $Id: essayresponse.pm,v 1.101 2009/05/23 18:07:57 riegler Exp $
+# $Id: essayresponse.pm,v 1.114 2011/01/29 19:41:41 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -29,7 +29,10 @@
 package Apache::essayresponse;
 use strict;
 use Apache::lonxml();
+use Apache::lonhtmlcommon;
+use Apache::loncommon;
 use Apache::lonnet;
+use Apache::lonnavmaps;
 use Apache::lonlocal;
 use LONCAPA qw(:DEFAULT :match);
  
@@ -55,25 +58,37 @@ sub start_essayresponse {
         if (!defined($maxfilesize)) {
             $maxfilesize = 10.0; #FIXME This should become a domain configuration 
         }
-	if ( $Apache::lonhomework::type eq 'survey' ) {
-	    $result.= '<input type="hidden" name="HWDRAFT'.$part.'_'.$id.'" value="yes" /> ';
-	}
-	$result.='<br /><table border="1">';
-	if ( $Apache::lonhomework::type ne 'survey' ) {
-	    $result.= '<tr><td>'.
+        my $hiddendraft;
+	if (($Apache::lonhomework::type eq 'survey') ||
+            ($Apache::lonhomework::type eq 'surveycred') ||
+            ($Apache::lonhomework::type eq 'anonsurvey') ||
+            ($Apache::lonhomework::type eq 'anonsurveycred')) {
+            $hiddendraft = '<input type="hidden" name="HWDRAFT'.$part.'_'.$id.'" value="yes" />';
+        } else {
+            my $status_text = &mt('Submission type');
+            if ($Apache::lonhomework::history{"resource.$part.award"} eq 'DRAFT') {
+                $status_text .= '<br />'.&mt('(Currently -- draft)');
+            }
+            $result = &Apache::lonhtmlcommon::row_title($status_text);
+            my $closure;
+            unless ($ncol || $uploadedfiletypes) {
+                $closure = 1;
+            }
+	    $result.= 
 		'<label>'.
-		'<input type="radio" name="HWDRAFT'.$part.'_'.$id.'" value="yes" checked="checked" /> '.
+		'<input type="radio" name="HWDRAFT'.$part.'_'.$id.'" value="yes" checked="checked" />&nbsp;'.
 		&mt('Submit entries below as answer to receive credit').
 		'</label> <br />'.
 		'<label>'.
-		'<input type="radio" name="HWDRAFT'.$part.'_'.$id.'" value="no" /> '.
+		'<input type="radio" name="HWDRAFT'.$part.'_'.$id.'" value="no" />&nbsp;'.
 		&mt('Save entries below (not submitted for credit yet)').
 		'</label>'.
-		'</td></tr>';
+                &Apache::lonhtmlcommon::row_closure($closure);
 	}
 
 	if ($ncol > 0) {
-	    $result .='<tr><td>'.'<label>'.
+	    $result.= &Apache::lonhtmlcommon::row_title(&mt('Collaborators')).
+                      '<label>'.
 		      &mt('Collaborators:').' <input type="text" size="70" max="80" name="HWCOL'.
 		      $part.'_'.$id.'" value="'.$coll.'" /><br />'.
 		      &mt('(Enter a maximum of [quant,_1,collaborator] using username or username:domain, e.g. smithje or smithje:[_2].)',$ncol,$env{'user.domain'});
@@ -82,7 +97,7 @@ sub start_essayresponse {
             }
             $result .= '</label><br />';
 	    $result .= &check_collaborators($ncol,$coll) if ($coll =~ /\w+/);
-	    $result .='</td></tr>';
+	    $result .= &Apache::lonhtmlcommon::row_closure();
 	}
         my $filesfrom = 'both';
         my $stuname = &Apache::lonnet::EXT('user.name');
@@ -92,27 +107,29 @@ sub start_essayresponse {
         }
 	$result.=&Apache::inputtags::file_selector($part,$id,$uploadedfiletypes,
 						   $filesfrom,undef,$maxfilesize);
-        $result.='</table>';
+        if ($result) {
+            $result =
+                  '<div>'.$hiddendraft.
+                  &Apache::lonhtmlcommon::start_pick_box().
+                  $result.
+                  &Apache::lonhtmlcommon::end_pick_box().'</div>';
+        } else {
+            $result = $hiddendraft;
+        }
     } elsif ($target eq 'web' &&
 	     $Apache::inputtags::status[-1] ne 'CAN_ANSWER') {
 	my $part= $Apache::inputtags::part;
 	my @msgs;
 	if ($Apache::lonhomework::history{"resource.$part.$id.collaborators"} =~ /\S/) {
 	    my $coll= &HTML::Entities::encode($Apache::lonhomework::history{"resource.$part.$id.collaborators"},'<>&"');
-	    $result .= '<td>'.&mt('Collaborated with [_1]',$coll).'</td>';
+	    $result .= '<td><i>'.&mt('Collaborated with [_1]',$coll).'</i></td>';
 	}
 
-	my $file_submission = 
-	    &Apache::inputtags::show_past_file_submission($part,$id);
-	if ($file_submission) {
-	    $result .= '<td>'.$file_submission.'</td>';
-	}
-
-	my $port_submission = 
-	    &Apache::inputtags::show_past_portfile_submission($part,$id);
-	if ($port_submission) {
-	    $result .= '<td>'.$port_submission.'</td>';
-	}
+        my $current_files_display = &Apache::inputtags::current_file_submissions($part,$id);
+        if ($current_files_display) {
+            $result .= '<td><b>'.&mt('Submitted files:').'</b><br />'.
+                       $current_files_display.'</td>';
+        }
 
 	if ($result ne '') {
 	    $result = 
@@ -130,32 +147,58 @@ sub end_essayresponse {
     my $increment     = &Apache::response::repetition();
     my $result;
     if ( $target eq 'grade' ) {
-	my $collaborators = $env{'form.HWCOL'.$part.'_'.$id};	
-	if ($collaborators =~ /[^\s]/) {
-	    my $previous_list= &HTML::Entities::encode($Apache::lonhomework::history{"resource.$part.$id.collaborators"},'<>&"');
-	    $Apache::lonhomework::results{"resource.$part.$id.collaborators"}=$collaborators
-		if ($collaborators ne $previous_list);
-	}
+# Deal with collaborators
+	my $collaborators = $env{'form.HWCOL'.$part.'_'.$id};
+	my $previous_list= &HTML::Entities::encode($Apache::lonhomework::history{"resource.$part.$id.collaborators"},'<>&"');
+	if ($collaborators ne $previous_list) { 
+#           &Apache::lonnet::logthis("New collaborators [$collaborators] [$previous_list]");
+           $Apache::lonhomework::results{"resource.$part.$id.collaborators"}=$collaborators; 
+        }
+# Scantron
 	if (  &Apache::response::submitted('scantron') ) {
 	    $increment=&Apache::response::scored_response($part,$id);
 	} elsif ( &Apache::response::submitted() ) {
 	    my $response      = $env{'form.HWVAL_'.$id};
-            my $filename = $env{'form.HWFILE'.$part.'_'.$id.'.filename'} || 
+            my $jspart=$part;
+            $jspart=~s/\./_/g;
+            my $filename = $env{'form.HWFILE'.$jspart.'_'.$id.'.filename'} || 
                            $env{'form.HWFILETOOBIG'.$part.'_'.$id};
-            my $portfiles = $env{'form.HWPORT'.$part.'_'.$id};
-	    if (( $response =~ /[^\s]/) || ($filename =~ /[^\s]/) || ($portfiles =~ /[^\s]/)) {
+            my $portfiles = $env{'form.HWPORT'.$jspart.'_'.$id};
+            my @deletions = &Apache::loncommon::get_env_multiple('form.HWFILE'.$jspart.'_'.$id.'_delete');
+            my ($is_submit,$was_draft);
+            if ($env{'form.HWDRAFT'.$part.'_'.$id} eq 'yes') {
+                 $is_submit = 1;
+            }
+            if ($Apache::lonhomework::history{"resource.$part.award"} eq 'DRAFT') {
+                $was_draft = 1;
+            }
+	    if (($response =~ /[^\s]/) || ($filename =~ /[^\s]/) || ($portfiles =~ /[^\s]/) || 
+                (@deletions > 0) || ($was_draft && $is_submit)) {
  		my $award='DRAFT';
         	if ($env{'form.HWDRAFT'.$part.'_'.$id} eq 'yes') {
-		    $award='SUBMITTED';
+                    if ($Apache::lonhomework::type eq 'anonsurvey') {
+                        $award='ANONYMOUS';
+                    } elsif ($Apache::lonhomework::type eq 'anonsurveycred') {
+                        $award='ANONYMOUS_CREDIT';
+                    } elsif ($Apache::lonhomework::type eq 'surveycred') {
+                        $award='SUBMITTED_CREDIT';
+                    } else {
+		        $award='SUBMITTED';
+                    }
 		}
                 my $uploadedflag=0;
                 my $totalsize=0;
-		&file_submission($part,$id,'filename',\$award,\$uploadedflag,\$totalsize);
-		&file_submission($part,$id,'portfiles',\$award,\$uploadedflag,\$totalsize);
+                &file_submission($part,$id,\$award,\$uploadedflag,\$totalsize,\@deletions);
 		$Apache::lonhomework::results{"resource.$part.$id.submission"}=$response;
 		$Apache::lonhomework::results{"resource.$part.$id.awarddetail"}=$award;
 		my %previous=&Apache::response::check_for_previous($response,$part,$id);
-		unless ($uploadedflag) { &Apache::response::handle_previous(\%previous,$award); }
+		if ($uploadedflag) {
+                    if ($award eq 'FILENAME_INUSE') {
+                        delete($Apache::lonhomework::results{"resource.$id.tries"});
+                    }
+                } else {
+                    &Apache::response::handle_previous(\%previous,$award);
+                }
 #
 # Store with resource author for similarity testing
 #
@@ -175,7 +218,7 @@ sub end_essayresponse {
 					 { $akey => $response },$adom,$aname);
 		    }
                 }
-	    }
+            }
 	} 
     } elsif ($target eq 'edit') {
 	$result.=&Apache::edit::end_table();
@@ -243,59 +286,114 @@ sub format_prior_response {
 }
 
 sub file_submission {
-    my ($part,$id,$which,$award,$uploadedflag,$totalsize)=@_;
+    my ($part,$id,$award,$uploadedflag,$totalsize,$deletions)=@_;
     my $files;
     my $jspart=$part;
     $jspart=~s/\./_/g;
-    if ($which eq 'portfiles') { 
-        $files= $env{'form.HWPORT'.$jspart.'_'.$id};
-    } elsif ($which eq 'filename') {
-        if ($env{'form.HWFILETOOBIG'.$jspart.'_'.$id} ne '') {
-            $$award = 'EXCESS_FILESIZE';
-            return;
-        } else {
-            $files = $env{'form.HWFILE'.$jspart.'_'.$id.'.filename'};
+    my ($symb,$crsid,$udom,$uname) = &Apache::lonnet::whichuser();
+    my %crsinfo = &Apache::lonnet::coursedescription($crsid);
+    my $cdom = $crsinfo{'domain'};
+    my $cnum = $crsinfo{'num'};
+    my (@portfiles,$uploadedurl,@submitted_portfiles,$submitted_upload,
+        @acceptable_portfiles,$acceptable_upload,@accepted_portfiles,
+        $accepted_upload,@savedportfiles,$stored_upload,@tolock,
+        %port_delete,$uploaded_delete);
+    if ($Apache::lonhomework::history{"resource.$part.$id.portfiles"} ||
+        $Apache::lonhomework::history{"resource.$part.$id.uploadedurl"}) {
+        if ($Apache::lonhomework::history{"resource.$part.$id.portfiles"}) {
+            @portfiles = split(/,/,$Apache::lonhomework::history{"resource.$part.$id.portfiles"});
+        }
+        $uploadedurl = $Apache::lonhomework::history{"resource.$part.$id.uploadedurl"};
+        if (ref($deletions) eq 'ARRAY') {
+            if (@{$deletions} > 0) {
+                foreach my $file (@{$deletions}) {
+                    $file = &HTML::Entities::decode($file);
+                    if (grep(/^\Q$file\E$/,@portfiles)) {
+                        $port_delete{$file} = 1;
+                    } elsif ($file =~ m{^/uploaded/\Q$udom\E/\Q$uname\E/essayresponse/\Q$cdom\E/\Q$cnum\E/}) {
+                        $uploaded_delete = $file; 
+                    } elsif ($file =~ m{^/uploaded/\Q$udom\E/\Q$uname\E/essayresponse/[^/]+$}) {
+                        $uploaded_delete = $file;
+                    }
+                }
+            }
+        }
+        foreach my $current (@portfiles) {
+            unless ($port_delete{$current}) {
+                push(@savedportfiles,$current);
+            }
+        }
+        if ($uploaded_delete) {
+            if ($uploaded_delete eq $uploadedurl) {
+                $Apache::lonhomework::results{"resource.$part.$id.uploadedfile"} = "";
+                $Apache::lonhomework::results{"resource.$part.$id.uploadedurl"} = "";
+            } else {
+                undef($uploaded_delete);
+            }
         }
     }
-    if ($files =~ /[^\s]/) {
-	$files =~s/,$//;
-        my (@submitted_files,@acceptable_files,@accepted_files);
-        if ($which eq 'portfiles') {
-            @submitted_files = split(/\s*,\s*/,$files);
-        } else {
-            @submitted_files = ($files);
+    if ($env{'form.HWPORT'.$jspart.'_'.$id} ne '') {
+        my $newfiles= $env{'form.HWPORT'.$jspart.'_'.$id};
+        $newfiles =~s/,$//;
+        if ($newfiles =~ /[^\s]/) {
+            foreach my $file (split(/\s*,\s*/,$newfiles)) {
+                if ($file =~ /[^\s]/) {
+                    push(@submitted_portfiles,$file);
+                }
+            }
         }
-        my $uploadedfiletypes= 
+    }
+    if ($env{'form.HWFILETOOBIG'.$part.'_'.$id} ne '') {
+        $$award = 'EXCESS_FILESIZE';
+    } elsif ($env{'form.HWFILE'.$jspart.'_'.$id.'.filename'} ne '') {
+        my $newfile = $env{'form.HWFILE'.$jspart.'_'.$id.'.filename'};
+        if ($newfile =~ /[^\s]/) {
+            $submitted_upload = $newfile;
+        }
+    }
+    if (@savedportfiles) {
+        foreach my $file (reverse(@savedportfiles)) {
+            unless(grep(/^\Q$file\E$/,@submitted_portfiles)) {
+                unshift(@submitted_portfiles,$file);
+            }
+        }
+    }
+    if (@submitted_portfiles || $submitted_upload) {
+        my $uploadedfiletypes=
             &Apache::lonnet::EXT("resource.$part".'_'."$id.uploadedfiletypes");
         if ($uploadedfiletypes ne '') {
             $uploadedfiletypes=~s/[^\w\,]//g;
             $uploadedfiletypes=','.$uploadedfiletypes.',';
-            foreach my $file (@submitted_files) {
-                my ($extension)=($file=~/\.(\w+)$/);
-                if ($uploadedfiletypes=~/\,\s*\Q$extension\E\s*\,/i) {
-                    push(@acceptable_files,$file);
-                } else {
-                    $$award='INVALID_FILETYPE';
-                    if ($which eq 'filename') {
-                        &delete_form_items($jspart,$id);
+            if (@submitted_portfiles) {
+                foreach my $file (@submitted_portfiles) {
+                    my ($extension)=($file=~/\.(\w+)$/);
+                    if ($uploadedfiletypes=~/\,\s*\Q$extension\E\s*\,/i) {
+                        push(@acceptable_portfiles,$file);
                     }
                 }
             }
+            if ($submitted_upload) {
+                my ($upload_ext)=($submitted_upload=~/\.(\w+)$/);
+                if ($uploadedfiletypes=~/\,\s*\Q$upload_ext\E\s*\,/i) {
+                    $acceptable_upload = $submitted_upload;
+                } else {
+                    $$award='INVALID_FILETYPE';
+                    &delete_form_items($jspart,$id);
+                }
+            }
         } else {
-            @acceptable_files = @submitted_files;
+            @acceptable_portfiles = @submitted_portfiles;
+            $acceptable_upload = $submitted_upload;
         }
+    }
+    if ((@acceptable_portfiles) || ($acceptable_upload ne '')) {
         my $maxfilesize=&Apache::lonnet::EXT("resource.$part".'_'."$id.maxfilesize");
         if (!$maxfilesize) {
             $maxfilesize = 10.0; #FIXME This should become a domain configuration
         }
         my %dirlist;
-        foreach my $file (@acceptable_files) {
-            if ($which eq 'filename') {
-                if (ref($totalsize)) {
-                    $$totalsize += $env{'form.HWFILESIZE'.$jspart.'_'.$id};
-                }
-            } else {
-                my ($symb,$crsid,$udom,$uname) = &Apache::lonnet::whichuser();
+        if (@acceptable_portfiles) {
+            foreach my $file (@acceptable_portfiles) {
                 my ($path,$filename) = ($file =~ m{^(.*/)([^/]+)$});
                 my $fullpath = '/userfiles/portfolio'.$path;
                 if (!exists($dirlist{$fullpath})) {
@@ -305,7 +403,7 @@ sub file_submission {
                 if (ref($dirlist{$fullpath}) eq 'ARRAY') {
                     foreach my $dir_line (@{$dirlist{$fullpath}}) {
                         my ($fname,$dom,undef,$testdir,undef,undef,undef,undef,
-                            $size,undef,$mtime,undef,undef,undef,$obs,undef) = 
+                            $size,undef,$mtime,undef,undef,undef,$obs,undef) =
                         split(/\&/,$dir_line,16);
                         if ($filename eq $fname) {
                             my $mbsize = $size/(1024.0*1024.0);
@@ -316,78 +414,129 @@ sub file_submission {
                         }
                     }
                 }
+                if (ref($totalsize)) {
+                    if ($$totalsize > $maxfilesize) {
+                        $$award='EXCESS_FILESIZE';
+                        &delete_form_items($jspart,$id);
+                    } else {
+                        push(@accepted_portfiles,$file);
+                    }
+                } else {
+                    push(@accepted_portfiles,$file);
+                }
             }
+        }
+        if ($acceptable_upload ne '') {
             if (ref($totalsize)) {
+                $$totalsize += $env{'form.HWFILESIZE'.$jspart.'_'.$id};
                 if ($$totalsize > $maxfilesize) {
                     $$award='EXCESS_FILESIZE';
-                    if ($which eq 'filename') {
-                        &delete_form_items($jspart,$id);
-                    }
-                    last;
+                    delete($env{'form.HWFILE'.$jspart.'_'.$id});
                 } else {
-                    push(@accepted_files,$file);
+                    $accepted_upload = $acceptable_upload;
                 }
             } else {
-                push(@accepted_files,$file);
+                $accepted_upload = $acceptable_upload;
             }
         }
-        $Apache::lonhomework::results{"resource.$part.$id.$which"}=join(',',@accepted_files);
-        if (($$award eq 'INVALID_FILETYPE') || ($award eq 'EXCESS_FILESIZE')) {
-            return;
-        }
-	if (ref($uploadedflag)) {
-	    $$uploadedflag=1;
-	}
-        my ($symb,$crsid,$domain,$name)=&Apache::lonnet::whichuser();
-	if ($which eq 'portfiles') {
-	    &Apache::lonnet::unmark_as_readonly($domain,$name,[$symb,$crsid]);
-	    &Apache::lonnet::mark_as_readonly($domain,$name,\@submitted_files,[$symb,$crsid]);
-	    &Apache::lonnet::clear_selected_files($name);
-	}
-	if ($which eq 'filename') {
-	    $Apache::lonhomework::results{"resource.$part.$id.uploadedfile"}=
-		$files;
-            my $cleanpart = $part;
-            $cleanpart =~ s/\W/_/g;
-            my $cleanid = $id;
-            $cleanid =~ s/\W/_/g;
-            my ($map,$resid,$res)=&Apache::lonnet::decode_symb($symb);
-            my $container;
-            if ($map =~ /^uploaded/) {
-                (my $prefix,$container) = ($map =~ m{^uploaded/[^/]+/[^/]+/(default|supplemental)_?([^.]*)\.(?:sequence|page)$});
-                if (length($container) > 10) {
-                    $container = substr($container,-10,10);
-                }
-                if ($container ne '') {
-                    $container = $prefix.'_'.$container;
-                } else {
-                    $container = $prefix;
-                } 
-            } else {
-                ($container) = ($map =~ m{(.+)\.(?:sequence|page)$});
-                $container =~ s/\W/_/g;
-                if (length($container) > 255) {
-                    $container = substr($container,0,254);
-                }
-            }
-            my $subdir = 'essayresponse';
-            my %crsdesc = &Apache::lonnet::coursedescription($crsid);
-            foreach my $item ($crsdesc{'domain'},$crsdesc{'num'},$container,$resid,$cleanpart,$cleanid) {
-                if ($item ne '') {
-                    $subdir .= '/'.$item;
-                }
-            }
-	    $Apache::lonhomework::results{"resource.$part.$id.uploadedurl"}=
-		&Apache::lonnet::userfileupload('HWFILE'.$jspart.'_'.$id,undef,
-						$subdir);
-            delete($env{'form.HWFILE'.$jspart.'_'.$id});
-	}
-    } elsif ($which eq 'portfiles' &&
-	     $Apache::lonhomework::history{"resource.$part.$id.$which"}) {
-	my ($symb,$crsid,$domain,$name)=&Apache::lonnet::whichuser();
-	&Apache::lonnet::unmark_as_readonly($domain,$name,[$symb,$crsid]);
-	$Apache::lonhomework::results{"resource.$part.$id.$which"}="";
     }
+    if ($accepted_upload ne '') {
+        my ($map,$resid,$resurl)=&Apache::lonnet::decode_symb($symb);
+        my $turnindir;
+        my %userhash = &Apache::lonnet::userenvironment($udom,$uname,'turnindir');
+        $turnindir = $userhash{'turnindir'};
+        if ($turnindir eq '') {
+            $turnindir = &mt('turned in');
+            $turnindir =~ s/\W+/_/g;
+            my %newhash = (
+                            'turnindir' => $turnindir,
+                          );
+            &Apache::lonnet::put('environment',\%newhash,$udom,$uname);
+        }
+        my $prefix = 'portfolio';
+        my $path = '/'.$turnindir.'/';
+        my $restitle=&Apache::lonnet::gettitle($symb);
+        $restitle =~ s/\W+/_/g;
+        if ($restitle eq '') {
+            $restitle = ($resurl =~ m{/[^/]+$});
+            if ($restitle eq '') {
+                $restitle = time;
+            }
+        }
+        my @pathitems;
+        my $navmap = Apache::lonnavmaps::navmap->new();
+        if (defined($navmap)) {
+            my $mapres = $navmap->getResourceByUrl($map);
+            if (ref($mapres)) {
+                my $pcslist = $mapres->map_hierarchy();
+                if ($pcslist ne '') {
+                    foreach my $pc (split(/,/,$pcslist)) {
+                        my $res = $navmap->getByMapPc($pc);
+                        if (ref($res)) {
+                            my $title = $res->compTitle();
+                            $title =~ s/\W+/_/g;
+                            if ($title ne '') {
+                                push(@pathitems,$title);
+                            }
+                        }
+                    }
+                }
+                my $maptitle = $mapres->compTitle();
+                $maptitle =~ s/\W+/_/g;
+                if ($maptitle ne '') {
+                    push(@pathitems,$maptitle);
+                }
+            } else {
+                $$award = 'INTERNAL_ERROR';
+            }
+        } else {
+            $$award = 'INTERNAL_ERROR';
+        }
+        push(@pathitems,$restitle);
+        $path .= join('/',@pathitems);
+        my $formelement = 'HWFILE'.$jspart.'_'.$id;
+        my $fname = &Apache::lonnet::clean_filename($env{'form.'.$formelement.'.filename'});
+        my $url = '/uploaded/'.$udom.'/'.$uname.'/'.$prefix.$path.'/'.$fname;
+        my @stat = &Apache::lonnet::stat_file($url);
+        if (@stat && $stat[0] ne 'no_such_dir') {
+            $$award = 'FILENAME_INUSE';
+        } else {
+            my ($mode,%allfiles,%codebase);
+            my $result = &Apache::lonnet::userfileupload($formelement,'',
+                             $prefix.$path,$mode,\%allfiles,\%codebase);
+            if ($result =~ m{^/uploaded/}) {
+                $stored_upload = $path.'/'.$fname;
+                $Apache::lonhomework::results{"resource.$part.$id.portfiles"} = $stored_upload;
+                push(@tolock,$stored_upload);
+            } else {
+                $$award = 'INTERNAL_ERROR';
+            }
+        }
+        delete($env{'form.HWFILE'.$jspart.'_'.$id});
+    }
+    if (@accepted_portfiles) {
+        if ($stored_upload) {
+            $Apache::lonhomework::results{"resource.$part.$id.portfiles"} .= ',';
+        }
+        $Apache::lonhomework::results{"resource.$part.$id.portfiles"}.=join(',',@accepted_portfiles);
+        push(@tolock,@accepted_portfiles);
+    }
+    if (!defined($Apache::lonhomework::results{"resource.$part.$id.portfiles"})) {
+        if (keys(%port_delete) > 0) {
+            $Apache::lonhomework::results{"resource.$part.$id.portfiles"} = "";
+        }
+    }
+    if (($Apache::lonhomework::history{"resource.$part.$id.portfiles"} ne  
+         $Apache::lonhomework::results{"resource.$part.$id.portfiles"}) ||
+        ($uploaded_delete)) {
+        if (ref($uploadedflag)) {
+            $$uploadedflag=1;
+        }
+    }
+    &Apache::lonnet::unmark_as_readonly($udom,$uname,[$symb,$crsid]);
+    &Apache::lonnet::mark_as_readonly($udom,$uname,[@tolock],[$symb,$crsid]);
+    &Apache::lonnet::clear_selected_files($uname);
+    return;
 }
 
 sub delete_form_items {
@@ -397,7 +546,6 @@ sub delete_form_items {
     delete($env{'form.HWFILE'.$jspart.'_'.$id});
 }
 
-
 sub check_collaborators {
     my ($ncol,$coll) = @_;
     my %classlist=&Apache::lonnet::dump('classlist',
@@ -405,7 +553,7 @@ sub check_collaborators {
 					$env{'course.'.$env{'request.course.id'}.'.num'});
     my (@badcollaborators,$result);
   
-    my (@collaborators) = split(/,?\s+/,$coll);
+    my (@collaborators) = split(/[,;\s]+/,$coll);
     foreach my $entry (@collaborators) {
         my $collaborator;
 	if ($entry =~ /:/) {
@@ -453,7 +601,7 @@ __END__
 
 =head1 NAME
 
-Apache::easyresponse
+Apache::essayresponse
 
 =head1 SYNOPSIS
 
