@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # implements the tags that control the hints
 #
-# $Id: hint.pm,v 1.72 2008/10/24 16:22:54 bisitz Exp $
+# $Id: hint.pm,v 1.77 2010/11/13 03:22:58 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -26,6 +26,8 @@
 # http://www.lon-capa.org/
 #
 
+
+
 package Apache::hinttags; 
 
 use strict;
@@ -33,12 +35,14 @@ use Apache::lonnet();
 use capa;
 use Apache::caparesponse();
 use Apache::lonmaxima();
+use Apache::lonr();
+use Apache::chemresponse();
 use Apache::response();
 use Apache::lonlocal;
 use Storable qw(dclone);
 
 BEGIN {
-    &Apache::lonxml::register('Apache::hinttags',('hintgroup','hintpart','numericalhint','stringhint','formulahint','optionhint','radiobuttonhint','mathhint','customhint'));
+    &Apache::lonxml::register('Apache::hinttags',('hintgroup','hintpart','numericalhint','stringhint','formulahint','optionhint','radiobuttonhint','mathhint','customhint','reactionhint','organichint'));
 }
 
 
@@ -77,6 +81,10 @@ sub start_hintgroup {
        }
     }
     @Apache::hint::which=();
+    if (($#Apache::functionplotresponse::failedrules>=0) && ($target eq 'web')) {
+        @Apache::hint::which=@Apache::functionplotresponse::failedrules;
+        undef @Apache::functionplotresponse::failedrules;
+    }
     return $result;
 }
 
@@ -242,7 +250,7 @@ sub start_mathhint {
         $result.=&Apache::edit::text_arg('Name:','name',$token);
         $result.=&Apache::edit::select_arg('Algebra System:',
                                            'cas',
-                                           ['maxima'],
+                                           ['maxima','R'],
                                            $token);
         $result.=&Apache::edit::text_arg('Argument Array:',
                                          'args',$token);
@@ -280,6 +288,10 @@ sub end_mathhint {
 	    my $args = [&Apache::lonxml::get_param_var('args',$parstack,$safeeval)];
 	    $award=&Apache::lonmaxima::maxima_run($Apache::response::custom_answer[-1],$response,$args);
 	}
+        if ($cas eq 'R') {
+            my $args = [&Apache::lonxml::get_param_var('args',$parstack,$safeeval)];
+            $award=&Apache::lonr::r_run($Apache::response::custom_answer[-1],$response,$args);
+        }
         if ($award eq 'EXACT_ANS' || $award eq 'APPROX_ANS') {
             push (@Apache::hint::which,$name);
         }
@@ -460,6 +472,126 @@ sub end_stringhint {
     return $result;
 }
 
+# reactionhint
+
+sub start_reactionhint {
+    my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
+    #do everything in end, so intervening <responseparams> work
+    &Apache::response::start_hintresponse($parstack,$safeeval);
+    my $result;
+    if ($target eq 'edit') {
+        $result.=&Apache::edit::tag_start($target,$token);
+        $result.=&Apache::edit::text_arg('Name:','name',$token);
+        $result.=&Apache::edit::text_arg('Answer:','answer',$token);
+        $result.=&Apache::edit::end_row();
+        $result.=&Apache::edit::start_spanning_row();
+    } elsif ($target eq 'modified') {
+        my $constructtag;
+        $constructtag=&Apache::edit::get_new_args($token,$parstack,
+                                                  $safeeval,'name','answer',
+                                                  );
+        $result  = &Apache::edit::rebuild_tag($token);
+    } elsif ($target eq 'web') {
+        &Apache::response::reset_params();
+    }
+    return $result;
+}
+
+sub end_reactionhint {
+    my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
+    my $result;
+    if ($target eq 'web') {
+        if (!$Apache::lonxml::default_homework_loaded) {
+            &Apache::lonxml::default_homework_load($safeeval);
+        }
+        my $hint_name= &Apache::lonxml::get_param('name',$parstack,$safeeval);
+        &Apache::response::setup_params('reactionhint',$safeeval);
+        my $partid=$Apache::inputtags::part;
+        my $id=$Apache::inputtags::hint[-1];
+        #id submissions occurred under
+        my $submitid=$Apache::inputtags::response[-1];
+        my $response = $Apache::lonhomework::history{
+                            "resource.$partid.$submitid.submission"};
+        &Apache::lonxml::debug("hintgroup is using $response<br />\n");
+        my $answer=&Apache::lonxml::get_param('answer',$parstack,
+                                                  $safeeval);
+        &Apache::lonxml::debug("current $response");
+        &Apache::lonxml::debug("current $answer");
+        if (&Apache::chemresponse::chem_standard_order($response) eq 
+            &Apache::chemresponse::chem_standard_order($answer)) {
+            push(@Apache::hint::which,$hint_name);
+        }
+        $result='';
+    } elsif ($target eq 'meta') {
+        $result=&Apache::response::meta_package_write($token->[1]);
+    } elsif ($target eq 'edit') {
+        $result.=&Apache::edit::end_row().&Apache::edit::end_table();
+    }
+    &Apache::response::end_hintresponse();
+    return $result;
+}
+
+# organichint
+
+sub start_organichint {
+    my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
+    #do everything in end, so intervening <responseparams> work
+    &Apache::response::start_hintresponse($parstack,$safeeval);
+    my $result;
+    if ($target eq 'edit') {
+        $result.=&Apache::edit::tag_start($target,$token);
+        $result.=&Apache::edit::text_arg('Name:','name',$token);
+        $result.=&Apache::edit::text_arg('Answer:','answer',$token);
+        $result.=&Apache::edit::end_row();
+        $result.=&Apache::edit::start_spanning_row();
+    } elsif ($target eq 'modified') {
+        my $constructtag;
+        $constructtag=&Apache::edit::get_new_args($token,$parstack,
+                                                  $safeeval,'name','answer',
+                                                  );
+        $result  = &Apache::edit::rebuild_tag($token);
+    } elsif ($target eq 'web') {
+        &Apache::response::reset_params();
+    }
+    return $result;
+}
+
+sub end_organichint {
+    my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
+    my $result;
+    if ($target eq 'web') {
+        if (!$Apache::lonxml::default_homework_loaded) {
+            &Apache::lonxml::default_homework_load($safeeval);
+        }
+        my $hint_name= &Apache::lonxml::get_param('name',$parstack,$safeeval);
+        &Apache::response::setup_params('organichint',$safeeval);
+        my $partid=$Apache::inputtags::part;
+        my $id=$Apache::inputtags::hint[-1];
+        #id submissions occurred under
+        my $submitid=$Apache::inputtags::response[-1];
+        my $response = $Apache::lonhomework::history{
+                            "resource.$partid.$submitid.submission"};
+        &Apache::lonxml::debug("hintgroup is using $response<br />\n");
+        my (@answers)=&Apache::lonxml::get_param_var('answer',$parstack,$safeeval);
+        my %previous = &Apache::response::check_for_previous($response,$partid,$id);
+        foreach my $answer (@answers) {
+            &Apache::lonxml::debug("submitted a $response for $answer<br \>\n");
+            if ($response eq $answer) {
+               push(@Apache::hint::which,$hint_name);
+               last;
+            }
+        }
+        $result='';
+    } elsif ($target eq 'meta') {
+        $result=&Apache::response::meta_package_write($token->[1]);
+    } elsif ($target eq 'edit') {
+        $result.=&Apache::edit::end_row().&Apache::edit::end_table();
+    }
+    &Apache::response::end_hintresponse();
+    return $result;
+}
+
+
 # a part shows if it is on, if no specific parts are on, then default shows
 sub start_hintpart {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
@@ -649,3 +781,59 @@ sub end_radiobuttonhint {
 }
 1;
 __END__
+
+
+=head1 NAME
+
+Apache::hinttags
+
+=head1 SYNOPSIS
+
+This handler coordinates the delivery of hints to students working on LON-CAPA problems and assignments.
+
+This is part of the LearningOnline Network with CAPA project
+described at http://www.lon-capa.org.
+
+=head1 SUBROUTINES
+
+=over
+
+=item start_hintgroup()
+
+=item end_hintgroup()
+
+=item start_numericalhint()
+
+=item end_numericalhint()
+
+=item start_formulahint()
+
+=item end_formulahint()
+
+=item start_mathhint()
+
+=item end_mathhint()
+
+=item start_customhint()
+
+=item end_customhint()
+
+=item start_stringhint()
+
+=item end_stringhint()
+
+=item start_hintpart()
+
+=item end_hintpart()
+
+=item start_optionhint()
+
+=item end_optionhint()
+
+=item start_radiobuttonhint()
+
+=item end_radiobuttonhint()
+
+=back
+
+=cut
