@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # input  definitons
 #
-# $Id: inputtags.pm,v 1.259 2009/07/08 10:53:08 onken Exp $
+# $Id: inputtags.pm,v 1.271.2.7 2011/05/16 01:02:57 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -53,13 +53,14 @@ package Apache::inputtags;
 use HTML::Entities();
 use strict;
 use Apache::loncommon;
+use Apache::lonhtmlcommon;
 use Apache::lonlocal;
 use Apache::lonnet;
 use LONCAPA;
  
 
 BEGIN {
-    &Apache::lonxml::register('Apache::inputtags',('hiddenline','textfield','textline'));
+    &Apache::lonxml::register('Apache::inputtags',('hiddensubmission','hiddenline','textfield','textline'));
 }
 
 =pod
@@ -174,7 +175,18 @@ sub start_textfield {
     if ($target eq 'web') {
 	$Apache::lonxml::evaluate--;
 	my $partid=$Apache::inputtags::part;
-	my $oldresponse = &HTML::Entities::encode($Apache::lonhomework::history{"resource.$partid.$resid.submission"},'<>&"');
+        my ($oldresponse,$newvariation);
+        if ((($Apache::lonhomework::history{"resource.$partid.type"} eq 'randomizetry') ||
+             ($Apache::lonhomework::type eq 'randomizetry')) &&
+             ($Apache::inputtags::status[-1] eq 'CAN_ANSWER')) {
+            if ($env{'form.'.$partid.'.rndseed'} ne
+                $Apache::lonhomework::history{"resource.$partid.rndseed"}) {
+                $newvariation = 1;
+            }
+        }
+        unless ($newvariation) {
+	    $oldresponse = &HTML::Entities::encode($Apache::lonhomework::history{"resource.$partid.$resid.submission"},'<>&"');
+        }
 	if ($Apache::inputtags::status[-1] eq 'CAN_ANSWER') {
 	    my $cols = &Apache::lonxml::get_param('cols',$parstack,$safeeval);
 	    if ( $cols eq '') { $cols = 80; }
@@ -185,9 +197,10 @@ sub start_textfield {
 	    if ($addchars) {
 		$result.=&addchars('HWVAL_'.$resid,$addchars);
 	    }
-	    &Apache::lonhtmlcommon::add_htmlareafields('HWVAL_'.$resid);
+            my $textareaclass = 'class="LC_richDetectHtml"';
 	    $result.= '<textarea wrap="hard" name="HWVAL_'.$resid.'" id="HWVAL_'.$resid.'" '.
-		"rows=\"$rows\" cols=\"$cols\">".$oldresponse;
+		      'rows="'.$rows.'" cols="'.$cols.'" '.$textareaclass.'>'.
+                      $oldresponse;
 	    if ($oldresponse ne '') {
 
 		#get rid of any startup text if the user has already responded
@@ -329,16 +342,27 @@ sub start_textline {
 		    $maxlength = ' maxlength="'.$size.'"';
 		}
 	    }
-	    my $oldresponse = $Apache::lonhomework::history{"resource.$partid.$id.submission"};
-	    &Apache::lonxml::debug("oldresponse $oldresponse is ".ref($oldresponse));
+            my ($oldresponse,$newvariation);
+            if ((($Apache::lonhomework::history{"resource.$partid.type"} eq 'randomizetry') ||
+                 ($Apache::lonhomework::type eq 'randomizetry')) &&
+                 ($Apache::inputtags::status[-1] eq 'CAN_ANSWER')) {
+                if ($env{'form.'.$partid.'.rndseed'} ne
+                    $Apache::lonhomework::history{"resource.$partid.rndseed"}) {
+                    $newvariation = 1;
+                }
+            }
+            unless ($newvariation) {
+	        $oldresponse = $Apache::lonhomework::history{"resource.$partid.$id.submission"};
+	        &Apache::lonxml::debug("oldresponse $oldresponse is ".ref($oldresponse));
 
-	    if (ref($oldresponse) eq 'ARRAY') {
-		$oldresponse = $oldresponse->[$#Apache::inputtags::inputlist];
-	    }
-	    $oldresponse = &HTML::Entities::encode($oldresponse,'<>&"');
-            $oldresponse =~ s/^\s+//;
-            $oldresponse =~ s/\s+$//;
-            $oldresponse =~ s/\s+/ /g;
+	        if (ref($oldresponse) eq 'ARRAY') {
+		    $oldresponse = $oldresponse->[$#Apache::inputtags::inputlist];
+	        }
+	        $oldresponse = &HTML::Entities::encode($oldresponse,'<>&"');
+                $oldresponse =~ s/^\s+//;
+                $oldresponse =~ s/\s+$//;
+                $oldresponse =~ s/\s+/ /g;
+            }
 	    if ($Apache::lonhomework::type ne 'exam') {
 		my $addchars=&Apache::lonxml::get_param('addchars',$parstack,$safeeval);
 		$result='';
@@ -455,6 +479,48 @@ sub end_hiddenline {
     return "";
 }
 
+sub start_hiddensubmission {
+    my ($target,$token,$tagstack,$parstack,$parser,$safeeval)=@_;
+    my $result = "";
+    my $input_id = &start_input($parstack,$safeeval);
+    if ($target eq 'web') {
+        $Apache::lonxml::evaluate--;
+        if ($Apache::inputtags::status[-1] eq 'CAN_ANSWER') {
+            my $partid=$Apache::inputtags::part;
+            my $id=$Apache::inputtags::response[-1];
+            if ($Apache::lonhomework::type ne 'exam') {
+                my $value = &Apache::lonxml::get_param('value',$parstack,$safeeval);
+                $value = &HTML::Entities::encode($value,'<>&"');
+                $result= '<input type="hidden" name="HWVAL_'.$id.'" value="'.$value.'" />';
+            }
+        }
+    } elsif ($target eq 'edit') {
+        $result=&Apache::edit::tag_start($target,$token);
+        $result.=&Apache::edit::text_arg('Value:','value',$token,'15');
+        $result.=&Apache::edit::end_row();
+        $result.=&Apache::edit::end_table();
+    } elsif ($target eq 'modified') {
+        my $constructtag=&Apache::edit::get_new_args($token,$parstack,
+                                                     $safeeval,'value');
+        if ($constructtag) { $result = &Apache::edit::rebuild_tag($token); }
+    }
+
+    if ( ($target eq 'web' || $target eq 'tex')
+         && $Apache::lonhomework::type eq 'exam'
+         && &needs_exam_box($tagstack)) {
+        $result.=&exam_box($target);
+    }
+    return $result;
+}
+
+sub end_hiddensubmission {
+    my ($target,$token,$tagstack,$parstack,$parser,$safeeval)=@_;
+    if    ($target eq 'web') { $Apache::lonxml::evaluate++; }
+    elsif ($target eq 'edit') { return ('','no'); }
+    &end_input();
+    return "";
+}
+
 =pod
 
 =item file_selector()
@@ -479,87 +545,178 @@ sub file_selector {
     $jspart=~s/\./_/g;
 
     my $result;
-    
-    $result.='<tr><td>';
-    if (($uploadedfiletypes ne '*') || ($maxfilesize)) {
-        if ($uploadedfiletypes ne '*') {
-	    $result.=
-	        &mt('Allowed filetypes: [_1]','<b>'.$uploadedfiletypes.'</b>').'<br />';
-        }
-        if ($maxfilesize) {
-            $result.=&mt('Combined size of files not to exceed: [_1] MB[_2].',
-                         '<b>'.$maxfilesize.'</b>').'<br />';
-        }
-        $result .= '<br />';
+    my $current_files_display = &current_file_submissions($part,$id);
+    my $addfiles;
+    if ($current_files_display) {
+        $result .= &Apache::lonhtmlcommon::row_title(&mt('Currently submitted files')).
+                   $current_files_display.
+                   &Apache::lonhtmlcommon::row_closure();
+        $addfiles = &mt('Submit other file(s)');
+    } else {
+        $addfiles = &mt('Choose file(s) to submit');
+    }
+    $result .= &Apache::lonhtmlcommon::row_title($addfiles);
+    my $constraints;
+    if ($uploadedfiletypes ne '*') {
+	$constraints =
+	    &mt('Allowed filetypes: [_1]','<b>'.$uploadedfiletypes.'</b>').'<br />';
+    }
+    if ($maxfilesize) {
+        $constraints .= &mt('Combined size of all files not to exceed: [_1] MB[_2].',
+                        '<b>'.$maxfilesize.'</b>').'<br />';
+    }
+    if ($constraints) {
+        $result .= $constraints.'<br />';
     }
     if ($which eq 'uploadonly' || $which eq 'both') { 
-	$result.=&mt('Submit a file: (only one file can be uploaded)').
+	$result.=&mt('Submit a file: (only one file per submission)').
 	    ' <br /><input type="file" size="50" name="HWFILE'.
 	    $jspart.'_'.$id.'" /><br />';
-	$result .= &show_past_file_submission($part,$id);
     }
-    if ( $which eq 'both') { 
+    if ( $which eq 'both') {
 	$result.='<br />'.'<strong>'.&mt('OR:').'</strong><br />';
     }
     if ($which eq 'portfolioonly' || $which eq 'both') { 
 	$result.=$extratext.'<a href='."'".'javascript:void(window.open("/adm/portfolio?mode=selectfile&amp;fieldname='.$env{'form.request.prefix'}.'HWPORT'.$jspart.'_'.$id.'","cat","height=600,width=800,scrollbars=1,resizable=1,menubar=2,location=1"))'."'".'>'.
-	    &mt('Select Portfolio Files').'</a><br />'.
+	    &mt('Select Portfolio Files: (one or more files per submission)').'</a><br />'.
 	    '<input type="text" size="50" name="HWPORT'.$jspart.'_'.$id.'" value="" />'.
 	    '<br />';
-	$result .= &show_past_portfile_submission($part,$id);
+
     }
-    $result.='</td></tr>'; 
+    $result.=&Apache::lonhtmlcommon::row_closure(1);
     return $result;
 }
 
-sub show_past_file_submission {
+sub current_file_submissions {
     my ($part,$id) = @_;
-    my $uploadedfile= &HTML::Entities::encode($Apache::lonhomework::history{"resource.$part.$id.uploadedfile"},'<>&"');
-
-    return if (!$uploadedfile);
-
-    my $url=$Apache::lonhomework::history{"resource.$part.$id.uploadedurl"};
-    &Apache::lonxml::extlink($url);
-    &Apache::lonnet::allowuploaded('/adm/essayresponse',$url);
-    my $icon=&Apache::loncommon::icon($url);
-    my $curfile='<a href="'.$url.'"><img src="'.$icon.
-	'" border="0" />'.$uploadedfile.'</a>';
-    return &mt('Currently submitted: [_1]','<tt>'.$curfile.'</tt>');
-
-}
-
-sub show_past_portfile_submission {
-    my ($part,$id) = @_;
-    if ($Apache::lonhomework::history{"resource.$part.$id.portfiles"}!~/[^\s]/){
-	return;
+    my $jspart=$part;
+    $jspart=~s/\./_/g;
+    my $uploadedfile=$Apache::lonhomework::history{"resource.$part.$id.uploadedfile"};
+    my $portfiles=$Apache::lonhomework::history{"resource.$part.$id.portfiles"};
+    return if (($uploadedfile eq '') && ($portfiles !~/[^\s]/));
+    my $header = &Apache::loncommon::start_data_table().
+                 &Apache::loncommon::start_data_table_header_row();
+    if ($Apache::inputtags::status[-1] eq 'CAN_ANSWER') {
+        $header .= '<th>'.&mt('Delete?').'</th>';
     }
-    my (@file_list,@bad_file_list);
-    foreach my $file (split(/\s*,\s*/,&unescape($Apache::lonhomework::history{"resource.$part.$id.portfiles"}))) {
-	my (undef,undef,$domain,$user)=&Apache::lonnet::whichuser();
-	my $url="/uploaded/$domain/$user/portfolio$file";
-	my $icon=&Apache::loncommon::icon($url);
-	push(@file_list,'<a href="'.$url.'"><img src="'.$icon.
-	     '" border="0" />'.$file.'</a>');
-	if (! &Apache::lonnet::stat_file($url)) {
-	    &Apache::lonnet::logthis("bad file is $url");
-	    push(@bad_file_list,'<a href="'.$url.'"><img src="'.$icon.
-		 '" border="0" />'.$file.'</a>');
-	}
+    $header .=   '<th>'.&mt('File').'</th>'.
+                 '<th>'.&mt('Size (MB)').'</th>'.
+                 '<th>'.&mt('Last Modified').'</th>'.
+                 &Apache::loncommon::end_data_table_header_row();
+    my (undef,$crsid,$udom,$uname)=&Apache::lonnet::whichuser();
+    my ($cdom,$cnum) = ($crsid =~ /^($LONCAPA::match_domain)_($LONCAPA::match_courseid)$/);
+    my ($result,$header_shown,%okfiles,%rows,%legacy,@bad_file_list);
+    if ($uploadedfile) {
+        my $url=$Apache::lonhomework::history{"resource.$part.$id.uploadedurl"};
+        my $link = &HTML::Entities::encode($url,'<>&"');
+        my ($path,$name) = ($url =~ m{^(/uploaded/\Q$udom\E/\Q$uname\E/essayresponse.*/)([^/]+)$});
+        my ($status,$hashref,$error) =
+            &current_file_info($url,$link,$name,$path);
+        if ($status eq 'ok') {
+            push(@{$okfiles{$name}},$url);
+            $rows{$url} = $hashref;
+            $legacy{$url} = 1;
+            &Apache::lonxml::extlink($url);
+            &Apache::lonnet::allowuploaded('/adm/essayresponse',$url);
+        } else {
+            push(@bad_file_list,$error);
+        }
+    }
+    if ($portfiles =~ /[^\s]/) {
+        my $prefix = "/uploaded/$udom/$uname/portfolio";
+        foreach my $file (split(/\s*,\s*/,&unescape($portfiles))) {
+            my ($path,$name) = ($file =~ m{^(.*/)([^/]+)$});
+            my $url = $prefix.$path.$name;
+            my $uploadedfile = &HTML::Entities::encode($url,'<>&"');
+            my ($status,$hashref,$error) =
+                &current_file_info($url,$uploadedfile,$name,$path);
+            if ($status eq 'ok') {
+                push(@{$okfiles{$name}},$url);
+                $rows{$url} = $hashref;
+            } else {
+                push(@bad_file_list,$error);
+            }
+        }
+    }
+    my $num = 0;
+    foreach my $name (sort(keys(%okfiles))) {
+        if (ref($okfiles{$name}) eq 'ARRAY') {
+            foreach my $url (@{$okfiles{$name}}) {
+                if (ref($rows{$url}) eq 'HASH') {
+                    my $link = $rows{$url}{link};
+                    my $portfile = $rows{$url}{path}.$rows{$url}{name};
+                    $portfile = &HTML::Entities::encode($portfile,'<>&"');
+                    if ($link) {
+                        my $icon=&Apache::loncommon::icon($url);
+                        unless ($header_shown) {
+                            $result .= $header;
+                            $header_shown = 1;
+                        }
+                        $result.=
+                            &Apache::loncommon::start_data_table_row()."\n";
+                        if ($Apache::inputtags::status[-1] eq 'CAN_ANSWER') {
+                            $result .=
+                                 '<td valign="bottom"><input type="checkbox" name="HWFILE'.$jspart.'_'.$id.'_delete"'.
+                                 ' value="'.$portfile.'" id="HWFILE'.$jspart.'_'.$id.'_'.$num.'_delete" /></td>'."\n";
+                            $num ++;
+                        }
+                        my $showname = $rows{$url}{path}.$name;
+                        if ($legacy{$url}) {
+                            $showname = $name.' '.&mt('not in portfolio');
+                        }
+                        $result .= 
+                            '<td><a href="'.$link.'"><img src="'.$icon.
+                            '" border="0" alt="" />'.$showname.'</a></td>'."\n".
+                            '<td align="right" valign="bottom">'.$rows{$url}{size}.'</td>'."\n".
+                            '<td align="right" valign="bottom">'.$rows{$url}{lastmodified}.'</td>'."\n".
+                            &Apache::loncommon::end_data_table_row();
+                    }
+                }
+            }
+        }
+    }
+    if ($header_shown) {
+        $result .= &Apache::loncommon::end_data_table().
+                   '<br /><span class="LC_warning">'.
+                   &mt('Exclude existing file(s) from grading by checking the "Delete?" checkbox(es) and clicking "Submit Answer"').'</span>';
     }
-    my $files = '<span class="LC_filename">'.
-	join('</span>, <span class="LC_filename">',@file_list).
-	'</span>';
-    my $result = &mt("Portfolio files previously selected: [_1]",$files);
     if (@bad_file_list) {
-	my $bad_files = '<span class="LC_filename">'.
-	    join('</span>, <span class="LC_filename">',@bad_file_list).
-	    '</span>';
-	$result.='<p><span class="LC_error">'
-                .&mt("These file(s) don't exist: [_1]",$bad_files)
-                .'</span></p>';
+        my $bad_files = '<span class="LC_filename">'.
+            join('</span>, <span class="LC_filename">',@bad_file_list).
+            '</span>';
+        $result.='<p class="LC_error">'.
+                 &mt("These file(s) don't exist: [_1]",$bad_files).
+                 '</p>';
     }
     return $result;
+}
 
+sub current_file_info {
+    my ($url,$uploadedfile,$name,$path) = @_;
+    my ($status,$error,%info);
+    my @stat = &Apache::lonnet::stat_file($url);
+    if ((@stat) && ($stat[0] ne 'no_such_dir')) {
+        my ($lastmod,$size);
+        if ($stat[9] =~ /^\d+$/) {
+            $lastmod = &Apache::lonlocal::locallocaltime($stat[9]);
+        }
+        $size = $stat[7]/(1024*1024);
+        $size = sprintf("%.3f",$size);
+        %info = (
+                    link         => $uploadedfile,
+                    name         => $name,
+                    path         => $path,
+                    size         => $size,
+                    lastmodified => $lastmod,
+                );
+        $status = 'ok';
+    } else {
+        &Apache::lonnet::logthis("bad file is $url");
+        my $icon=&Apache::loncommon::icon($url);
+        $error = '<a href="'.$url.'"><img src="'.$icon.
+                 '" border="0" />'.$uploadedfile.'</a>';
+    }
+    return ($status,\%info,$error);
 }
 
 sub valid_award {
@@ -570,11 +727,14 @@ sub valid_award {
 			       'UNIT_INVALID_STUDENT', 'UNIT_IRRECONCIBLE',
 			       'UNIT_FAIL', 'NO_UNIT',
 			       'UNIT_NOTNEEDED', 'WANTED_NUMERIC',
-			       'BAD_FORMULA', 'INTERNAL_ERROR', 'SIG_FAIL', 'INCORRECT', 
+			       'BAD_FORMULA', 'NOT_FUNCTION', 'WRONG_FORMAT', 
+			       'INTERNAL_ERROR', 'SIG_FAIL', 'INCORRECT', 
 			       'MISORDERED_RANK', 'INVALID_FILETYPE',
-                               'EXCESS_FILESIZE', 'DRAFT',
-			       'SUBMITTED', 'ASSIGNED_SCORE',
-			       'APPROX_ANS', 'EXACT_ANS','COMMA_FAIL') {
+                               'EXCESS_FILESIZE', 'FILENAME_INUSE', 
+			       'DRAFT', 'SUBMITTED', 'SUBMITTED_CREDIT', 
+                               'ANONYMOUS', 'ANONYMOUS_CREDIT',
+                               'ASSIGNED_SCORE', 'APPROX_ANS',
+			       'EXACT_ANS','COMMA_FAIL') {
 	if ($award eq $possibleaward) { return 1; }
     }
     return 0;
@@ -585,9 +745,12 @@ sub valid_award {
 		  'TOO_LONG',
 		  'UNIT_INVALID_INSTRUCTOR', 'UNIT_INVALID_STUDENT',
 		  'UNIT_IRRECONCIBLE', 'UNIT_FAIL', 'NO_UNIT',
-		  'UNIT_NOTNEEDED', 'WANTED_NUMERIC', 'BAD_FORMULA', 'INTERNAL_ERROR',
+		  'UNIT_NOTNEEDED', 'WANTED_NUMERIC', 'BAD_FORMULA',  'NOT_FUNCTION', 
+		  'WRONG_FORMAT', 'INTERNAL_ERROR',
 		  'COMMA_FAIL', 'SIG_FAIL', 'INCORRECT', 'MISORDERED_RANK',
-		  'INVALID_FILETYPE', 'EXCESS_FILESIZE', 'DRAFT', 'SUBMITTED',
+		  'INVALID_FILETYPE', 'EXCESS_FILESIZE', 'FILENAME_INUSE', 
+                  'DRAFT', 'SUBMITTED',
+                  'SUBMITTED_CREDIT', 'ANONYMOUS', 'ANONYMOUS_CREDIT',
                   'ASSIGNED_SCORE', 'APPROX_ANS', 'EXACT_ANS');
     my $i=0;
     my %fwd_awards = map { ($_,$i++) } @awards;
@@ -611,7 +774,7 @@ sub hide_award {
 	return 1;
     }
     if ($award =~
-	/^(?:EXACT_ANS|APPROX_ANS|SUBMITTED|ASSIGNED_SCORE|INCORRECT)/) {
+	/^(?:EXACT_ANS|APPROX_ANS|SUBMITTED|SUBMITTED_CREDIT|ANONYMOUS|ANONYMOUS_CREDIT|ASSIGNED_SCORE|INCORRECT)/) {
 	return 1;
     }
     return 0;
@@ -817,6 +980,16 @@ sub decideoutput {
         $message = &mt('Submission won\'t be graded. The combined size of submitted files exceeded the amount allowed.');
         $css_class=$possible_class{'not_charged_try'};
         $button=1;
+    } elsif ($award eq 'FILENAME_INUSE') {
+        $message = &mt('You have already uploaded a file with that filename.');
+        if ($target eq 'tex') {
+            $message.= "\\\\\n";
+        } else {
+            $message .= '<br />';
+        }
+        $message .= &mt('Please use a different file name.');
+        $css_class=$possible_class{'not_charged_try'};
+        $button=1;
     } elsif ($award eq 'INVALID_FILETYPE') {
 	$message = &mt("Submission won't be graded. The type of file submitted is not allowed.");
 	$css_class=$possible_class{'not_charged_try'};
@@ -860,6 +1033,14 @@ sub decideoutput {
         if ($target ne 'tex') {$message.=&Apache::loncommon::help_open_topic('Formula_Answers')};
 	$css_class=$possible_class{'not_charged_try'};
 	$button=1;
+    } elsif ($award eq 'NOT_FUNCTION') {
+        $message = &mt("Not a function").'.';
+        $css_class=$possible_class{'not_charged_try'};
+        $button=1;
+    } elsif ($award eq 'WRONG_FORMAT') {
+        $message = &mt("Wrong format").'.';
+        $css_class=$possible_class{'not_charged_try'};
+        $button=1;
     } elsif ($award eq 'INTERNAL_ERROR') {
         $message = &mt("An internal error occurred while processing your answer. Please try again later.");
         $css_class=$possible_class{'not_charged_try'};
@@ -872,6 +1053,17 @@ sub decideoutput {
 	$message = &mt("Your submission has been recorded.");
 	$css_class=$possible_class{'no_grade'};
 	$button=1;
+    } elsif ($award eq 'SUBMITTED_CREDIT') {
+        $message = &mt("Your submission has been recorded, and credit awarded.");
+        $css_class=$possible_class{'correct'};
+        $button=1;
+    } elsif ($award eq 'ANONYMOUS') {
+        $message = &mt("Your anonymous submission has been recorded.");
+        $css_class=$possible_class{'no_grade'};
+        $button=1;
+    } elsif ($award eq 'ANONYMOUS_CREDIT') {
+        $message = &mt("Your anonymous submission has been recorded, and credit awarded.");
+        $css_class=$possible_class{'correct'};
     } elsif ($award eq 'DRAFT') {
 	$message = &mt("Copy saved but not submitted.");
 	$css_class=$possible_class{'not_charged_try'};
@@ -1035,6 +1227,18 @@ sub setgradedata {
 	    $Apache::lonhomework::results{"resource.$id.solved"} =
 		$solvemsg;
 	    $Apache::lonhomework::results{"resource.$id.awarded"} = '1';
+        } elsif ( $award eq 'SUBMITTED_CREDIT' ) {
+            $Apache::lonhomework::results{"resource.$id.tries"} =
+                $Apache::lonhomework::history{"resource.$id.tries"} + 1;
+            $Apache::lonhomework::results{"resource.$id.solved"} =
+                'credit_attempted';
+            $Apache::lonhomework::results{"resource.$id.awarded"} = '1';
+        }  elsif ( $award eq 'ANONYMOUS_CREDIT' ) {
+            $Apache::lonhomework::results{"resource.$id.tries"} =
+                $Apache::lonhomework::history{"resource.$id.tries"} + 1;
+            $Apache::lonhomework::results{"resource.$id.solved"} =
+                'credit_attempted';
+            $Apache::lonhomework::results{"resource.$id.awarded"} = '1';
 	} elsif ( $award eq 'INCORRECT' ) {
 	    $Apache::lonhomework::results{"resource.$id.tries"} =
 		$Apache::lonhomework::history{"resource.$id.tries"} + 1;
@@ -1049,6 +1253,11 @@ sub setgradedata {
 		$Apache::lonhomework::history{"resource.$id.tries"} + 1;
 	    $Apache::lonhomework::results{"resource.$id.solved"} =
 		'ungraded_attempted';
+        }  elsif ( $award eq 'ANONYMOUS' ) {
+            $Apache::lonhomework::results{"resource.$id.tries"} =
+                $Apache::lonhomework::history{"resource.$id.tries"} + 1;
+            $Apache::lonhomework::results{"resource.$id.solved"} =
+                'ungraded_attempted';
 	} elsif ( $award eq 'DRAFT' ) {
 	    $Apache::lonhomework::results{"resource.$id.solved"} = '';
 	} elsif ( $award eq 'NO_RESPONSE' ) {
@@ -1108,6 +1317,14 @@ sub setgradedata {
     if ($award eq 'SUBMITTED') {
 	&Apache::response::add_to_gradingqueue();
     }
+    if (($Apache::lonhomework::type eq 'anonsurvey') ||
+        ($Apache::lonhomework::type eq 'anonsurveycred') ||
+        ($Apache::lonhomework::type eq 'randomizetry')) {
+        $Apache::lonhomework::results{"resource.$id.type"} = $Apache::lonhomework::type;
+    }
+    if ($Apache::lonhomework::type eq 'randomizetry') {
+        $Apache::lonhomework::results{"resource.$id.rndseed"} = $env{'form.'.$id.'.rndseed'};
+    }
 }
 
 sub find_which_previous {
@@ -1220,12 +1437,7 @@ sub get_grade_messages {
     if ( $tries eq '' ) { $tries = '0'; }
     if ( $maxtries eq '' ) { $maxtries = '2'; } 
     if ( $maxtries eq 'con_lost' ) { $maxtries = '0'; } 
-    my $tries_text=&mt('Tries');
-    if ( $Apache::lonhomework::type eq 'survey' ||
-	 $Apache::lonhomework::parsing_a_task) {
-	$tries_text=&mt('Submissions');
-    }
-
+    my $tries_text= &get_tries_text();;
     if ($showbutton) {
 	if ($target eq 'tex') {
 	    if ($env{'request.state'} ne "construct"
@@ -1237,7 +1449,7 @@ sub get_grade_messages {
 		$trystr = '\vskip 0 mm ';
 	    }
 	} else {
-	    $trystr = '<td><span class="LC_nobreak">'.$tries_text." $tries";
+	    $trystr = '<td><span class="LC_nobreak">'.&mt($tries_text)." $tries";
 	    if ($Apache::lonhomework::parsing_a_task) {
 	    } elsif($env{'request.state'} ne 'construct') {
 		$trystr.="/$maxtries";
@@ -1289,11 +1501,9 @@ sub gradestatus {
 	if ( $showbutton ) { 
 	    if ($target ne 'tex') {
 		$button = 
-		    '<input 
-                          onmouseup="javascript:setSubmittedPart(\''.$id.'\')"
-                           onsubmit="javascript:setSubmittedPart(\''.$id.'\')"
-                        type="submit" name="submit_'.$id.'"
-                         value="'.&mt('Submit Answer').'" />';
+            '<input onmouseup="javascript:setSubmittedPart(\''.$id.'\');this.form.action+=\'#'.&escape($id).'\';"
+                    type="submit" name="submit_'.$id.'"
+                    value="'.&mt('Submit Answer').'" />';
 	    }
 	}
 
@@ -1323,14 +1533,22 @@ sub previous_tries {
 
     my $count;
     my %count_lookup;
+    my $lastrndseed;
 
     foreach my $i (1..$Apache::lonhomework::history{'version'}) {
 	my $prefix = $i.":resource.$id";
-
+        my $is_anon; 
+        if (defined($env{'form.grade_symb'})) {
+            if (($Apache::lonhomework::history{"$prefix.type"} eq 'anonsurvey') || 
+                ($Apache::lonhomework::history{"$prefix.type"} eq 'anonsurveycred')) {
+                $is_anon = 1;
+            }
+        }
 	next if (!exists($Apache::lonhomework::history{"$prefix.award"}));
 	$count++;
 	$count_lookup{$i} = $count;
-	
+        my $curr_rndseed = $Apache::lonhomework::history{"$prefix.rndseed"};
+
 	my ($previousmsg,$latemessage,$message,$trystr);
 
 	($previousmsg,$latemessage,$message,$trystr) =
@@ -1348,10 +1566,25 @@ sub previous_tries {
 		) {
 		
                 my $txt_correct = &mt('Correct');
+                my $awarded = $Apache::lonhomework::history{"$prefix.awarded"};
+                if ($awarded < 1 && $awarded > 0) {
+                    $txt_correct=&mt('Partially Correct');
+                } elsif ($awarded < 1) {
+                    if ($awarded eq '') {
+                        $txt_correct='';
+                    } else {
+                        $txt_correct=&mt('Incorrect');
+                    }
+                }
 		$message =~ s{(<td.*?>)(.*?)(</td>)}
                              {$1 <strong>$txt_correct</strong>. $3}s;
 	    }
             my $trystr = "(".&mt('Try [_1]',$Apache::lonhomework::history{"$prefix.tries"}).")";
+            if ($curr_rndseed || $lastrndseed) {
+                if ($curr_rndseed ne $lastrndseed) {
+                    $trystr .= '<br /><span style="color: green; white-space: nowrap; font-style: italic; font-weight: bold; font-size: 80%;">'.&mt('New problem variation this try.').'</span>';
+                }
+            }
 	    $message =~ s{(</td>)}{ $trystr $1};
 	}
 	my ($class) = ($message =~ m{<td.*class="([^"]*)"}); #"
@@ -1371,12 +1604,17 @@ sub previous_tries {
 		    $submission = 
 			$Apache::lonhomework::history{"$prefix.submission"};
 		}
-		$output.='<td>'.$submission.'</td>';
+                if ($is_anon) {
+                    $output.='<td>'.&mt('(only shown to submitter)').'</td>';
+                } else {
+		    $output.='<td>'.$submission.'</td>';
+                }
 	    } else {
 		$output.='<td></td>';
 	    }
 	}
 	$output.=&Apache::loncommon::end_data_table_row()."\n";
+        $lastrndseed = $curr_rndseed;
     }
     return if ($output eq '');
     my $headers = 
@@ -1389,8 +1627,9 @@ sub previous_tries {
     $output.='<br /><form action=""><center><input type="button" name="close" value="'.&mt('Close Window').'" onClick="window.close()" /></center></form>';
 
     my $windowopen=&Apache::lonhtmlcommon::javascript_docopen();
+    my $tries_text = &get_tries_text('link');
     my $start_page =
-	&Apache::loncommon::start_page('Previous Tries', undef,
+	&Apache::loncommon::start_page($tries_text, undef,
 				       {'only_body'      => 1,
 					'bgcolor'        => '#FFFFFF',
 					'js_ready'       => 1,
@@ -1405,12 +1644,34 @@ sub previous_tries {
 // <![CDATA[
     function $function_name() {newWindow=open('','new_W','width=500,height=500,scrollbars=1,resizable=yes');newWindow.$windowopen;newWindow.document.writeln('$start_page $output $end_page');newWindow.document.close();newWindow.focus()}
 // ]]>
-</script><a href=\"javascript:$function_name();void(0);\">".&mt("Previous Tries")."</a><br />";
+</script><a href=\"javascript:$function_name();void(0);\">".&mt($tries_text)."</a><br />";
     #use Data::Dumper;
     #&Apache::lonnet::logthis(&Dumper(\%Apache::inputtags::submission_display));
     return $result;
 }
 
+sub get_tries_text {
+    my ($context) = @_;
+    my $tries_text;
+    if ($context eq 'link') {
+        $tries_text = 'Previous Tries';
+    } else {
+        $tries_text = 'Tries';
+    }
+    if ( $Apache::lonhomework::type eq 'survey' ||
+         $Apache::lonhomework::type eq 'surveycred' ||
+         $Apache::lonhomework::type eq 'anonsurvey' ||
+         $Apache::lonhomework::type eq 'anonsurveycred' ||
+         $Apache::lonhomework::parsing_a_task) {
+        if ($context eq 'link') {
+            $tries_text = 'Previous Submissions';
+        } else {
+            $tries_text = 'Submissions';
+        }
+    }
+    return $tries_text;
+}
+
 1;
 __END__
 
