@@ -1,7 +1,7 @@
 # LearningOnline Network with CAPA
 # option list style responses
 #
-# $Id: optionresponse.pm,v 1.162 2010/02/05 23:02:39 www Exp $
+# $Id: optionresponse.pm,v 1.173 2010/12/19 00:52:00 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -103,7 +103,7 @@ sub start_foilgroup {
   my $result='';
   %Apache::response::foilgroup=();
   $Apache::optionresponse::conceptgroup=0;
-  &Apache::response::pushrandomnumber();
+  &Apache::response::pushrandomnumber(undef,$target);
   if ($target eq 'edit') {
     my $optionlist="<option></option>\n";
     my $option;
@@ -137,7 +137,10 @@ ENDTABLE
        }
        $result.='>'.$option.'</option>';
     }
-    $result.='</select></label>';  
+    $result.='</select></label>';
+    $result.=&Apache::edit::checked_arg('Checkbox options:','checkboxoptions',
+                                         [ ['nochoice','Don\'t show option list'] ]
+                                         ,$token).'</td>';
     $result.= &Apache::edit::end_row();
     $result.= &Apache::edit::start_spanning_row();
     $result.= $insertlist.'<br />';
@@ -162,7 +165,7 @@ ENDTABLE
       $optchanged=1;
     }
     my $rebuildtag = &Apache::edit::get_new_args($token,$parstack,$safeeval,
-						 'texoptions','checkboxvalue');
+						 'texoptions','checkboxvalue','checkboxoptions');
     if ($optchanged || $rebuildtag ) {
       $result = "<foilgroup options=\"(";
       foreach my $option (@options) {
@@ -173,14 +176,14 @@ ENDTABLE
       chop $result;
       $result.=')" ';
       $result .= 'texoptions="'.$token->[2]{'texoptions'}.'" ';
+      $result .= 'checkboxoptions="'.$token->[2]{'checkboxoptions'}.'" ';
       $result .= 'checkboxvalue="'.$token->[2]{'checkboxvalue'}.'"';
       $result .= '>';
     } # else nothing changed so just use the default mechanism
   }
   if ($target eq 'tex' and $Apache::lonhomework::type ne 'exam') {
     if($env{'form.pdfFormFields'} ne 'yes') {
-      $result .= ' \renewcommand{\labelenumi}{\Alph{enumi}.}
-                   \begin{enumerate} ';
+      $result .= ' \begin{itemize} ';
     } else {
       $result .= "\\\\";
     }
@@ -203,13 +206,14 @@ sub end_foilgroup {
     my $TeXlayout=&Apache::lonxml::get_param('TeXlayout',$parstack,$safeeval,
 					     -2,0);
     my $checkboxvalue=&Apache::lonxml::get_param('checkboxvalue',$parstack,$safeeval);
+    my $checkboxchoices=(&Apache::lonxml::get_param('checkboxoptions',$parstack,$safeeval) ne 'nochoice');
     if ($target eq 'tex' && $tex_option_switch eq 'nochoice') {@opt=();}
     &Apache::lonxml::debug("Options are $#opt");
     my $max = &Apache::lonxml::get_param('max',$parstack,$safeeval,'-2');
     my $randomize = &Apache::lonxml::get_param('randomize',$parstack,
 					       $safeeval,'-2');
     if ($target eq 'web' || $target eq 'tex') {
-      $result.=&displayfoils($target,$max,$randomize,$TeXlayout,$checkboxvalue,@opt);
+      $result.=&displayfoils($target,$max,$randomize,$TeXlayout,$checkboxvalue,$checkboxchoices,@opt);
       $Apache::lonxml::post_evaluate=0;
     } elsif ( $target eq 'answer') {
       $result.=&displayanswers($max,$randomize,@opt);
@@ -258,10 +262,24 @@ sub end_foilgroup {
 	$Apache::lonhomework::results{"resource.$part.$id.submission"}=
 	    $responsestr;
 	$Apache::lonhomework::results{"resource.$part.$id.submissiongrading"}=$gradestr;
-	
-	if ($Apache::lonhomework::type eq 'survey') {
+        if ($Apache::lonhomework::type eq 'randomizetry') {
+            $Apache::lonhomework::results{"resource.$part.$id.foilorder"} = &Apache::lonnet::array2str(@whichopt);
+        }
+	if (($Apache::lonhomework::type eq 'survey') ||
+            ($Apache::lonhomework::type eq 'surveycred') ||
+            ($Apache::lonhomework::type eq 'anonsurvey') ||
+            ($Apache::lonhomework::type eq 'anonsurveycred')) {
 	    if ($ignored == 0) {
-		my $ad=$Apache::lonhomework::results{"resource.$part.$id.awarddetail"}='SUBMITTED';
+                my $ad;
+                if ($Apache::lonhomework::type eq 'anonsurveycred') {
+                    $ad=$Apache::lonhomework::results{"resource.$part.$id.awarddetail"}='ANONYMOUS_CREDIT';
+                } elsif ($Apache::lonhomework::type eq 'anonsurvey') {
+                    $ad=$Apache::lonhomework::results{"resource.$part.$id.awarddetail"}='ANONYMOUS';
+                } elsif ($Apache::lonhomework::type eq 'surveycred') {
+                    $ad=$Apache::lonhomework::results{"resource.$part.$id.awarddetail"}='SUBMITTED_CREDIT';
+                } else {
+		    $ad=$Apache::lonhomework::results{"resource.$part.$id.awarddetail"}='SUBMITTED';
+                }
 		&Apache::response::handle_previous(\%previous,$ad);
 	    } elsif ($wrong==0 && $right==0) {
 	    } else {
@@ -315,7 +333,7 @@ sub end_foilgroup {
   }
   if ($target eq 'tex' and $Apache::lonhomework::type ne 'exam') {
     if($env{'form.pdfFormFields'} ne 'yes') {
-      $result .= '\end{enumerate}';
+      $result .= '\end{itemize}'; 
     } else {
       $result .= "\\\\";
     }
@@ -403,7 +421,7 @@ sub check_for_invalid {
 }
 
 sub displayfoils {
-  my ($target,$max,$randomize,$TeXlayout,$checkboxvalue,@opt)=@_;
+  my ($target,$max,$randomize,$TeXlayout,$checkboxvalue,$checkboxchoices,@opt)=@_;
   if (!defined(@{ $Apache::response::foilgroup{'names'} })) {return;}
   my @names = @{ $Apache::response::foilgroup{'names'} };
   my @truelist;
@@ -423,7 +441,11 @@ sub displayfoils {
     my $temp=1;
     foreach $name (@whichopt) {
 	my $text=$Apache::response::foilgroup{$name.'.text'};
-	my %lastresponse=&Apache::lonnet::str2hash($Apache::lonhomework::history{"resource.$part.$id.submission"});
+        my $lastresp;
+        unless ((($Apache::lonhomework::history{"resource.$part.type"} eq 'anonsurvey') || ($Apache::lonhomework::history{"resource.$part.type"} eq 'anonsurveycred')) && (defined($env{'form.grade_symb'}))) {
+            $lastresp = $Apache::lonhomework::history{"resource.$part.$id.submission"};
+        }
+	my %lastresponse=&Apache::lonnet::str2hash($lastresp);
 	my $lastopt=$lastresponse{$name};
 	if ($text!~/^\s*$/) { $break='<br />'; }
 	$result.=$break;
@@ -436,7 +458,9 @@ sub displayfoils {
 		    $text='<b>'.$value.':</b> '.$text;
 		}
 	    } else {
-		$text='&#149;'.$text;
+                if (@whichopt > 1) {
+                    $text='&#149;'.$text;
+                }
 	    }
 	    $result.=$text."\n";
 	}
@@ -447,12 +471,25 @@ sub displayfoils {
     }
   } else {
     my $temp=1;
-    my %lastresponse=&Apache::lonnet::str2hash($Apache::lonhomework::history{"resource.$part.$id.submission"});
+    my %lastresponse;
+    my $newvariation;
+    if ((($Apache::lonhomework::history{"resource.$part.type"} eq 'randomizetry') ||
+        ($Apache::lonhomework::type eq 'randomizetry')) &&
+        ($Apache::inputtags::status[-1] eq 'CAN_ANSWER')) {
+        if ($env{'form.'.$part.'.rndseed'} ne
+            $Apache::lonhomework::history{"resource.$part.rndseed"}) {
+            $newvariation = 1;
+        }
+    }
+    unless ($newvariation) {
+        %lastresponse=&Apache::lonnet::str2hash($Apache::lonhomework::history{"resource.$part.$id.submission"});
+    }
     my $internal_counter=$Apache::lonxml::counter;
     my $checkboxopt=&check_box_opt($target,$checkboxvalue,@opt);
     if ($checkboxopt) {
-       $result.='<br />'.&mt('Choices: ').'<b>'.$opt[0].','.$opt[1].'</b>. '.
-                &mt('Select all that are <b>[_1]</b>.',$checkboxopt);
+       $result.='<br />'.
+                ($checkboxchoices?&mt('Choices: ').'<b>'.$opt[0].','.$opt[1].'</b>. ':'').
+                 &mt('Select all that are <b>[_1]</b>.',$checkboxopt);
     }
     foreach $name (@whichopt) {
       my $text=$Apache::response::foilgroup{$name.'.text'};
@@ -476,14 +513,16 @@ sub displayfoils {
 	  my $escopt=&HTML::Entities::encode($option,'\'"&<>');
           if ($option eq $lastopt) {
               if ($target eq 'tex' && $env{'form.pdfFormFields'} eq 'yes'
-                  && $Apache::inputtags::status[-1] eq 'CAN_ANSWER') {
+                  && $Apache::inputtags::status[-1] eq 'CAN_ANSWER'
+                  && $Apache::lonhomework::type ne 'exam') {
                   $optionlist .= &Apache::lonxml::print_pdf_add_combobox_option($option);
               } else {
                   $optionlist.="<option value='".$escopt."' selected=\"selected\">$option</option>\n";
               }
           } else {
               if ($target eq 'tex' && $env{'form.pdfFormFields'} eq 'yes'
-                  && $Apache::inputtags::status[-1] eq 'CAN_ANSWER') {
+                  && $Apache::inputtags::status[-1] eq 'CAN_ANSWER'
+                  && $Apache::lonhomework::type ne 'exam') {
                   $optionlist .= &Apache::lonxml::print_pdf_add_combobox_option($option);
               } else {
                   $optionlist.="<option value='".$escopt."'>$option</option>\n";
@@ -525,7 +564,9 @@ sub displayfoils {
 	  }
 	  if ($text=~s|<drawoptionlist\s*/>|$optionlist|) {
 	      if ($Apache::lonhomework::type ne 'exam') {
-		  $text='&#149;'.$text;
+                  if (@whichopt > 1) {  
+                      $text='&#149;'.$text;
+                  }
 	      }
 	  } else {
 	      if ($Apache::lonhomework::type ne 'exam') {
@@ -565,13 +606,14 @@ sub displayfoils {
 	      }
 	  }
 	  if ($Apache::lonhomework::type eq 'exam') {
-	      $result.='\vskip -1 mm\noindent\begin{enumerate}\item[\textbf{'.
-		  $internal_counter.'}.]'.&bubbles(\@alphabet,\@opt).
-		  '\end{enumerate} \vskip -8 mm \strut ';
+	      $result.='\vskip -1 mm\noindent';
+              $result.= '\textbf{'. $internal_counter.'}. \vskip -3mm'.&bubbles(\@alphabet,\@opt).
+		                 ' \strut ';
 	      $internal_counter++;
 	  }
           if ($target eq 'tex' && $env{'form.pdfFormFields'} eq 'yes'
-              && $Apache::inputtags::status[-1] eq 'CAN_ANSWER') {
+              && $Apache::inputtags::status[-1] eq 'CAN_ANSWER'
+              && $Apache::lonhomework::type ne 'exam') {
               $text =~ s/\\item//m;
               $result .= " $optionlist ". &Apache::lonxml::print_pdf_end_combobox($text).'\strut \\\\';
               $temp++;
@@ -582,9 +624,12 @@ sub displayfoils {
   }
 
   if ($target eq 'web') {
-      &Apache::response::setup_prior_tries_hash(\&Apache::rankresponse::format_prior_answer,
-						[\@whichopt,
-						 'submissiongrading']);
+      my $data = [\@whichopt,'submissiongrading'];
+      my $questiontype;
+      if ($Apache::lonhomework::type eq 'randomizetry') {
+          $questiontype = $Apache::lonhomework::type,
+      }
+      &Apache::response::setup_prior_tries_hash(\&Apache::rankresponse::format_prior_answer,$data,$questiontype);
   }
 
   if ($target ne 'tex') {
@@ -673,12 +718,12 @@ sub bubbles {
 
 	$current_length += (length($opt[$ind])+length($alphabet[$ind])+4)*2;
 	if ($current_length<($textwidth-$leftmargin) and $ind!=$number_of_bubbles) {
-	    $line.='\hskip -1 mm {\small \textbf{'.$alphabet[$ind].'}}$\bigcirc$\hskip -1 mm & \hskip -3 mm {\small '.$opt[$ind].'} & ';
+	    $line.='\hskip 4 mm {\small \textbf{'.$alphabet[$ind].'}}$\bigcirc$\hskip -1 mm & \hskip -3 mm {\small '.$opt[$ind].'} & ';
 	    $head.='lr';
 	} else {
 	    $line=~s/\&\s*$//;
-	    $result.='\vskip -2 mm\noindent\setlength{\tabcolsep}{2 mm}\begin{tabular}{'.$head.'}'.$line.'\\\\\end{tabular}\vskip 0 mm';
-	    $line = '\hskip -1 mm {\small \textbf{'.$alphabet[$ind].'}}$\bigcirc$\hskip -1 mm & \hskip -3 mm {\small '.$opt[$ind].'} & ';;
+	    $result.='\vskip -1 mm\noindent\setlength{\tabcolsep}{2 mm}\renewcommand{\arraystretch}{1.25}\begin{tabular}{'.$head.'}'.$line.'\\\\\end{tabular}\vskip 0 mm';
+	    $line = '\hskip 4 mm {\small \textbf{'.$alphabet[$ind].'}}$\bigcirc$\hskip -1 mm & \hskip -3 mm {\small '.$opt[$ind].'} & ';;
 	    $head ='lr';
 	    $current_length = (length($opt[$ind])+length($alphabet[$ind]))*2;
 	}
