@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler for displaying the course catalog interface
 #
-# $Id: coursecatalog.pm,v 1.53.4.7 2010/10/07 14:45:04 raeburn Exp $
+# $Id: coursecatalog.pm,v 1.58.4.7 2011/01/25 09:46:43 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -87,8 +87,9 @@ sub handler {
     }
     &Apache::loncommon::extract_categories($cathash,\@cats,\@trails,\%allitems,
                                            \%idx,\@jsarray,$subcats);
+    my ($numtitles,@codetitles);
     if ($env{'form.coursenum'} ne '' && &user_is_known()) {
-        &course_details($r,$codedom,$formname,$domdesc,\@trails,\%allitems);
+        &course_details($r,$codedom,$formname,$domdesc,\@trails,\%allitems,\@codetitles);
     } else {
         my ($catlinks,$has_subcats,$selitem) = &category_breadcrumbs($codedom,@cats);
         my $catjs = <<"ENDSCRIPT";
@@ -114,12 +115,12 @@ function setCourseId(caller) {
 
 ENDSCRIPT
         $catjs .= &courselink_javascript(); 
-        my $numtitles;
         if ($env{'form.currcat_0'} eq 'instcode::0') {
             $numtitles = &instcode_course_selector($r,$codedom,$formname,$domdesc,
-                                                   $catlinks,$catjs);
+                                                   $catlinks,$catjs,\@codetitles);
             if ($env{'form.state'} eq 'listing') {
-                $r->print(&print_course_listing($codedom,$numtitles));
+                $r->print(&print_course_listing($codedom,$numtitles,undef,undef,undef,
+                                                \@codetitles));
             }
         } else {
             my (%add_entries);
@@ -164,7 +165,7 @@ ENDJS
                           $display_button.'" /></form><br /><br />');
             }
             if ($env{'form.state'} eq 'listing') {
-                $r->print(&print_course_listing($codedom,undef,\@trails,\%allitems,$subcats));
+                $r->print(&print_course_listing($codedom,undef,\@trails,\%allitems,$subcats,\@codetitles));
             }
         }
     }
@@ -173,7 +174,7 @@ ENDJS
 }
 
 sub course_details {
-    my ($r,$codedom,$formname,$domdesc,$trails,$allitems) = @_;
+    my ($r,$codedom,$formname,$domdesc,$trails,$allitems,$codetitles) = @_;
     my $output;
     my %add_entries = (topmargin    => "0",
                        marginheight => "0",);
@@ -190,7 +191,7 @@ sub course_details {
                 ({href=>"/adm/coursecatalog",
                   text=>"Course/Community Catalog"});
     }
-    my $brtextone = 'Course listing';
+    my $brtextone = 'Course listing'; 
     my $brtexttwo = 'Course details';
     if ($env{'form.currcat_0'} eq 'communities::0') {
         $brtextone = 'Community listing';
@@ -200,7 +201,6 @@ sub course_details {
              ({href=>"javascript:document.$formname.submit()",
               text=>$brtextone},
              {text=>$brtexttwo});
-    $r->print(&Apache::lonhtmlcommon::breadcrumbs('Course/Community Catalog'));
     $r->print('<br />');
     if ($env{'form.currcat_0'} eq 'communities::0') {
         $r->print(&mt('Detailed community information:'));
@@ -208,7 +208,7 @@ sub course_details {
         $r->print(&mt('Detailed course information:'));
     }
     $r->print('<br /><br />'.
-              &print_course_listing($codedom,undef,$trails,$allitems).
+              &print_course_listing($codedom,undef,$trails,$allitems,undef,$codetitles).
               '<br /><br />');
     $r->print('<form name="'.$formname.'" method="post" action="/adm/coursecatalog">'.
               '<a href = "javascript:document.coursecatalog.submit()">');
@@ -250,10 +250,9 @@ END
 }
 
 sub instcode_course_selector {
-    my ($r,$codedom,$formname,$domdesc,$catlinks,$catjs) = @_;
+    my ($r,$codedom,$formname,$domdesc,$catlinks,$catjs,$codetitles) = @_;
     my %coursecodes = ();
     my %codes = ();
-    my @codetitles = ();
     my %cat_titles = ();
     my %cat_order = ();
     my %cat_items;
@@ -263,7 +262,7 @@ sub instcode_course_selector {
                        marginheight => "0",);
     my ($jscript,$totcodes,$numtitles,$lasttitle) = 
         &Apache::courseclassifier::instcode_selectors_data($codedom,$formname,
-                           \%cat_items,\@codetitles,\%cat_titles,\%cat_order);
+                           \%cat_items,$codetitles,\%cat_titles,\%cat_order);
     my $js = '<script type"text/javascript">'."\n$jscript\n$catjs\n".
               '</script>';
     if ($totcodes) {
@@ -280,7 +279,7 @@ sub instcode_course_selector {
         if ($numtitles > 0) {
             $r->print('<b>'.&mt('Choose which course(s) to list.').'</b><br />'.
                       &Apache::courseclassifier::build_instcode_selectors($numtitles,
-                       $lasttitle,\%cat_items,\@codetitles,\%cat_titles,\%cat_order));
+                       $lasttitle,\%cat_items,$codetitles,\%cat_titles,\%cat_order));
         }
         $r->print('<input type="hidden" name="coursenum" value="" />'."\n".
                   '<input type="hidden" name="sortby" value="" />'."\n".
@@ -306,7 +305,7 @@ sub instcode_course_selector {
 sub cat_header {
     my ($r,$codedom,$js,$add_entries,$catlinks,$numtitles) = @_;
     my $start_page =
-        &Apache::loncommon::start_page('Course/Community Catalog',$js,
+        &Apache::loncommon::start_page('Other',$js,
                                        {
                                          'add_entries' => $add_entries,
                                          'no_inline_link'   => 1,});
@@ -332,7 +331,7 @@ sub cat_header {
     }
     $r->print(&Apache::lonhtmlcommon::breadcrumbs('Course/Community Catalog'));
     my $onchange;
-    unless (($env{'browser.interface'} eq 'textual') || ($env{'form.interface'} eq 'textual')) {
+    unless ($env{'form.interface'} eq 'textual') {
         $onchange = 'this.form.submit()';
     }
     $r->print('<form name="coursecatdom" method="post" action="/adm/coursecatalog">'.
@@ -387,7 +386,7 @@ sub category_breadcrumbs {
     } else {
         $catlinks .= &mt('Official courses (with institutional codes)');
                      $env{'form.currcat_0'} = 'instcode::0';
-        $currcat_str .= '<input type="hidden" name="currcat_0" value="'.$env{'form.currcat_0'}.'" />';
+         $currcat_str .= '<input type="hidden" name="currcat_0" value="'.$env{'form.currcat_0'}.'" />';
     }
     if ($deeper) {
         for (my $i=1; $i<=$deeper; $i++) {
@@ -582,8 +581,8 @@ sub user_is_dc {
 }
 
 sub search_official_courselist {
-    my ($domain,$numtitles) = @_;
-    my $instcode = &Apache::courseclassifier::instcode_search_str($domain,$numtitles);
+    my ($domain,$numtitles,$codetitles) = @_;
+    my $instcode = &Apache::courseclassifier::instcode_search_str($domain,$numtitles,$codetitles);
     my $showhidden;
     if (&user_is_dc($domain)) {
         $showhidden = $env{'form.showhidden'};
@@ -640,7 +639,7 @@ sub search_courselist {
 }
 
 sub print_course_listing {
-    my ($domain,$numtitles,$trails,$allitems,$subcats) = @_;
+    my ($domain,$numtitles,$trails,$allitems,$subcats,$codetitles) = @_;
     my $output;
     my %courses;
     my $knownuser = &user_is_known();
@@ -664,7 +663,7 @@ sub print_course_listing {
         }
     } else {
         if ($env{'form.currcat_0'} eq 'instcode::0') {
-            %courses = &search_official_courselist($domain,$numtitles);
+            %courses = &search_official_courselist($domain,$numtitles,$codetitles);
         } else {
             %courses = &search_courselist($domain,$subcats);
         }
@@ -806,8 +805,8 @@ sub build_courseinfo_hash {
             $selfenroll_end = $courses->{$course}{'selfenroll_end_date'};
             $categories = $courses->{$course}{'categories'};
             push(@owners,$singleowner);
-            if (ref($courses->{$course}{'co-owners'}) eq 'ARRAY') {
-                foreach my $item (@{$courses->{$course}{'co-owners'}}) {
+            if ($courses->{$course}{'co-owners'} ne '') {
+                foreach my $item (split(/,/,$courses->{$course}{'co-owners'})) {
                     push(@owners,$item);
                 }
             }
@@ -1024,7 +1023,13 @@ sub courseinfo_row {
             if (($info->{'selfenroll_start'} > 0) && ($info->{'selfenroll_start'} > $now)) {
                 $output .= '<td>'.&mt('Starts: [_1]','<span class="LC_cusr_emph">'.$showstart.'</span>').'<br />'.&mt('Ends: [_1]','<span class="LC_cusr_emph">'.$showend.'</span>').'</td>';
             } else { 
-                $output .= '<td><a href="javascript:ToSelfenroll('."'$course'".')">'.&mt('Enroll in course').'</a></td>';
+                $output .= '<td><a href="javascript:ToSelfenroll('."'$course'".')">'.&mt('Enroll in course').'</a><br />';
+                if ($info->{'selfenroll_end'} == 0) {
+                    $output .= &mt('Available permanently');
+                } elsif ($info->{'selfenroll_end'} > $now) {
+                    $output .= &mt('Self-enrollment ends: [_1]','<span class="LC_cusr_emph">'.$showend.'</span>');
+                }
+                $output .= '</td>';
             }
             $selfenroll = 1;
         }
