@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Utilities for classifying courses based on institutional code
 #
-# $Id: courseclassifier.pm,v 1.8 2009/07/29 22:32:44 raeburn Exp $
+# $Id: courseclassifier.pm,v 1.14 2011/03/03 00:06:38 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -30,6 +30,7 @@ package Apache::courseclassifier;
 use strict;
 use lib '/home/httpd/lib/perl/';
 use Apache::lonnet;
+use Apache::loncommon;
 use Apache::lonlocal;
 use LONCAPA;
 
@@ -39,8 +40,10 @@ sub retrieve_instcodes {
     my %courses = &Apache::lonnet::courseiddump($codedom,'.',1,'.','.','.',                                                undef,undef,'Course');
     foreach my $course (keys(%courses)) {
         if (ref($courses{$course}) eq 'HASH') {
-            $$coursecodes{$course} = $courses{$course}{'inst_code'};
-            $totcodes ++;
+            if ($courses{$course}{'inst_code'} ne '') {
+                $$coursecodes{$course} = $courses{$course}{'inst_code'};
+                $totcodes ++;
+            }
         }
     }
     return $totcodes;
@@ -52,7 +55,7 @@ sub sort_cats {
     if (defined($$cat_order{$$codetitles[$num]})) {
         foreach my $item (@{$$cat_order{$$codetitles[$num]}}) {
             if (grep/^\Q$item\E$/,@unsorted) {
-                push @{$sorted}, $item;
+                push(@{$sorted},$item);
             }
         }
     } else {
@@ -258,12 +261,16 @@ sub build_code_selections {
 sub javascript_code_selections {
     my ($formname,@codetitles) = @_;
     my $numtitles = @codetitles;
+    my %lt = &Apache::lonlocal::texthash(
+                      Select => 'Select',
+                      Pick   => 'Pick',
+             );
     my $output = (<<END_OF_BLOCK);
  var display = new Array($numtitles)
  if (caller == "" || caller == "$codetitles[0]") {
      if (caller == "") {
          document.$formname.Year.length = 0
-         document.$formname.Year.options[0] = new Option("Select","-1",true,true)
+         document.$formname.Year.options[0] = new Option("$lt{'Select'}","-1",true,true)
          display[0] = new Array(idyears.length)
          for (var i=0; i<idyears.length; i++) {
              display[0][i] = idyears[i]
@@ -284,13 +291,13 @@ sub javascript_code_selections {
      document.$formname.Semester.length = 0
      document.$formname.Department.length = 0;
      document.$formname.Number.length = 0
-     document.$formname.Department.options[0] = new Option("<-Pick $codetitles[1]","-1",true,true)
-     document.$formname.Number.options[0] = new Option("<-Pick $codetitles[2]","-1",true,true)
+     document.$formname.Department.options[0] = new Option("<-$lt{'Pick'} $codetitles[1]","-1",true,true)
+     document.$formname.Number.options[0] = new Option("<-$lt{'Pick'} $codetitles[2]","-1",true,true)
      if (idyr == 0 || caller == "") {
-         document.$formname.Semester.options[0] = new Option("<-Pick $codetitles[0]","-1",true,true)
+         document.$formname.Semester.options[0] = new Option("<-$lt{'Pick'} $codetitles[0]","-1",true,true)
      }
      else {
-         document.$formname.Semester.options[0] = new Option("Select","-1",true,true)
+         document.$formname.Semester.options[0] = new Option("$lt{'Select'}","-1",true,true)
          display[1] = new Array(idsems[idyr-1].length)
          for (var i=0; i<idsems[idyr-1].length; i++) {
              display[1][i] = idsems[idyr-1][i]
@@ -309,10 +316,10 @@ sub javascript_code_selections {
    document.$formname.Number.length = 0
    document.$formname.Number.options[0] = new Option("<-Pick $codetitles[2]","-1",true,true)
    if (idsem == 0) {
-     document.$formname.Department.options[0] = new Option("<-Pick $codetitles[1]","-1",true,true)
+     document.$formname.Department.options[0] = new Option("<-$lt{'Pick'} $codetitles[1]","-1",true,true)
    }
    else {
-    document.$formname.Department.options[0] = new Option("Select","-1",true,true)
+    document.$formname.Department.options[0] = new Option("$lt{'Select'}","-1",true,true)
     display[2] = new Array(idcodes[idyr-1][idsem-1].length)
     for (var i=0; i<idcodes[idyr-1][idsem-1].length; i++) {
       display[2][i] = idcodes[idyr-1][idsem-1][i]
@@ -329,7 +336,7 @@ sub javascript_code_selections {
  if (caller == "$codetitles[2]") {
    document.$formname.Number.length = 0
    if (iddept == 0) {
-     document.$formname.Number.options[0] = new Option("<-Pick $codetitles[2]","-1",true,true)
+     document.$formname.Number.options[0] = new Option("<-$lt{'Pick'} $codetitles[2]","-1",true,true)
    }
    else {
     document.$formname.Number.options[0] = new Option("Select","-1",true,true)
@@ -510,26 +517,35 @@ function setOfficial(caller) {
                 }
                 $jscript .= &javascript_select_filler($formname,$scripttext,$codetitles,$longtitles_str,$allidlist,$officialjs);
                 if ($env{'form.state'} eq 'listing') {
+                    my @standardnames = &Apache::loncommon::get_standard_codeitems();
+                    my %local_to_standard;
+                    if (ref($codetitles) eq 'ARRAY') {
+                        for (my $i=0; $i<@{$codetitles}; $i++) {
+                            $local_to_standard{$codetitles->[$i]} = $standardnames[$i];
+                        }
+                    }
                     $jscript .= '
 function setElements() {
 ';
                     for (my $i=0; $i<@{$codetitles}-1; $i++) {
-                        if ($env{'form.'.$codetitles->[$i]} != -1) {
+                        my $item = $local_to_standard{$codetitles->[$i]};
+                        if ($env{'form.'.$item} != -1) {
                             $jscript .= '
-    for (var j=0; j<document.'.$formname.'.'.$codetitles->[$i].'.length; j++) {
-        if (document.'.$formname.'.'.$codetitles->[$i].'[j].value == "'.$env{'form.'.$codetitles->[$i]}.'") {
-            document.'.$formname.'.'.$codetitles->[$i].'.selectedIndex = j;
+    for (var j=0; j<document.'.$formname.'.'.$item.'.length; j++) {
+        if (document.'.$formname.'.'.$item.'[j].value == "'.$env{'form.'.$item}.'") {
+            document.'.$formname.'.'.$item.'.selectedIndex = j;
         }
     }
 ';
                         }
                     }
                     $jscript .= '   courseSet()'."\n";
-                    if ($env{'form.'.$codetitles->[-1]} != -1) {
+                    my $lastcodetitle =  $local_to_standard{$codetitles->[-1]};
+                    if ($env{'form.'.$lastcodetitle} != -1) {
                         $jscript .= '
-    for (var j=0; j<document.'.$formname.'.'.$codetitles->[-1].'.length; j++) {
-        if (document.'.$formname.'.'.$codetitles->[-1].'[j].value == "'.$env{'form.'.$codetitles->[-1]}.'") {
-            document.'.$formname.'.'.$codetitles->[-1].'.selectedIndex = j;
+    for (var j=0; j<document.'.$formname.'.'.$lastcodetitle.'.length; j++) {
+        if (document.'.$formname.'.'.$lastcodetitle.'[j].value == "'.$env{'form.'.$lastcodetitle}.'") {
+            document.'.$formname.'.'.$lastcodetitle.'.selectedIndex = j;
         }
     }
 ';
@@ -545,6 +561,7 @@ function setElements() {
 sub build_instcode_selectors {
     my ($numtitles,$lasttitle,$cat_items,$codetitles,$cat_titles,$cat_order) = @_;
     my $output;
+    my @standardnames = &Apache::loncommon::get_standard_codeitems();
     if ($numtitles > 0) {
         $output .= '<table><tr>';
         for (my $k=0; $k<$lasttitle-1; $k++) {
@@ -562,8 +579,8 @@ sub build_instcode_selectors {
                 @longitems = @items;
             }
             $output .= '<td align="center">'.$codetitles->[$k].'<br />'."\n".
-                       '<select name="'.$codetitles->[$k].'" onChange="courseSet(this)"'.
-                       '>'."\n".'<option value="0" />All'."\n";
+                       '<select name="'.$standardnames[$k].'" onChange="courseSet(this)"'.
+                       '>'."\n".'<option value="0">'.&mt('All').'</option>'."\n";
             for (my $i=0; $i<@items; $i++) {
                 if ($longitems[$i] eq '') {
                     $longitems[$i] = $items[$i];
@@ -573,13 +590,13 @@ sub build_instcode_selectors {
             $output .= '</select></td>';
         }
         $output .= '<td align="center">'.$codetitles->[$lasttitle-1].'<br />'."\n".
-                   '<select name="'.$codetitles->[$lasttitle-1].'">'."\n".
+                   '<select name="'.$standardnames[$lasttitle-1].'">'."\n".
                    '<option value="0">'.&mt('All')."\n".
                    '</option>'."\n".'</select>'."\n".
                    '</td></tr></table>'."\n";
         if ($numtitles > 4) {
             $output .= '<br /><br />'.$codetitles->[$numtitles-1].'<br />'."\n".
-                       '<input type="text" name="'.$codetitles->[$numtitles-1].
+                       '<input type="text" name="'.$standardnames[$numtitles-1].
                        '" /><br />'."\n";
         }
         $output .= '<br />';
@@ -671,6 +688,8 @@ sub build_javascript {
 
 sub javascript_select_filler {
     my ($formname,$scripttext,$codetitles,$longtitles_str,$allidlist,$officialjs) = @_;
+    my $all = &mt('All');
+    my $nocrs = &mt('No courses');
     my $output = <<END;
 
 function courseSet(caller) {
@@ -693,14 +712,14 @@ function courseSet(caller) {
     if (selYear == -1) {
         if (selSemester == -1) {
             if (selDepartment > -1) {
-                document.$formname.Number.options[0] =  new Option('All','0',false,false);
+                document.$formname.Number.options[0] =  new Option('$all','0',false,false);
                 for (var k=0; k<idcse_by_dep[selDepartment].length; k++) {
                     document.$formname.Number.options[k+1] = new Option(idcse_by_dep[selDepartment][k],idcse_by_dep[selDepartment][k],false,false);
 
                 }
             }
             else {
-                document.$formname.Number.options[0] = new Option("All","0",true,true);
+                document.$formname.Number.options[0] = new Option('$all','0',true,true);
             }
         }
         else {
@@ -718,17 +737,17 @@ function courseSet(caller) {
                     }
                 }
                 if (iddept != -1) {
-                    document.$formname.Number.options[0] =  new Option('All','0',false,false);
+                    document.$formname.Number.options[0] =  new Option('$all','0',false,false);
                     for (var k=0; k<idcse_by_sem_num[idsem][iddept].length; k++) {
                         document.$formname.Number.options[k+1] = new Option(idcse_by_sem_num[idsem][iddept][k],idcse_by_sem_num[idsem][iddept][k],false,false);
                     }
                 }
                 else {
-                    document.$formname.Number.options[0] =  new Option('No courses','0',true,true);
+                    document.$formname.Number.options[0] =  new Option('$nocrs','0',true,true);
                 }
             }
             else {
-                document.$formname.Number.options[0] = new Option("All","0",true,true);
+                document.$formname.Number.options[0] = new Option('$all','0',true,true);
             }
         }
     }
@@ -748,17 +767,17 @@ function courseSet(caller) {
                     }
                 }
                 if (iddept != -1) {
-                    document.$formname.Number.options[0] =  new Option('All','0',false,false);
+                    document.$formname.Number.options[0] =  new Option('$all','0',false,false);
                     for (var k=0; k<idcse_by_yr_num[idyr][iddept].length; k++) {
                         document.$formname.Number.options[k+1] = new Option(idcse_by_yr_num[idyr][iddept][k],idcse_by_yr_num[idyr][iddept][k],false,false);
                     }
                 }
                 else {
-                    document.$formname.Number.options[0] =  new Option('No courses','0',true,true);
+                    document.$formname.Number.options[0] =  new Option('$nocrs','0',true,true);
                 }
             }
             else {
-                document.$formname.Number.options[0] = new Option("All","0",true,true);
+                document.$formname.Number.options[0] = new Option('$all','0',true,true);
             }
         }
         else {
@@ -783,7 +802,7 @@ function courseSet(caller) {
                     }
                 }
                 if (iddept != -1) {
-                    document.$formname.Number.options[0] =  new Option('All','0',false,false);
+                    document.$formname.Number.options[0] =  new Option('$all','0',false,false);
                     for (var i=0; i<idcourses[idyr][idsem][iddept].length; i++) {
                         var display = idcourses[idyr][idsem][iddept][i];
                         if (longtitles[3] == 1) {
@@ -795,11 +814,11 @@ function courseSet(caller) {
                     }
                 }
                 else {
-                    document.$formname.Number.options[0] =  new Option('No courses','0',true,true);
+                    document.$formname.Number.options[0] =  new Option('$nocrs','0',true,true);
                 }
             }
             else {
-                document.$formname.Number.options[0] =  new Option('All','0',true,true);
+                document.$formname.Number.options[0] =  new Option('$all','0',true,true);
             }
         }
         document.$formname.Number.selectedIndex = 0
@@ -811,7 +830,7 @@ END
 }
 
 sub instcode_search_str {
-    my ($domain,$numtitles) = @_;
+    my ($domain,$numtitles,$codetitles) = @_;
     my $instcode;
     if (defined($numtitles) && $numtitles == 0) {
         $instcode = '.+';
@@ -820,13 +839,25 @@ sub instcode_search_str {
         my $defaults_result =
             &Apache::lonnet::auto_instcode_defaults($domain,\%codedefaults,
                                                     \@code_order);
+        my @standardnames = &Apache::loncommon::get_standard_codeitems();
+        my %local_to_standard;
+        if (ref($codetitles) eq 'ARRAY') {
+            for (my $i=0; $i<@{$codetitles}; $i++) {
+                $local_to_standard{$codetitles->[$i]} = $standardnames[$i];
+            }
+        }
         if ($defaults_result eq 'ok') {
             $instcode ='^';
-            foreach my $item (@code_order) {
-                if ($env{'form.'.$item} eq '0' ) {
-                    $instcode .= $codedefaults{$item};
+            foreach my $loctitle (@code_order) {
+                my $item = $local_to_standard{$loctitle};
+                if ($item ne '') {
+                    if ($env{'form.'.$item} eq '0' ) {
+                        $instcode .= $codedefaults{$loctitle};
+                    } else {
+                        $instcode .= $env{'form.'.$item};
+                    }
                 } else {
-                    $instcode .= $env{'form.'.$item};
+                    $instcode .= '.+';
                 }
             }
             $instcode .= '$';
@@ -837,5 +868,43 @@ sub instcode_search_str {
     return $instcode;
 }
 
+sub instcode_from_selectors {
+    my ($cdom,$noregexps) = @_;
+    my $instcode;
+    my $caller = 'global';
+    my (%coursecodes,%codes,@codetitles,%cat_titles,%cat_order,
+        %codedefaults,@code_order);
+    my $format_reply =
+        &Apache::lonnet::auto_instcode_format($caller,$cdom,\%coursecodes,
+                            \%codes,\@codetitles,\%cat_titles,\%cat_order);
+    my $defaults_result =
+        &Apache::lonnet::auto_instcode_defaults($cdom,\%codedefaults,
+                                                \@code_order);
+    if (($defaults_result eq 'ok') && ($format_reply eq 'ok')) {
+        my @standardnames = &Apache::loncommon::get_standard_codeitems();
+        my %local_to_standard;
+        for (my $i=0; $i<@codetitles; $i++) {
+            $local_to_standard{$codetitles[$i]} = $standardnames[$i];
+        }
+        foreach my $loctitle (@code_order) {
+            my $category = $local_to_standard{$loctitle};
+            if ($category ne '') {
+                if ($env{'form.'.$category} eq '-1' ) {
+                    if ($noregexps) {
+                        $instcode .= ' ';
+                    } else {
+                        $instcode .= $codedefaults{$category};
+                    }
+                } else {
+                    $instcode .= $env{'form.'.$category};
+                }
+            } else {
+                $instcode .= '.+';
+            }
+        }
+    }
+    return $instcode;
+}
+
 1;
 
