@@ -3,7 +3,7 @@
 # institutional log-in ID (institutional authentication required - localauth
 #  or kerberos) or an e-mail address.
 #
-# $Id: createaccount.pm,v 1.37.6.1 2010/08/20 04:01:47 raeburn Exp $
+# $Id: createaccount.pm,v 1.40.2.3 2010/12/24 20:36:11 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -139,7 +139,6 @@ sub handler {
     $start_page =
         &Apache::loncommon::start_page($title,$js,
                                        {'no_inline_link'   => 1,});
-
     my %domconfig = 
         &Apache::lonnet::get_dom('configuration',['usercreation'],$domain);
     my ($cancreate,$statustocreate) = &get_creation_controls($domain,$domconfig{'usercreation'});
@@ -286,7 +285,7 @@ sub selfenroll_crumbs {
     }
     my $last_crumb;
     if ($desc ne '') {
-        $last_crumb = &mt('Self-enroll in [_1]','<span class="LC_cusr_emph">'.$desc.'</span>');
+        $last_crumb = &mt('Self-enroll in [_1]',"<span class='LC_cusr_emph'>$desc</span>");
     } else {
         $last_crumb = &mt('Self-enroll');
     }
@@ -461,7 +460,7 @@ sub login_box {
                                             );
     my ($lkey,$ukey) = &Apache::lonpreferences::des_keys();
     my ($lextkey,$uextkey) = &getkeys($lkey,$ukey);
-    my $logtoken=Apache::lonnet::reply('tmpput:'.$ukey.$lkey.'&createaccount',
+    my $logtoken=Apache::lonnet::reply('tmpput:'.$ukey.$lkey.'&createaccount:createaccount',
                                        $lonhost);
     $output = &serverform($logtoken,$lonhost,undef,$courseid,$context);
     my $unameform = '<input type="text" name="uname" size="20" value="" />';
@@ -599,7 +598,7 @@ sub send_token {
                 'domain'     => $domain,
                 'username'   => $email,
                 'courseid'   => $courseid);
-    my $token = &Apache::lonnet::tmpput(\%info,$server);
+    my $token = &Apache::lonnet::tmpput(\%info,$server,'createaccount');
     if ($token !~ /^error/ && $token ne 'no_such_host') {
         my $esc_token = &escape($token);
         my $showtime = localtime(time);
@@ -645,7 +644,7 @@ sub process_mailtoken {
                 if ($result eq 'ok') {
                     $msg = $output; 
                     my $shownow = &Apache::lonlocal::locallocaltime($now);
-                    my $mailmsg = &mt('A LON-CAPA account for the institution: [_1] has been created [_2] from IP address: [_3].  If you did not perform this action or authorize it, please contact the [_4] ([_5]).',$domdesc,$shownow,$ENV{'REMOTE_ADDR'},$contact_name,$contact_email)."\n";
+                    my $mailmsg = &mt('A LON-CAPA account for the institution: [_1] has been created [_2] from IP address: [_3]. If you did not perform this action or authorize it, please contact the [_4] ([_5]).',$domdesc,$shownow,$ENV{'REMOTE_ADDR'},$contact_name,$contact_email)."\n";
                     my $mailresult = &Apache::resetpw::send_mail($domdesc,$data{'email'},
                                                                  $mailmsg,$contact_name,
                                                                  $contact_email);
@@ -723,7 +722,7 @@ sub print_dataentry_form {
         $output .= &javascript_setforms($now)."\n".&javascript_checkpass($now);
         my ($lkey,$ukey) = &Apache::lonpreferences::des_keys();
         my ($lextkey,$uextkey) = &getkeys($lkey,$ukey);
-        my $logtoken=Apache::lonnet::reply('tmpput:'.$ukey.$lkey.'&createaccount',
+        my $logtoken=Apache::lonnet::reply('tmpput:'.$ukey.$lkey.'&createaccount:createaccount',
                                            $lonhost);
         my $formtag = '<form name="server" method="post" target="_top" action="/adm/createaccount">';
         my ($datatable,$rowcount) =
@@ -964,7 +963,7 @@ sub username_check {
                     'time'       => $now,
                     'domain'     => $domain,
                     'username'   => $username);
-        my $authtoken = &Apache::lonnet::tmpput(\%info,$lonhost);
+        my $authtoken = &Apache::lonnet::tmpput(\%info,$lonhost,'createaccount');
         if ($authtoken !~ /^error/ && $authtoken ne 'no_such_host') {
             $output .= '<input type="hidden" name="authtoken" value="'.&HTML::Entities::encode($authtoken,'&<>"').'" />';
         } else {
@@ -1138,32 +1137,38 @@ sub invalid_state {
     my ($error,$domdesc,$contact_name,$contact_email,$msgtext) = @_;
     my $msg = '<h3>'.&mt('Account creation unavailable').'</h3><span class="LC_error">';
     if ($error eq 'baduseremail') {
-        $msg = &mt('The e-mail address you provided does not appear to be a valid address.');
+        $msg .= &mt('The e-mail address you provided does not appear to be a valid address.');
     } elsif ($error eq 'existinguser') {
-        $msg = &mt('The e-mail address you provided is already in use as a username in LON-CAPA at this institution.');
+        $msg .= &mt('The e-mail address you provided is already in use as a username in LON-CAPA at this institution.');
     } elsif ($error eq 'userrules') {
-        $msg = &mt('Username rules at this institution do not allow the e-mail address you provided to be used as a username.');
+        $msg .= &mt('Username rules at this institution do not allow the e-mail address you provided to be used as a username.');
     } elsif ($error eq 'userformat') {
-        $msg = &mt('The e-mail address you provided may not be used as a username at this LON-CAPA institution.');
+        $msg .= &mt('The e-mail address you provided may not be used as a username at this LON-CAPA institution.');
     } elsif ($error eq 'captcha') {
-        $msg = &mt('Validation of the code your entered failed.');
+        $msg .= &mt('Validation of the code you entered failed.');
     } elsif ($error eq 'noemails') {
-        $msg = &mt('Creation of a new user account using an e-mail address as username is not permitted at this LON-CAPA institution.');
+        $msg .= &mt('Creation of a new user account using an e-mail address as username is not permitted at this LON-CAPA institution.');
     }
     $msg .= '</span>';
     if ($msgtext) {
         $msg .= '<br />'.$msgtext;
     }
-    $msg .= &linkto_email_help($contact_email,$domdesc);
+    $msg .= &linkto_email_help($contact_email,$domdesc,$error);
     return $msg;
 }
 
 sub linkto_email_help {
-    my ($contact_email,$domdesc) = @_;
+    my ($contact_email,$domdesc,$error) = @_;
     my $msg;
+    my $href = '/adm/helpdesk';
     if ($contact_email ne '') {
         my $escuri = &HTML::Entities::encode('/adm/createaccount','&<>"');
-        $msg .= '<br />'.&mt('You may wish to contact the [_1]LON-CAPA helpdesk[_2] for [_3].','<a href="/adm/helpdesk?origurl='.$escuri.'">','</a>',$domdesc).'<br />';
+        $href .= '?origurl='.$escuri;
+        if ($error eq 'existinguser') {
+            my $escemail = &HTML::Entities::encode($env{'form.useremail'});
+            $href .= '&useremail='.$escemail.'&useraccount='.$escemail;
+        }
+        $msg .= '<br />'.&mt('You may wish to contact the [_1]LON-CAPA helpdesk[_2] for [_3].','<a href="'.$href.'">','</a>',$domdesc).'<br />';
     } else {
         $msg .= '<br />'.&mt('You may wish to send an e-mail to the server administrator: [_1] for [_2].',$Apache::lonnet::perlvar{'AdminEmail'},$domdesc).'<br />';
     }
