@@ -1,6 +1,8 @@
 # The LearningOnline Network
 # Group Bulletin Boards Manager
 #
+# $Id: groupboards.pm,v 1.14 2009/02/13 17:20:29 bisitz Exp $
+#
 # Copyright Michigan State University Board of Trustees
 #
 # This file is part of the LearningOnline Network with CAPA (LON-CAPA).
@@ -59,7 +61,7 @@ sub handler {
     my $gpterm =  &Apache::loncommon::group_term();
     my $ucgpterm = $gpterm;
     $ucgpterm =~ s/^(\w)/uc($1)/e;
-    my $bodytitle = $crstype.' Discussion Boards';
+    my $bodytitle = $ucgpterm.' Discussion Boards';
     my $group = $env{'form.group'};
     $group =~ s/\W//g;
     my ($description,$earlyout,$refarg);
@@ -155,7 +157,12 @@ function makebulboard() {
                   "\n".'</form><br />');
     }
     if (@{$groupboards} > 0) {
-        $r->print('<br />');
+        $r->print('<br />'
+                 .&Apache::loncommon::start_data_table()
+                 .&Apache::loncommon::start_data_table_header_row()
+                 .'<th>'.&mt('Discussion Boards').'</th>'
+                 .&Apache::loncommon::end_data_table_header_row()
+        );
         foreach my $board (@{$groupboards}) {
             my $board_url = $$boards{$board}{'url'};
             if ($board_url =~ /\?/) {
@@ -163,12 +170,20 @@ function makebulboard() {
             } else {
                 $board_url .= '?group='.$group;
             }
-            $r->print('<a href="'.$board_url.'&amp;'.$refarg.'">'.
-                      $$boards{$board}{'title'}.'</a><br />');
+            $r->print(&Apache::loncommon::start_data_table_row()
+                     .'<td>'
+                     .'<a href="'.$board_url.'&amp;'.$refarg.'">'
+                     .$$boards{$board}{'title'}.'</a>'
+                     .'</td>'
+                     .&Apache::loncommon::end_data_table_row()
+            );
         }
+        $r->print(&Apache::loncommon::end_data_table());
     } else {
-        $r->print('<br />'.&mt('There are currently no discussion boards in this [_1].',
-                      $gpterm));
+        $r->print('<p class="LC_info">'
+                 .&mt('There are currently no discussion boards in this '.$gpterm.'.',)
+                 .'</p>'
+        );
     }
     $r->print(&Apache::loncommon::end_page());
     return OK;
