@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Routines for messaging
 #
-# $Id: lonmsg.pm,v 1.222.2.2 2010/09/13 23:38:04 raeburn Exp $
+# $Id: lonmsg.pm,v 1.231 2011/02/13 17:44:51 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -455,6 +455,7 @@ sub sendemail {
     "*** ".&mt_user($user_lh,'This is an automatic e-mail generated by the LON-CAPA system.')."\n".
     "*** ".($senderaddress?&mt_user($user_lh,'You can reply to this e-mail'):&mt_user($user_lh,'Please do not reply to this address.')."\n*** ".
     &mt_user($user_lh,'A reply will not be received by the recipient!'))."\n\n".$body;
+    
     my $msg = new Mail::Send;
     $msg->to($to);
     $msg->subject('[LON-CAPA] '.$subject);
@@ -464,6 +465,7 @@ sub sendemail {
     if ($senderaddress) {
         $msg->add('From',$senderaddress);
     }
+    $msg->add('Content-type','text/plain; charset=UTF-8');
     if (my $fh = $msg->open()) {
 	print $fh $body;
 	$fh->close;
@@ -574,10 +576,17 @@ sub make_htmlfree {
     return $text;
 }
 
+sub mynewmail{
+	&newmail();
+	return $env{'user.mailcheck.lastnewmessagetime'} > $env{'user.mailcheck.lastvisit'};
+}
+
+
 sub newmail {
     if ((time-$env{'user.mailcheck.time'})>300) {
         my %what=&Apache::lonnet::get('email_status',['recnewemail']);
         &Apache::lonnet::appenv({'user.mailcheck.time'=>time});
+		&Apache::lonnet::appenv({'user.mailcheck.lastnewmessagetime'=> $what{'recnewemail'}});
         if ($what{'recnewemail'}>0) { return 1; }
     }
     return 0;
@@ -977,7 +986,9 @@ sub secapply {
     my $rec=shift;
     my $defaultflag=shift;
     $rec=~s/\s+//g;
-    $rec=~s/\@/\:/g;
+    unless ($rec =~ /\:/) {
+        $rec=~s/\@/\:/g;
+    }
     my ($adr,$sections_or_groups)=($rec=~/^([^\(]+)\(([^\)]+)\)/);
     if ($sections_or_groups) {
 	foreach my $item (split(/\;/,$sections_or_groups)) {
