@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Pick a course
 #
-# $Id: lonpickcourse.pm,v 1.93.2.3 2010/11/13 14:43:08 raeburn Exp $
+# $Id: lonpickcourse.pm,v 1.101 2011/01/25 02:49:42 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -140,9 +140,10 @@ sub handler {
 # ------------------------------------------ Display of filters to limit search
     my $filter = {};
     my $action = '/adm/pickcourse';
-    my ($numtitles,$showroles,$nohost);
+    my ($numtitles,$showroles,$nohost,@codetitles);
     if (!$onlyown) {
         my $filterlist = ['domainfilter'];
+        # created filter for DCs only
         if ($env{'user.adv'} && $env{'form.domainfilter'} &&
             exists($env{'user.role.dc./'.$env{'form.domainfilter'}.'/'})
             && $env{'form.form'} ne 'portform') {
@@ -152,7 +153,6 @@ sub handler {
             }
         }
         push(@{$filterlist},('descriptfilter','instcodefilter'));
-
         if ($env{'form.form'} eq 'rules') {
             push(@{$filterlist},'personfilter');
             if (($env{'form.personfilter'} ne '') && ($env{'form.persondomfilter'} ne '')) {
@@ -177,7 +177,7 @@ sub handler {
 
         $r->print(&build_filters($filterlist,$type,$roleelement,$multelement,
                                  $filter,$action,\$numtitles,undef,$cloneruname,
-                                 $clonerudom,$typeelement));
+                                 $clonerudom,$typeelement,\@codetitles));
     }
 
 # ---------------------------------------------------------------- Get the data
@@ -191,7 +191,7 @@ sub handler {
             }
         }
         my %courses = &search_courses($r,$type,$onlyown,$filter,$numtitles,
-                                      $cloneruname,$clonerudom,$domcloner);
+                                      $cloneruname,$clonerudom,$domcloner,\@codetitles);
         if ($nohost) {
             $r->print ('<span class="LC_warning">'.
                        &mt('User does not exist - username: [_1], domain: [_2].',
@@ -418,7 +418,7 @@ sub display_matched_courses {
                             $canclone = 1;
                         }
                     }
-                    unless ($canclone) {
+                    unless ($canclone) { 
                         if ($cc_cloneable{$cnum.':'.$cdom}) {
                             $canclone = 1;
                         }
@@ -439,10 +439,10 @@ sub display_matched_courses {
                         }
                     }
                 }
-                push(@owners,&unescape($courses{$course}{'owner'}));
-                if (ref($courses{$course}{'co-owners'}) eq 'ARRAY') {
-                    foreach my $item (@{$courses{$course}{'co-owners'}}) {
-                        push(@owners,&unescape($item));
+                push(@owners,$courses{$course}{'owner'});
+                if ($courses{$course}{'co-owners'} ne '') {
+                    foreach my $item (split(/,/,$courses{$course}{'co-owners'})) {
+                        push(@owners,$item);
                     }
                 }
             } else {
@@ -543,7 +543,7 @@ sub multiples_tag {
 
 sub build_filters {
     my ($filterlist,$type,$roleelement,$multelement,$filter,$action,
-        $numtitlesref,$caller,$cloneruname,$clonerudom,$typeelement) = @_;
+        $numtitlesref,$caller,$cloneruname,$clonerudom,$typeelement,$codetitlesref) = @_;
     my ($list,$formname,$fixeddom,$codedom,$jscript);
     $codedom = $env{'request.role.domain'};
     if (defined($env{'form.form'})) {
@@ -551,10 +551,7 @@ sub build_filters {
     } else {
         $formname = $caller;
     }
-    my $onchange;
-    unless ($env{'form.interface'} eq 'textual') {
-        $onchange = 'javascript:updateFilters(this)';
-    }
+    my $onchange = 'javascript:updateFilters(this)';
     my ($domainselectform,$sincefilterform,$createdfilterform,
         $ownerdomselectform,$persondomselectform,$instcodeform,
         $typeselectform,$instcodetitle);
@@ -619,7 +616,6 @@ sub build_filters {
         }
     }
 
-
     # last course activity filter and selection
     $sincefilterform = &timebased_select_form('sincefilter',$filter);
 
@@ -630,7 +626,7 @@ sub build_filters {
 
     my %lt = &Apache::lonlocal::texthash(
                 'cac' => "$type Activity",
-                'ccr' => "$type Created",
+                'ccr' => "$type Created", 
                 'cde' => "$type Title",
                 'cdo' => "$type Domain",
                 'ins' => 'Institutional Code',
@@ -681,7 +677,7 @@ sub build_filters {
                 || ($formname eq 'modifycourse')) {
                 $officialjs = 1;
                 ($instcodeform,$jscript,$$numtitlesref) = 
-                    &instcode_selectors($codedom,'filterpicker',$officialjs);
+                    &instcode_selectors($codedom,'filterpicker',$officialjs,$codetitlesref);
                 if ($jscript) {
                     $jscript = '<script type="text/javascript" language="Javascript">'.
                                $jscript.'</script>'."\n";
@@ -816,10 +812,10 @@ sub timebased_select_form {
         $filter->{$item} = $env{'form.'.$item};
         $filter->{$item} =~ s/[^\d-]//g;
         if (!$filter->{$item}) { $filter->{$item}=-1; }
-        return &Apache::loncommon::select_form(
+        return &Apache::loncommon::select_form( 
                             $filter->{$item},
                             $item,
-                            (      '-1' => '',
+                            {      '-1' => '',
                                 '86400' => &mt('today'),
                                '604800' => &mt('last week'),
                               '2592000' => &mt('last month'),
@@ -828,7 +824,7 @@ sub timebased_select_form {
                              '31104000' => &mt('last year'),
                     'select_form_order' =>
                            ['-1','86400','604800','2592000','7776000',
-                            '15552000','31104000']));
+                            '15552000','31104000']});
     }
 }
 
@@ -836,7 +832,7 @@ sub get_coordinator_cloneable {
     my ($cloneruname,$clonerudom,$type) = @_;
     if (($cloneruname!~/\w/) || ($clonerudom!~/\w/)) {
         my $warning = '<div class="LC_warning">'.&mt('Intended course owner not specified').
-                      '</div>';
+                   '</div>';
         return ('',$warning);
     } elsif (&Apache::lonnet::homeserver($cloneruname,$clonerudom) eq 'no_host') {
         my $warning = '<div class="LC_error">'.&mt('Intended course owner does not exist').
@@ -861,11 +857,11 @@ sub get_coordinator_cloneable {
 }
 
 sub instcode_selectors {
-    my ($codedom,$formname,$officialjs) = @_;
-    my ($output,@codetitles,%cat_titles,%cat_order,%cat_items);
+    my ($codedom,$formname,$officialjs,$codetitles) = @_;
+    my ($output,%cat_titles,%cat_order,%cat_items);
     my ($jscript,$totcodes,$numtitles,$lasttitle) =
         &Apache::courseclassifier::instcode_selectors_data($codedom,$formname,
-                           \%cat_items,\@codetitles,\%cat_titles,\%cat_order,$officialjs);
+                           \%cat_items,$codetitles,\%cat_titles,\%cat_order,$officialjs);
     if ($numtitles > 0) {
         my $official = ' checked="checked" ';
         my $unofficial = '';
@@ -879,7 +875,7 @@ sub instcode_selectors {
                    '<input type="radio" name="official" value="off"'.$unofficial.
                    ' onclick="toggleOfficial();" />'.&mt('No').'</label></span><br />'.
                    &Apache::courseclassifier::build_instcode_selectors($numtitles,
-                   $lasttitle,\%cat_items,\@codetitles,\%cat_titles,\%cat_order)."\n".
+                   $lasttitle,\%cat_items,$codetitles,\%cat_titles,\%cat_order)."\n".
                    '<input type="hidden" name="numtitles" value="'.$numtitles.'" />'."\n".
                    '<input type="hidden" name="state" value="listing" />'."\n";
  
@@ -888,7 +884,7 @@ sub instcode_selectors {
 }
 
 sub search_courses {
-    my ($r,$type,$onlyown,$filter,$numtitles,$cloneruname,$clonerudom,$domcloner) = @_;
+    my ($r,$type,$onlyown,$filter,$numtitles,$cloneruname,$clonerudom,$domcloner,$codetitles) = @_;
     my (%courses,%showcourses,$cloner,$ccrole);
     if ($type eq 'Community') {
         $ccrole = 'co';
@@ -909,7 +905,7 @@ sub search_courses {
             }
         }
         my $now = time;
-        my $timefilter =
+        my $timefilter = 
            ($filter->{'sincefilter'}==-1?1:$now-$filter->{'sincefilter'});
         my ($createdbefore,$createdafter);
         if (($filter->{'createdfilter'} ne '') && ($filter->{'createdfilter'} !=-1)) {
@@ -920,10 +916,10 @@ sub search_courses {
         if ($numtitles) {
             if ($env{'form.official'} eq 'on') {
                 $instcodefilter = 
-                    &Apache::courseclassifier::instcode_search_str($filter->{'domainfilter'},$numtitles);
+                    &Apache::courseclassifier::instcode_search_str($filter->{'domainfilter'},$numtitles,$codetitles);
                 $regexpok = 1;
             } elsif ($env{'form.official'} eq 'off') {
-                $instcodefilter = &Apache::courseclassifier::instcode_search_str($filter->{'domainfilter'},$numtitles);
+                $instcodefilter = &Apache::courseclassifier::instcode_search_str($filter->{'domainfilter'},$numtitles,$codetitles);
                 unless ($instcodefilter eq '') {
                     $regexpok = -1;
                 }
@@ -1217,10 +1213,10 @@ Side Effects: None
 
 =item *
 X<build_filters()>
-B<build_filters($filterlist,$type,$roleelement,$multelement,$filter,$action,$numfiltersref,$caller,$cloneruname,$clonerudom,$typeelem)>:
+B<build_filters($filterlist,$type,$roleelement,$multelement,$filter,$action,$numfiltersref,$caller,$cloneruname,$clonerudom,$typeelem,$codetitlesref>:
 
 
-Input: 11 - anonymous array of search criteria; course type; $roleelement ; $multelement ; anonymous hash of criteria and their values; form action; ref to scalar (count of number of elements in institutional codes -- e.g., 4 for year, semester, department, and number); caller context (e.g., set to 'modifycourse' when routine is called from lonmodifycourse.pm), username and domain of new course owner who wants to clone, $tyepelem 
+Input: 12 - anonymous array of search criteria; course type; $roleelement ; $multelement ; anonymous hash of criteria and their values; form action; ref to scalar (count of number of elements in institutional codes -- e.g., 4 for year, semester, department, and number); caller context (e.g., set to 'modifycourse' when routine is called from lonmodifycourse.pm); username and domain of new course owner who wants to clone, $typeelem; reference to array of titles of components in institutional codes (official courses). 
 
 Output: 1 - $output - HTML for display of search criteria, and hidden form elements. 
 
@@ -1229,10 +1225,11 @@ Side Effects: None
 =item *
 X<search_courses()>
 B<search_courses($r,$type,$onlyown,$filter,$numtitles,$cloneruname,$clonerudom,
-                 $domcloner)>:
+                 $domcloner,$codetitles)>:
 
 
-Input: 8 -  request object, course type, search scope: only courses in which user has active role (1), or any course (0); anonymous hash of criteria and their values; for institutional codes - number of categories; optional username of new course owner, optional domain of new course owner). Seventh and eighth needed when search is for courses to clone from course request form, or course creation form (DC). Optional "domcloner" flag (has value=1 if user has ccc priv in domain being filtered by (used when DC is using course creation form).
+Input: 9 -  request object, course type, search scope: only courses in which user has active role (1), or any course (0); anonymous hash of criteria and their values; for institutional codes - number of categories; optional username of new course owner, optional domain of new course owner). Seventh and eighth needed when search is for courses to clone from course request form, or course creation form (DC). Optional "domcloner" flag (has value=1 if user has ccc priv in  
+domain being filtered by (used when DC is using course creation form). Ninth is reference to array of titles of components in institutional codes (official courses).
 
 Output: 1 - %courses - hash of courses satisfying search criteria, keys = course IDs, values are corresponding colon-separated escaped description, institutional code, owner and type.
 
