@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Pick a student from the classlist
 #
-# $Id: lonpickstudent.pm,v 1.26 2009/03/01 01:17:20 raeburn Exp $
+# $Id: lonpickstudent.pm,v 1.28 2009/11/05 14:24:01 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -50,7 +50,7 @@ sub handler {
 
     &Apache::loncommon::get_unprocessed_cgi
         ($ENV{'QUERY_STRING'},['filter','form','unameelement','udomelement',
-			       'roles']);
+			       'roles','courseadvonly']);
 # Allowed?
     my $allowed;
     my $scope = $env{'request.course.id'};
@@ -83,27 +83,22 @@ FILTER
    <input type="hidden" name="$name" value="$value" />
 HIDDEN
     }
-    $filtermsg = '<br />'.
-	&mt('Showing users with a name starting with [_1]',
-	    $filterbutton).'<br />';
+    unless ($env{'form.courseadvonly'}) {
+        $filtermsg = '<br />'.
+	    &mt('Showing users with a name starting with [_1]',
+	        $filterbutton).'<br />';
+    }
     if ($filter eq '') {
 	$filter = '.'
     }
 
-    my $cdom = $env{'course.'.$env{'request.course.id'}.'.domain'};
-    my $cnum = $env{'course.'.$env{'request.course.id'}.'.num'};
-    my $classlist=&Apache::loncoursedata::get_classlist();
-    my %grouplist=&Apache::lonnet::get_group_membership($cdom,$cnum);
-    my $now = time;
-    my %allgroups = &Apache::longroup::coursegroups($cdom,$cnum);
-
 # --------------------------------------- There is such a user, get environment
 
     $r->print(<<ENDSCRIPT);
 <script type="text/javascript">
 function gochoose(uname,udom) {
-    opener.document.$env{'form.form'}.$env{'form.unameelement'}.value=uname;
-    var slct=opener.document.$env{'form.form'}.$env{'form.udomelement'};
+    opener.document.$env{'form.form'}.elements['$env{'form.unameelement'}'].value=uname;
+    var slct=opener.document.$env{'form.form'}.elements['$env{'form.udomelement'}'];
     var i;
     for (i=0;i<slct.length;i++) {
         if (slct.options[i].value==udom) { slct.selectedIndex=i; }
@@ -138,60 +133,69 @@ ENDSCRIPT
 
 	$r->print('</p>');
 
+        unless ($env{'form.courseadvonly'}) {
+
 # ------------------------------------------------------------------ Students
-	my $result;
-	foreach my $user (sort(keys(%$classlist))) {
-	    # the following undefs are for 'domain', and 'username' respectively.
-	    my (undef,undef,$end,$start,$id,$section,$fullname,$status)=
-		@{$classlist->{$user}};
-	    if ($allowed eq 'section' && $section ne $env{'request.course.sec'}) {
-		next;
-	    }
-	    if ($user=~/^($LONCAPA::username_re)\:($LONCAPA::domain_re)$/) {
-		my ($uname,$udom)=($1,$2);
-		if (($uname=~/^$filter/) || 
-		    ($fullname=~/^$filter/i)) {
-		    my $grouplist = '';
-		    foreach my $group (sort(keys(%allgroups))) {
-			if (exists($grouplist{$group.':'.$uname.':'.$udom})) {
-			    my ($end,$start) = split(/:/,$grouplist{$group.':'.$uname.':'.$udom});
-			    if (($end!=0) && ($end<$now)) { next; }
-			    if (($start!=0) && ($start>$now)) {next; }
-			    $grouplist .= " $group,"; 
-			}
+	    my $result;
+            my $cdom = $env{'course.'.$env{'request.course.id'}.'.domain'};
+            my $cnum = $env{'course.'.$env{'request.course.id'}.'.num'};
+            my $classlist=&Apache::loncoursedata::get_classlist();
+            my %grouplist=&Apache::lonnet::get_group_membership($cdom,$cnum);
+            my $now = time;
+            my %allgroups = &Apache::longroup::coursegroups($cdom,$cnum);
+
+	    foreach my $user (sort(keys(%$classlist))) {
+	        # the following undefs are for 'domain', and 'username' respectively.
+	        my (undef,undef,$end,$start,$id,$section,$fullname,$status)=
+		    @{$classlist->{$user}};
+	        if ($allowed eq 'section' && $section ne $env{'request.course.sec'}) {
+		    next;
+	        }
+	        if ($user=~/^($LONCAPA::username_re)\:($LONCAPA::domain_re)$/) {
+		    my ($uname,$udom)=($1,$2);
+		    if (($uname=~/^$filter/) || ($fullname=~/^$filter/i)) {
+		        my $grouplist = '';
+		        foreach my $group (sort(keys(%allgroups))) {
+			    if (exists($grouplist{$group.':'.$uname.':'.$udom})) {
+			        my ($end,$start) = split(/:/,$grouplist{$group.':'.$uname.':'.$udom});
+			        if (($end!=0) && ($end<$now)) { next; }
+			        if (($start!=0) && ($start>$now)) {next; }
+			        $grouplist .= " $group,"; 
+			    }
+		        }
+		        $grouplist =~ s/,$//;
+		        $result .=&Apache::loncommon::start_data_table_row().
+		    	          '<td>'.
+			          '<input type="button" value="'.&mt('Select').'" onClick="gochoose('.
+			          "'".$uname."','".$udom."')".'" /></td>'.
+			          '<td><tt>'.$uname.'</tt></td><td> <tt>'.$udom.
+			          '</tt></td><td>'.
+			          &Apache::loncommon::aboutmewrapper($fullname,
+				    				     $uname,$udom).
+			          '</td><td>'.$id.'</td><td>'.$section.
+			          '</td><td>'.$grouplist.'</td>'.
+			          &Apache::loncommon::end_data_table_row();
 		    }
-		    $grouplist =~ s/,$//;
-		    $result .=&Apache::loncommon::start_data_table_row().
-			      '<td>'.
-			      '<input type="button" value="'.&mt('Select').'" onClick="gochoose('.
-			      "'".$uname."','".$udom."')".'" /></td>'.
-			      '<td><tt>'.$uname.'</tt></td><td> <tt>'.$udom.
-			      '</tt></td><td>'.
-			      &Apache::loncommon::aboutmewrapper($fullname,
-								 $uname,$udom).
-			      '</td><td>'.$id.'</td><td>'.$section.
-			      '</td><td>'.$grouplist.'</td>'.
-			      &Apache::loncommon::end_data_table_row();
-		}
+	        }
 	    }
-	}
-	if (!$result) {
-	    $r->print('<p>'.&mt('No students found.').'</p>');
-	} else {
-	    $r->print(&Apache::loncommon::start_data_table().
-		      &Apache::loncommon::start_data_table_header_row().
-		      &Apache::loncommon::end_data_table_header_row().
-		      '<th>&nbsp;</th>'.
-		      '<th>'.&mt('username').'</th>'.
-		      '<th>'.&mt('domain').'</th>'.
-		      '<th>'.&mt('Name').'</th>'.
-		      '<th>'.&mt('ID').'</th>'.
-		      '<th>'.&mt('section').'</th>'.
-		      '<th>'.&mt('active group(s)').'</th>'.
-		      &Apache::loncommon::end_data_table_header_row().
-		      $result.
-		      &Apache::loncommon::end_data_table());
-	}
+	    if (!$result) {
+	        $r->print('<p>'.&mt('No students found.').'</p>');
+	    } else {
+	        $r->print(&Apache::loncommon::start_data_table().
+	    	          &Apache::loncommon::start_data_table_header_row().
+		          &Apache::loncommon::end_data_table_header_row().
+		          '<th>&nbsp;</th>'.
+		          '<th>'.&mt('username').'</th>'.
+		          '<th>'.&mt('domain').'</th>'.
+		          '<th>'.&mt('Name').'</th>'.
+		          '<th>'.&mt('ID').'</th>'.
+		          '<th>'.&mt('section').'</th>'.
+		          '<th>'.&mt('active group(s)').'</th>'.
+		          &Apache::loncommon::end_data_table_header_row().
+		          $result.
+		          &Apache::loncommon::end_data_table());
+	    }
+        }
     } else {
 	$r->print('<h3>'.&mt('Users with Roles Assigned by').' '.
 		  &Apache::loncommon::plainname($env{'user.name'},
