@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 # CGI-script to run LaTeX, dvips, ps2ps, ps2pdf etc.
 #
-# $Id: printout.pl,v 1.142.6.4 2010/08/26 08:45:08 raeburn Exp $
+# $Id: printout.pl,v 1.146.4.2 2011/03/04 16:53:06 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -178,7 +178,17 @@ my %perlvar=%{&LONCAPA::Configuration::read_conf('loncapa.conf')};
 &Apache::lonlocal::get_language_handle();
 &Apache::loncommon::content_type(undef,'text/html');
 $env{'request.noversionuri'} = '/cgi-bin/printout.pl';
-print(&Apache::loncommon::start_page('Creating PDF'));
+# Breadcrumbs
+#FIXME: Choose better/different breadcrumbs?!? Links?
+my $brcrum = [{'href' => '',
+               'text' => 'Helper'}, #FIXME: Different origin possible than print out helper?
+              {'href' => '',
+               'text' => 'Preparing Printout'},
+              {'href' => '',
+               'text' => 'Creating PDF'}];
+print(&Apache::loncommon::start_page('Creating PDF',
+                                     undef,
+                                     {'bread_crumbs' => $brcrum,}));
 
 my $identifier = $ENV{'QUERY_STRING'};
 my $texfile = $env{'cgi.'.$identifier.'.file'};
@@ -470,7 +480,7 @@ foreach $texfile (@texfile) {
 	      if ($laystyle eq 'album' and $numberofcolumns eq '2') {
 		  $comma = "psnup $papera -2 -s1.0 $new_name_file";
 		  &debug("PSNUP command: $comma");
-                  &busy_wait_command("$comma $tempo_file 1>/dev/null 2>/dev/null",
+		  &busy_wait_command("$comma $tempo_file 1>/dev/null 2>/dev/null",
 				     "for $status_statement now Modifying PS layout",
 				     \%prog_state,$tempo_file);
 	      } elsif ($laystyle eq 'book' and $numberofcolumns eq '2') {
@@ -894,8 +904,8 @@ sub convert_figure {
 	$not_eps =~ s/^\s+//;
 	$not_eps =~ s/\s+$//;
 	$not_eps =~ s/ /\\ /g;
+        my $prettyname=$not_eps;
 	if ($advanced_role) {
-	    my $prettyname=$not_eps;
 	    $prettyname=~s|/home/([^/]+)/public_html|/priv/$1|;
 	    $prettyname=~s|$perlvar{'lonDocRoot'}/|/|;
 	    &Apache::lonhtmlcommon::Update_PrgWin('',\%prog_state,
@@ -918,6 +928,12 @@ sub convert_figure {
 	    system("pdftops $not_eps $eps_f");
 	} else {
 	    system("convert $not_eps $eps_f");
+            if ($? and $advanced_role) {
+                print '<p class="LC_warning">'
+                      .&mt('An error occured during the conversion of [_1].[_2]If possible try to save this image using different settings and republish it.',
+                      '<span class="LC_filename">'.$prettyname.'</span>','<br/>')
+                      .'</p>';
+            }
 	}
 
 	if (not -e $eps_f) {
