@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Allow access to password changing via a token sent to user's e-mail. 
 #
-# $Id: resetpw.pm,v 1.22 2009/10/09 00:26:40 raeburn Exp $
+# $Id: resetpw.pm,v 1.23.2.2 2010/12/24 21:21:51 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -69,6 +69,15 @@ sub handler {
     my $contact_email =  $r->dir_config('lonSupportEMail');
     my $server = $r->dir_config('lonHostID');
     my $defdom = &Apache::lonnet::default_login_domain();
+    my $handle = &Apache::lonnet::check_for_valid_session($r);
+    my $lonidsdir=$r->dir_config('lonIDsDir');
+    if ($handle ne '') {
+        if ($handle=~/^publicuser\_/) {
+            unlink($r->dir_config('lonIDsDir')."/$handle.id");
+        } else {
+            &Apache::lonnet::transfer_profile_to_env($lonidsdir,$handle);
+        }
+    }
     &Apache::lonacc::get_posted_cgi($r);
     &Apache::lonlocal::get_language_handle($r);
     &Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},['token']);
@@ -77,11 +86,28 @@ sub handler {
     my $uname = &unescape($env{'form.uname'});
     my $udom = $env{'form.udom'};
     my $token = $env{'form.token'};
-    my $start_page =
-        &Apache::loncommon::start_page('Reset password','',
-                                           {
-                                             'no_inline_link'   => 1,});
-    $r->print($start_page);
+    my $brcrum = [];
+    my $bread_crumbs_component = 'Forgotten Password';
+    if ($token) {
+        push (@{$brcrum},
+            {href => '/adm/resetpw',
+             text => 'Update Password'});
+
+        $bread_crumbs_component = 'Reset Password';
+    } else {
+        push (@{$brcrum},
+            {href => '/adm/resetpw',
+             text => 'Account Information'});
+        if ($uname && $udom) {
+            push (@{$brcrum},
+                {href => '/adm/resetpw',
+                 text => 'Result'});
+        }
+    }
+    my $args = {bread_crumbs           => $brcrum,
+                bread_crumbs_component => $bread_crumbs_component,
+               'no_inline_link'        => 1};
+    $r->print(&Apache::loncommon::start_page('Reset password','',$args));
     $r->print('<h3>'.&mt('Reset forgotten LON-CAPA password').'</h3>');
     my $output;
     if ($token) {
@@ -153,29 +179,24 @@ sub get_uname {
                                          uemail => 'E-mail address in LON-CAPA',
                                          proc => 'Proceed');
 
-    my $msg = &mt('If you use the same account for other campus services besides LON-CAPA, (e.g., e-mail, course registration, etc.), a separate centrally managed mechanism likely exists to reset a password.  However, if your account is used for just LON-CAPA access you will probably be able to reset a password from this page.');
+    my $msg = &mt('If you use the same account for other campus services besides LON-CAPA, (e.g., e-mail, course registration, etc.), a separate centrally managed mechanism likely exists to reset a password. However, if your account is used for just LON-CAPA access you will probably be able to reset a password from this page.');
     $msg .= '<br /><br />'.&mt('Three conditions must be met:')
            .'<ul><li>'.&mt('An e-mail address must have previously been associated with your LON-CAPA username.').'</li>'
            .'<li>'.&mt('You must be able to access e-mail sent to that address.').'</li>'
            .'<li>'.&mt('Your LON-CAPA account must be of a type for which LON-CAPA can reset a password.')
            .'</ul>';
-    $msg .= qq|
-<form name="forgotpw" method="post">
-<table>
-<tr><td>
-<tr><td align="left">LON-CAPA $lt{'unam'}:                      </td>
-    <td><input type="text" name="uname" size="15" /></td></tr>
-<tr><td align="left">LON-CAPA $lt{'udom'}:                      </td>
-    <td>|;
-    $msg .= &Apache::loncommon::select_dom_form($defdom,'udom');
-    $msg .= qq|</td></tr>
-<tr><td align="left">$lt{'uemail'}:                             </td>
-    <td><input type="text" name="useremail" size="30" /></td></tr>
-<tr><td colspan="2" align="left"><br />
-    <input type="submit" value="$lt{'proc'}" /></td></tr>
-</table>
-</form>
-|;
+    $msg .= '<form name="forgotpw" method="post" action="/adm/resetpw">'.
+            &Apache::lonhtmlcommon::start_pick_box().
+            &Apache::lonhtmlcommon::row_title('LON-CAPA '.$lt{'unam'}).
+            '<input type="text" name="uname" size="20" />'.
+            &Apache::lonhtmlcommon::row_closure(1).
+            &Apache::lonhtmlcommon::row_title('LON-CAPA '.$lt{'udom'}).
+            &Apache::loncommon::select_dom_form($defdom,'udom').
+            &Apache::lonhtmlcommon::row_closure(1).
+            &Apache::lonhtmlcommon::row_title($lt{'uemail'}).
+            '<input type="text" name="useremail" size="30" />'.
+            &Apache::lonhtmlcommon::end_pick_box().
+            '<br /><br /><input type="submit" name="resetter" value="'.$lt{'proc'}.'" /></form>';
     return $msg;
 }
 
@@ -198,7 +219,7 @@ sub send_token {
         my $esc_token = &escape($token);
         my $showtime = &Apache::lonlocal::locallocaltime(time);
         my $reseturl = &Apache::lonnet::absolute_url().'/adm/resetpw?token='.$esc_token;
-        my $mailmsg = &mt('A request was submitted on [_1] for reset of the password for your LON-CAPA account.',$showtime).' '.&mt('To complete this process please open a web browser and enter the following URL in the address/location box: [_1]',$reseturl);
+        my $mailmsg = &mt('A request was submitted on [_1] for reset of the password for your LON-CAPA account.',$showtime)." \n".&mt('To complete this process please open a web browser and enter the following URL in the address/location box: [_1]',"\n\n".$reseturl);
         my $result = &send_mail($domdesc,$email,$mailmsg,$contact_name,
                                 $contact_email);
         if ($result eq 'ok') {
@@ -218,6 +239,7 @@ sub send_mail {
     my $requestmail = "To: $email\n".
                       "From: $contact_name <$contact_email>\n".
                       "Subject: ".&mt('Your LON-CAPA account')."\n".
+                      "Content-type: text/plain\;charset=UTF-8\n".
                       "\n\n".$mailmsg."\n\n".
                       &mt('[_1] LON-CAPA support team',$domdesc)."\n".
                       "$contact_email\n";
@@ -235,8 +257,8 @@ sub invalid_state {
     my ($error,$domdesc,$contact_name,$contact_email) = @_;
     my $msg;
     if ($error eq 'invalid') {
-        $msg = &mt('The username you provided was not verified as a valid username in the LON-CAPA system for the [_1] domain.',$domdesc)
-              .' '.&mt('Please [_1]go back[_2] and try again.','<a href="javascript:history.go(-1)"><u>','</u></a>');
+        $msg = '<p class="LC_warning">'.&mt('The username you provided was not verified as a valid username in the LON-CAPA system for the [_1] domain.',$domdesc)
+              .'</p>'.&mt('Please [_1]go back[_2] and try again.','<a href="javascript:history.go(-1)"><u>','</u></a>');
     } else {
         if ($error eq 'baduseremail') {
             $msg = &mt('The e-mail address you provided does not appear to be a valid address.');
@@ -247,6 +269,7 @@ sub invalid_state {
         } elsif ($error eq 'authentication') {
             $msg = &mt('The username you provided uses an authentication type which can not be reset directly via LON-CAPA.');
         }
+        $msg = '<p class="LC_warning">'.$msg.'</p>';
         if ($contact_email ne '') {
             my $escuri = &HTML::Entities::encode('/adm/resetpw','&<>"');
             $msg .= '<br /> '.&mt('You may wish to contact the [_1]LON-CAPA helpdesk[_2] for the [_3] domain.'
