@@ -1,5 +1,5 @@
 #
-# $Id: lonspreadsheet.pm,v 1.51 2007/08/18 00:04:41 albertel Exp $
+# $Id: lonspreadsheet.pm,v 1.55 2009/07/08 17:55:10 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -73,12 +73,12 @@ use HTML::Entities();
 sub textfield {
     my ($title,$name,$value)=@_;
     return "\n<p><b>$title:</b><br />".
-        '<input type=text name="'.$name.'" size=80 value="'.$value.'" />';
+        '<input type="text" name="'.$name.'" size="80" value="'.$value.'" />';
 }
 
 sub hiddenfield {
     my ($name,$value)=@_;
-    return '<input type=hidden name="'.$name.'" value="'.$value.'" />'."\n";
+    return '<input type="hidden" name="'.$name.'" value="'.$value.'" />'."\n";
 }
 
 sub selectbox {
@@ -86,7 +86,7 @@ sub selectbox {
     my $selout="\n<p><b>$title:</b><br />".'<select name="'.$name.'">';
     foreach (sort keys(%options)) {
         $selout.='<option value="'.$_.'"';
-        if ($_ eq $value) { $selout.=' selected'; }
+        if ($_ eq $value) { $selout.=' selected="selected"'; }
         $selout.='>'.&mt($options{$_}).'</option>';
     }
     return $selout.'</select>';
@@ -140,13 +140,13 @@ sub file_dialogs {
     if ($spreadsheet->is_default()) {
         $filename = 'Default';
     }
-    my $save_dialog = '<nobr>'.
+    my $save_dialog = '<span class="LC_nobreak">'.
         '<input type="submit" name="save" value="'.&mt('Save as').'" /> '.
         '<input type="text" name="savefilename" size="30" value="'.
         $truefilename.'" />'.
-        '</nobr>';
+        '</span>';
     my $makedefault_dialog = '<input type="submit" name="makedefault" '.
-        'value="'.&mt('Save as & Make This Sheet the Default').'"/>';
+        'value="'.&mt('Save as &amp; Make This Sheet the Default').'"/>';
     #
     my $link = '<a href="javascript:openbrowser'.
         "('sheet','loadfilename','spreadsheet')\">".&mt('Select Spreadsheet File')."</a>";
@@ -154,9 +154,9 @@ sub file_dialogs {
     my $load_dialog = <<END;
 <table bgcolor="$bgcolor">
 <tr><td><input type="submit" name="load" value="$load" /></td>
-    <td><nobr>
+    <td><span class="LC_nobreak">
         <input type="text" name="loadfilename" size="20" value="$filename" />
-        $link</nobr>
+        $link</span>
     </td></tr>
 <tr><td>&nbsp;</td><td>
     <select name="fileselect" onchange="document.sheet.loadfilename.value=document.sheet.fileselect.value" >
@@ -165,17 +165,18 @@ END
     foreach my $sheetfilename ($spreadsheet->othersheets()) {
         $load_dialog .= '    <option value="'.$sheetfilename.'"';
         if ($filename eq $sheetfilename) {
-            $load_dialog .= ' selected';
+            $load_dialog .= ' selected="selected"';
             $default_filename_set = 1;
         }
         $load_dialog .= '>'.$sheetfilename."</option>\n";
     }
     $load_dialog .= "</select>\n</td><td>&nbsp;</td></tr>\n</table>\n";
         #
+    my $headline = &mt('File Dialogs');
     $result .=<<END;
 <!-- 
     <fieldset title="File Dialogs" >
-    <legend>File Dialogs</legend>
+    <legend>$headline</legend>
   -->
 <!-- load / save dialogs -->
 <table cellspacing="2">
