@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonproblemstatistics.pm,v 1.117 2009/03/05 09:12:14 bisitz Exp $
+# $Id: lonproblemstatistics.pm,v 1.118 2010/02/28 23:58:54 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1457,7 +1457,7 @@ sub compute_statistics_on_sequence {
     my @Data;
     foreach my $res (&Apache::lonstathelpers::get_resources($navmap,$seq)) {
         foreach my $part (@{$res->parts}) {
-            next if ($res->is_survey($part));
+            next if (($res->is_survey($part)) || ($res->is_anonsurvey($part))) ;
             #
             # This is where all the work happens
             my $data = &get_statistics($seq,$res,$part,scalar(@StatsArray)+1);
