@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonstudentassessment.pm,v 1.150.2.5 2010/04/14 07:08:00 raeburn Exp $
+# $Id: lonstudentassessment.pm,v 1.162 2010/06/09 14:55:27 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -255,7 +255,7 @@ sub next_and_previous_buttons {
             'document.Statistics.submit();" />';
     } else {
         $previousbutton .= '<input type="button" value="'.
-            &mt('Previous student').'" disabled="disabled" />';
+            &mt('Previous Student').'" disabled="disabled" />';
     }
     #
     # Build the next student link
@@ -267,11 +267,11 @@ sub next_and_previous_buttons {
             &mt('Next Student ([_1])',
             $next->{'username'}.':'.$next->{'domain'}).
             '" onclick="document.Statistics.SelectedStudent.value='.
-            "'$sname'".';'.
+            "'".$sname."'".';'.
             'document.Statistics.submit();" />';
     } else {
         $nextbutton .= '<input type="button" value="'.
-            &mt('Next student').'" disabled="disabled" />';
+            &mt('Next Student').'" disabled="disabled" />';
     }
     #
     # Build the 'all students' button
@@ -361,20 +361,19 @@ sub CreateInterface {
     $Str .= &CreateAndParseOutputDataSelector();
     $Str .= '</td></tr>'."\n";
     $Str .= '</table>'."\n";
-    $Str .= '<p>'.
-            &mt('Status:').' '.
-            '<input type="text" name="stats_status" size="60" value="" readonly="readonly" />'.
-            '</p>';
+    $Str .= '<p>'
+           .&mt('Status:').' '
+           .'<input type="text" name="stats_status" size="60" value="" readonly="readonly" />'
+           .'</p>';
     $Str .= '<input type="submit" name="selectstudent" value="'.
         &mt('Select One Student').'" />';
     $Str .= '&nbsp;'x5;
     $Str .= '<input type="submit" name="ClearCache" value="'.
         &mt('Clear Caches').'" />';
-    $Str .= '<p>'.
-            '<input type="submit" name="Generate Chart"'.
-            ' value="'.&mt('Generate Chart').'" />'.
-            '</p>';
-
+    $Str .= '<p>'
+           .'<input type="submit" name="Generate Chart"'
+           .' value="'.&mt('Generate Chart').'" />'
+           .'</p>';
     return $Str;
 }
 
@@ -556,7 +555,6 @@ my @OutputDataOptions =
 sub HTMLifyOutputDataDescriptions {
     my $Str = '';
     $Str .= '<h2>'.&mt('Output Data').'</h2>'."\n";
-
     $Str .= "<dl>\n";
     foreach my $option (@OutputDataOptions) {
         $Str .= '    <dt>'.$option->{'name'}.'</dt>';
@@ -665,19 +663,20 @@ sub html_initialize {
         &Apache::lonstatistics::selected_sequences_with_assessments();
     if (! ref($navmap)) {
         # Unable to get data, so bail out
-        $r->print('<p class="LC_error">'.
-                  &mt('Unable to retrieve course information.').
-                  '</p>');
+        $r->print('<p class="LC_error">'
+                 .&mt('Unable to retrieve course information.')
+                 .'</p>');
     }
 
     # If we're showing links, show a checkbox to open in new
     # windows.
     if ($show_links ne 'no') {
-        my $labeltext = &mt('Show links in new window:');
+        my $labeltext = &mt('Show links in new window');
         $r->print(<<NEW_WINDOW_CHECKBOX);
 <script type="text/javascript">new_window = true;</script>
-<p><label>$labeltext 
+<p><label> 
 <input type="checkbox" checked="checked" onclick="new_window=this.checked" />
+$labeltext
 </label></p>
 NEW_WINDOW_CHECKBOX
     }
@@ -715,8 +714,8 @@ NEW_WINDOW_CHECKBOX
                 $width{$symb}->{'width_sum'} += 1;            
             }
 	    $total_count += &count_parts($navmap,$seq);
-            # Use 3 digits for the sum
-            $width{$symb}->{'width_sum'} += 3;
+            # Use 6 digits for the sum
+            $width{$symb}->{'width_sum'} += 6;
         }
         # Compute width of maximum
         if ($chosen_output->{'sequence_max'}) {
@@ -724,8 +723,8 @@ NEW_WINDOW_CHECKBOX
                 # One digit for the '/'
                 $width{$symb}->{'width_sum'} +=1;
             }
-            # Use 3 digits for the total
-            $width{$symb}->{'width_sum'}+=3;
+            # Use 6 digits for the total
+            $width{$symb}->{'width_sum'}+=6;
         }
 	#
         if ($chosen_output->{'every_problem'}) {
@@ -827,7 +826,12 @@ sub html_outputstudent {
     return if (! defined($navmap));
     #
     if($count++ % 5 == 0 && $count > 0) {
-        $r->print("</pre><pre>");
+#       $r->print("</pre><pre>");
+        $r->print('</pre>');
+        &Apache::lonhtmlcommon::Increment_PrgWin(
+            $r,\%prog_state,'last five students',5);
+        $r->rflush();
+        $r->print('<pre>');
     }
     # First, the @StudentData fields need to be listed
     my @to_show = &get_student_fields_to_show();
@@ -887,16 +891,17 @@ sub html_outputstudent {
             $ratio .= ' ';
         }
         if ($chosen_output->{'sequence_sum'} && $score ne ' ') {
-            my $score .= sprintf("%3.0f",$score);
-            $ratio .= (' 'x(3-length($score))).$score;
+            my $score .= sprintf("%3.2f",$score);
+            $ratio .= (' 'x(6-length($score))).$score;
         } elsif($chosen_output->{'sequence_sum'}) {
-            $ratio .= ' 'x3;
+            $ratio .= ' 'x6;
         }
         if ($chosen_output->{'sequence_max'}) {
             if ($chosen_output->{'sequence_sum'}) {
                 $ratio .= '/';
             }
-            $ratio .= sprintf("%3.0f",$seq_max);
+            my $sequence_total=sprintf("%3.2f",$seq_max);
+            $ratio .= $sequence_total.(' 'x(6-length($sequence_total)));
         }
         #
         if (! $chosen_output->{'every_problem'}) {
@@ -930,16 +935,16 @@ sub html_outputstudent {
     if (! defined($score)) {
         $score = ' ' x $total_sum_width;
     } else {
-        $score = sprintf("%.0f",$score);
-        $score = (' 'x(3-length($score))).$score;
+        $score = sprintf("%.2f",$score);
+        $score = (' 'x(6-length($score))).$score;
     }
     $Str .= ' '.' 'x($total_sum_width-length($score)).$score.' / '.$max;
     $Str .= " \n";
     #
     $r->print($Str);
     #
-    $r->rflush();
-    &Apache::lonhtmlcommon::Increment_PrgWin($r,\%prog_state,'last student');
+#   $r->rflush();
+#   &Apache::lonhtmlcommon::Increment_PrgWin($r,\%prog_state,'last student');
     return;
 }    
 
