@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonstudentsubmissions.pm,v 1.56 2010/01/14 17:20:51 bisitz Exp $
+# $Id: lonstudentsubmissions.pm,v 1.61 2010/08/24 14:05:19 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -76,6 +76,10 @@ sub BuildStudentSubmissionsPage {
                                    '<div class="LC_info">'.&mt('Loading student data...').'</div>');
     $r->rflush();
     #
+    my %anoncounter =
+         &Apache::lonnet::dump('nohist_anonsurveys',
+                        $env{'course.'.$env{'request.course.id'}.'.domain'},
+                        $env{'course.'.$env{'request.course.id'}.'.num'});
     if (exists($env{'form.problemchoice'}) && 
         ! exists($env{'form.SelectAnother'})) {
         foreach my $button (@SubmitButtons) {
@@ -97,29 +101,104 @@ sub BuildStudentSubmissionsPage {
         # Determine which problems we are to analyze
         my @Symbs = 
             &Apache::lonstathelpers::get_selected_symbs('problemchoice');
-        foreach my $selected (@Symbs) {
-            $r->print('<input type="hidden" name="problemchoice" value="'.
-                      $selected.'" />'.$/);
+
+        # If there are multi-part problems with anonymous survey and named
+        # parts check if named was picked for display.
+        #
+        my %mixed_named; 
+        foreach my $envkey (%env) {
+            if ($envkey =~ /^form\.mixed_(\d+:\d+)$/) {
+                my $item = $1; 
+                if ($env{$envkey} =~ /^symb_(.+)$/) {
+                    my $symb = &unescape($1);
+                    if (ref($mixed_named{$symb}) eq 'ARRAY') {
+                        push(@{$mixed_named{$symb}},$item);
+                    } else {
+                        @{$mixed_named{$symb}} = ($item);
+                    }
+                }
+            }
         }
         #
         # Get resource objects
         my $navmap = Apache::lonnavmaps::navmap->new();
         if (!defined($navmap)) {
+            foreach my $selected (@Symbs) {
+                $r->print('<input type="hidden" name="problemchoice" value="'.
+                          &escape($selected).'" />'.$/);
+                if (ref($mixed_named{$selected}) eq 'ARRAY') {
+                    foreach my $item (@{$mixed_named{$selected}}) {
+                        $r->print('<input type="hidden" name="mixed_'.$item.'" value="'.&escape($selected).'" />'.$/);
+                    }
+                }
+            }
             $r->print('<div class="LC_error">'.&mt("Internal error").'</div>');
             return;
         }
         my %already_seen;
-        my @Problems;
+        my (@Problems,@anonProbs,@namedProbs,$show_named);
         foreach my $symb (@Symbs) {
             my $resource = $navmap->getBySymb($symb);
-            push(@Problems,$resource);
+            my ($hasanon,$hasnamed);
+            if (ref($resource)) {
+                foreach my $partid (@{$resource->parts}) {
+                    if (($anoncounter{$symb."\0".$partid}) || ($resource->is_anonsurvey($partid))) {
+                        unless (exists($mixed_named{$symb})) {
+                            $hasanon = 1;
+                        }
+                    } else {
+                        $hasnamed = 1;
+                    }
+                }
+                if ($hasanon) {
+                    push(@anonProbs,$resource);
+                } elsif ($hasnamed) {
+                    push(@namedProbs,$resource);
+                }
+            }
+        }
+        if (@namedProbs > 0) {
+            @Problems = @namedProbs;
+            $show_named = 1;
+        } elsif (@anonProbs > 0) {
+            @Problems = @anonProbs;
+        } 
+        foreach my $selected (@Symbs) {
+            $r->print('<input type="hidden" name="problemchoice" value="'.
+                      &escape($selected).'" />'.$/);
+            if (ref($mixed_named{$selected}) eq 'ARRAY') {
+                foreach my $item (@{$mixed_named{$selected}}) {
+                    $r->print('<input type="hidden" name="mixed_'.$item.'" value="'.&escape($selected).'" />'.$/);
+                }
+            }
+        }
+        # If these are to be anonymized, do a random shuffle of @Students. 
+        unless ($show_named) {
+            &array_shuffle(\@Students);
+        }
+        #
+
+        my $threshold = $env{'course.'.$env{'request.course.id'}.'.internal.anonsurvey_threshold'};
+        if ($threshold eq '') {
+            my %domconfig =
+                &Apache::lonnet::get_dom('configuration',['coursedefaults'],
+                                        $env{'course.'.$env{'request.course.id'}.'.domain'});
+            if (ref($domconfig{'coursedefaults'}) eq 'HASH') {
+                $threshold = $domconfig{'coursedefaults'}{'anonsurvey_threshold'};
+                if ($threshold eq '') {
+                    $threshold = 10;
+                }
+            } else {
+                $threshold = 10;
+            }
         }
-        # 
         $r->print('<h4>'.
                   &Apache::lonstatistics::section_and_enrollment_description().
                   '</h4>');
         if (! scalar(@Problems) || ! defined($Problems[0])) {
-            $r->print('resource is undefined');
+            $r->print(&mt('resource is undefined'));
+        } elsif (!$show_named && @Students < $threshold) {
+            $r->print(&mt('The number of students matching the selection criteria is too few for display of submission data for anonymous surveys.').'<br />'.&mt('There must be at least [quant,_1,student].',$threshold).' '.&mt('Contact a Domain Coordinator if you need the threshold to be changed for this course.'));
         } else {
             if (scalar(@Problems) == 1) {
                 my $resource = $Problems[0];
@@ -131,11 +210,11 @@ sub BuildStudentSubmissionsPage {
                 }
             }
             if ($env{'form.output'} eq 'excel') {
-                &prepare_excel_output($r,\@Problems,\@Students);
+                &prepare_excel_output($r,\@Problems,\@Students,\%anoncounter,$show_named);
             } elsif ($env{'form.output'} eq 'csv') {
-                &prepare_csv_output($r,\@Problems,\@Students);
+                &prepare_csv_output($r,\@Problems,\@Students,\%anoncounter,$show_named);
             } else {
-                &prepare_html_output($r,\@Problems,\@Students);
+                &prepare_html_output($r,\@Problems,\@Students,\%anoncounter,$show_named);
             }
         }
         $r->print('<hr />');
@@ -144,29 +223,46 @@ sub BuildStudentSubmissionsPage {
                   &mt('Prepare Report').'" />');
         $r->print('&nbsp;'x5);
         $r->print('<p>'.
-                  &mt('Computing correct answers greatly increasese the amount of time required to prepare a report.').
+                  &mt('Computing correct answers greatly increases the amount of time required to prepare a report.').
                   '</p>');
         $r->print('<p>'.
                   &mt('Please select problems and use the [_1]Prepare Report[_2] button to continue.','<b>','</b>').
                   '</p>');
         $r->print(&Apache::lonstathelpers::MultipleProblemSelector
-                  (undef,'problemchoice','Statistics'));
+                  (undef,'problemchoice','Statistics',\%anoncounter));
     }
 }
 
+sub array_shuffle {
+    my $array = shift;
+    return unless (ref($array) eq 'ARRAY');
+    my $i = scalar(@$array);
+    my $j;
+    foreach my $item (@$array) {
+        --$i;
+        $j = int(rand($i+1));
+        next if($i == $j);
+        @$array [$i,$j] = @$array[$j,$i];
+    }
+    return @$array;
+}
+
 ##
 ## get_extra_response_headers
 ##
 sub get_extra_response_headers {
+    my ($show_named) = @_;
     my @extra_resp_headers;
     if ($env{'form.correctans'} eq 'true') {
         push(@extra_resp_headers,'Correct');
-    } 
-    if ($env{'form.prob_status'} eq 'true') {
-        push(@extra_resp_headers,'Award Detail'); 
-        push(@extra_resp_headers,'Time');
-        push(@extra_resp_headers,'Attempt');
-        push(@extra_resp_headers,'Awarded');
+    }
+    if ($show_named) { 
+        if ($env{'form.prob_status'} eq 'true') {
+            push(@extra_resp_headers,'Award Detail'); 
+            push(@extra_resp_headers,'Time');
+            push(@extra_resp_headers,'Attempt');
+            push(@extra_resp_headers,'Awarded');
+        }
     }
     return @extra_resp_headers;
 }
@@ -211,7 +307,7 @@ sub get_headers {
 #########################################################
 #########################################################
 sub prepare_html_output {
-    my ($r,$problems,$students) = @_;
+    my ($r,$problems,$students,$anoncounter,$show_named) = @_;
     my $c = $r->connection();
     #
     # Set a flag for the case when there is just one problem
@@ -222,10 +318,18 @@ sub prepare_html_output {
     }
     #
     # Compute the number of columns per response
-    my @extra_resp_headers = &get_extra_response_headers();
+    my @extra_resp_headers = &get_extra_response_headers($show_named);
     #
     # Create the table header
-    my @student_columns = ('username','domain','id','section');
+    my @student_columns;
+    if ($show_named) {
+        @student_columns = @Apache::lonstatistics::SelectedStudentData;
+        if (grep(/^all$/,@student_columns)) {
+            @student_columns = qw(fullname username domain id section status groups comments);
+        }
+    } else {
+        @student_columns = ('username');
+    }
     #
     my %headers;
     my $student_column_count = scalar(@student_columns);
@@ -242,13 +346,21 @@ sub prepare_html_output {
     foreach my $prob (@$problems) {
         my %analysis = &Apache::lonstathelpers::get_problem_data($prob->src);
         $problem_analysis{$prob->src}=\%analysis;
+        my $symb = $prob->symb();
         #
         my $prob_span = 0;
         my $single_part = 0;
         if (scalar(@{$prob->parts}) == 1) {
             $single_part = 1;
         }
+        my $shown_parts = 0;
         foreach my $partid (@{$prob->parts}) {
+            if (($prob->is_anonsurvey($partid)) || ($anoncounter->{$symb."\0".$partid})) {
+                next if ($show_named);
+            } else {
+                next unless ($show_named);
+            }
+            $shown_parts ++;
             my $part_span = 0;
             my $responses = [$prob->responseIds($partid)];
             my $resptypes = [$prob->responseType($partid)];
@@ -289,6 +401,7 @@ sub prepare_html_output {
             }
             $prob_span += $part_span;
         }
+        next if (!$shown_parts);
         my $title = $prob->compTitle;
         if ($prob_span > 0) {
             $headers{'problem'}.= qq{<th colspan="$prob_span">$title</th>};
@@ -325,9 +438,21 @@ sub prepare_html_output {
             $count = 0;
         }
         last if ($c->aborted());
-        foreach my $field (@student_columns) {
-            $student_row_data .= 
-                '<td valign="top">'.$student->{$field}.'</td>';
+        if ($show_named) {
+            foreach my $field (@student_columns) {
+                $student_row_data .= '<td valign="top">';
+                # handle comments like in lonstudentassessment.pm
+                if($field eq 'comments') {
+                    $student_row_data .= 
+                        '<a href="/adm/'.$student->{'domain'}.'/'.
+                        $student->{'username'}.'/'.'aboutme#coursecomment">'.&mt('Comments').'</a>';
+                } else {
+                    $student_row_data .= $student->{$field};
+                }
+                $student_row_data .= '</td>';
+            }
+        } else {
+            $student_row_data = '<td valign="top" colspan="'.$student_column_count.'">'.&mt('Anonymized').'</td>';
         }
         #
         # Figure out what it is we need to output for this student
@@ -335,8 +460,14 @@ sub prepare_html_output {
         my %prob_data;
         my $maxrow;
         foreach my $prob (@$problems) {
-            $prob_data{$prob->symb}={};
+            my $symb = $prob->symb;
+            $prob_data{$symb}={};
             foreach my $partid (@{$prob->parts}) {
+                if (($prob->is_anonsurvey($partid)) || ($anoncounter->{$symb."\0".$partid})) {
+                    next if ($show_named);
+                } else {
+                    next unless ($show_named);
+                }
                 my @responses = $prob->responseIds($partid);
                 my @response_type = $prob->responseType($partid);
                 for (my $i=0;$i<=$#responses;$i++) {
@@ -444,6 +575,7 @@ sub prepare_html_output {
             undef(@essays);
         }
     } # end of student loop
+    $r->print('</table>'.$/);
     return;
 }
 
@@ -625,19 +757,26 @@ sub html_non_essay_results {
 #########################################################
 #########################################################
 sub prepare_excel_output {
-    my ($r,$Problems,$Students) = @_;
+    my ($r,$Problems,$Students,$anoncounter,$show_named) = @_;
     my $c = $r->connection();
     #
     #
     # Determine the number of columns in the spreadsheet
     my $columncount = 3; # username, domain, id
-    my @extra_resp_headers = &get_extra_response_headers();
+    my @extra_resp_headers = &get_extra_response_headers($show_named);
     my $lastprob;
     my %problem_analysis;
     foreach my $prob (@$Problems) {
+        my $symb = $prob->symb();
         my %analysis = &Apache::lonstathelpers::get_problem_data($prob->src);
         $problem_analysis{$prob->src}=\%analysis;
         foreach my $partid (@{$prob->parts}) {
+            if (($prob->is_anonsurvey($partid)) || ($anoncounter->{$symb."\0".$partid})) {
+                next if ($show_named);
+            } else {
+                next unless ($show_named);
+            }
+
             my $responses = [$prob->responseIds($partid)];
             my $resptypes = [$prob->responseType($partid)];
             for (my $i=0;$i<scalar(@$responses);$i++) {
@@ -655,8 +794,10 @@ sub prepare_excel_output {
     if ($columncount > 255) {
         $r->print('<h1>'.&mt('Unable to complete request').'</h1>'.$/.
                   '<p>'.&mt('LON-CAPA is unable to produce your Excel spreadsheet because your selections will result in more than 255 columns.  Excel allows only 255 columns in a spreadsheet.').'</p>'.$/.
-                  '<p>'.&mt('Consider selecting fewer problems to generate reports on, or reducing the number of items per problem.  Or use HTML or CSV output.').'</p>'.$/.
-                  '<p>'.&mt('The last problem that will fit in the current spreadsheet is [_1].',$lastprob->compTitle).'</p>');
+                  '<p>'.&mt('Consider selecting fewer problems to generate reports on, or reducing the number of items per problem.  Or use HTML or CSV output.').'</p>'.$/);
+        if (ref($lastprob)) {
+            $r->print('<p>'.&mt('The last problem that will fit in the current spreadsheet is [_1].',$lastprob->compTitle).'</p>');
+        }
         $r->rflush();
         return;
     }
@@ -695,7 +836,12 @@ sub prepare_excel_output {
     $worksheet->write($partid_row,0,'Part ID',$format->{'bold'});
     $worksheet->write($respid_row,0,'Response ID',$format->{'bold'});
     # Student headers
-    my @StudentColumns = ('username','domain','id','section');
+    my @StudentColumns;
+    if ($show_named) {
+        @StudentColumns = qw(username domain id section);
+    } else {
+         @StudentColumns = qw(username);
+    }
     foreach (@StudentColumns) {
         $worksheet->write($header_row,$cols_output++,ucfirst($_),
                           $format->{'bold'});
@@ -704,9 +850,15 @@ sub prepare_excel_output {
     my %start_col;
     foreach my $prob (@$Problems) {
         my $title = $prob->compTitle;
+        my $symb = $prob->symb();
         $worksheet->write($title_row,$cols_output,
                           $title,$format->{'h3'});
         foreach my $partid (@{$prob->parts}) {
+            if (($prob->is_anonsurvey($partid)) || ($anoncounter->{$symb."\0".$partid})) {
+                next if ($show_named);
+            } else {
+                next unless ($show_named);
+            }
             $worksheet->write($partid_row,$cols_output,
                               $prob->part_display($partid));
             my $responses = [$prob->responseIds($partid)];
@@ -743,12 +895,23 @@ sub prepare_excel_output {
         $cols_output = 0;
         my $student_row = $max_row;
         foreach my $field (@StudentColumns) {
-            $worksheet->write($student_row,$cols_output++,
-                              $student->{$field});
+            if ($show_named) {
+                $worksheet->write($student_row,$cols_output++,
+                                  $student->{$field});
+            } else {
+                $worksheet->write($student_row,$cols_output++,
+                                      &mt('Anonymized'));
+            }
         }
         my $last_student_col = $cols_output-1;
         foreach my $prob (@$Problems) {
+            my $symb = $prob->symb();
             foreach my $partid (@{$prob->parts}) {
+                if (($prob->is_anonsurvey($partid)) || ($anoncounter->{$symb."\0".$partid})) {
+                    next if ($show_named);
+                } else {
+                    next unless ($show_named);
+                }
                 my @Response = $prob->responseIds($partid);
                 my @ResponseType = $prob->responseType($partid);
                 for (my $i=0;$i<=$#Response;$i++) {
@@ -799,8 +962,13 @@ sub prepare_excel_output {
         for (my $row = $student_row+1;$row<$max_row;$row++) {
             my $cols = 0;
             foreach my $field (@StudentColumns) {
-                $worksheet->write($row,$cols++,
-                                  $student->{$field});
+                if ($show_named) {
+                    $worksheet->write($row,$cols++,
+                                      $student->{$field});
+                } else {
+                    $worksheet->write($row,$cols++,
+                                      &mt('Anonymized'));
+                }
             }
         }
         &Apache::lonhtmlcommon::Increment_PrgWin($r,\%prog_state,
@@ -910,7 +1078,7 @@ sub excel_format_item {
 #########################################################
 #########################################################
 sub prepare_csv_output {
-    my ($r,$problems,$students) = @_;
+    my ($r,$problems,$students,$anoncounter,$show_named) = @_;
     my $c = $r->connection();
     #
     $r->print('<h2>'.
@@ -942,10 +1110,16 @@ sub prepare_csv_output {
     }
     #
     # Compute the number of columns per response
-    my @extra_resp_headers = &get_extra_response_headers();
+    my @extra_resp_headers = &get_extra_response_headers($show_named);
     #
     # Create the table header
     my @student_columns = ('username','domain','id','section');
+    if ($show_named) {
+        @student_columns = qw(username domain id section);
+    } else {
+        @student_columns = qw(username);
+    }
+    my $student_column_count = scalar(@student_columns);
     #
     my %headers;
     push(@{$headers{'student'}},@student_columns);
@@ -959,10 +1133,16 @@ sub prepare_csv_output {
     my %start_col;
     my $max_column = scalar(@student_columns);
     foreach my $prob (@$problems) {
+        my $symb = $prob->symb();
         my %analysis = &Apache::lonstathelpers::get_problem_data($prob->src);
         $problem_analysis{$prob->src}=\%analysis;
         $headers{'problem'}->[$max_column] = $prob->compTitle;
         foreach my $partid (@{$prob->parts}) {
+            if (($prob->is_anonsurvey($partid)) || ($anoncounter->{$symb."\0".$partid})) {
+                next if ($show_named);
+            } else {
+                next unless ($show_named);
+            }
             $headers{'part'}->[$max_column] = $prob->part_display($partid);
             my $responses = [$prob->responseIds($partid)];
             my $resptypes = [$prob->responseType($partid)];
@@ -996,7 +1176,13 @@ sub prepare_csv_output {
         last if ($c->aborted());
         my @rows;
         foreach my $prob (@$problems) {
+            my $symb = $prob->symb;
             foreach my $partid (@{$prob->parts}) {
+                if (($prob->is_anonsurvey($partid)) || ($anoncounter->{$symb."\0".$partid})) {
+                    next if ($show_named); 
+                } else {
+                    next unless ($show_named);
+                }
                 my @responses = $prob->responseIds($partid);
                 my @response_type = $prob->responseType($partid);
                 for (my $i=0;$i<=$#responses;$i++) {
@@ -1034,10 +1220,16 @@ sub prepare_csv_output {
             }
         }
         foreach my $row (@rows) {
-            print $outputfile '"'.join('","',
-                                       map { $student->{$_}; }
-                                       @student_columns).'"';
-            for (my $i=scalar(@student_columns);$i<$max_column;$i++) {
+            my $student_row_data = '';
+            if ($show_named) {
+                $student_row_data = '"'.join('","',
+                                        map { $student->{$_}; }
+                                        @student_columns).'"';
+            } else {
+                $student_row_data = '"'.&mt('Anonymized').'"';
+            }
+            print $outputfile $student_row_data;
+            for (my $i=$student_column_count;$i<$max_column;$i++) {
                 my $value = &Apache::loncommon::csv_translate($row->[$i]);
                 $value ||='';
                 print $outputfile ',"'.$value.'"';
@@ -1083,7 +1275,7 @@ sub CreateInterface {
     foreach ('HTML','Excel','CSV') {
         $output_selector .= '    <option value="'.lc($_).'"';
         if ($env{'form.output'} eq lc($_)) {
-            $output_selector .= ' selected ';
+            $output_selector .= ' selected="selected"';
         }
         $output_selector .='>'.&mt($_).'</option>'.$/;
     } 
@@ -1092,11 +1284,12 @@ sub CreateInterface {
     ## Environment variable initialization
     my $Str = '';
     $Str .= &Apache::lonhtmlcommon::breadcrumbs('Student Submission Reports');
-    $Str .= '<p>';
+    $Str .= '<br />';
     $Str .= &Apache::loncommon::start_data_table();
     $Str .= &Apache::loncommon::start_data_table_header_row();
     $Str .= '<th>'.&mt('Sections').'</th>';
     $Str .= '<th>'.&mt('Groups').'</th>';
+    $Str .= '<th>'.&mt('Student Data').&Apache::loncommon::help_open_topic("Chart_Student_Data").'</th>';
     $Str .= '<th>'.&mt('Access Status').'</th>';
     $Str .= '<th>'.&mt('Options').'</th>';
     $Str .= '<th>'.&mt('Output Format').'</th>';
@@ -1111,6 +1304,10 @@ sub CreateInterface {
     $Str .= &Apache::lonstatistics::GroupSelect('Group','multiple',5);
     $Str .= '</td>';
     #
+    $Str .= '<td align="center">'."\n";
+    $Str .= &Apache::lonstatistics::StudentDataSelect('StudentData','multiple', 5,undef);
+    $Str .= '</td>';
+    #
     $Str .= '<td align="center">';
     $Str .= &Apache::lonhtmlcommon::StatusOptions(undef,undef,5);
     $Str .= '</td>';
@@ -1171,7 +1368,6 @@ sub CreateInterface {
                     '<input type="text" name="stats_status"'
                    .' size="60" value="" readonly="readonly" />')
            .'</span></p>';
-    $Str .= '</p>';
     ##
     return $Str;
 }
