@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Arabic Localization Lexicon
 #
-# $Id: ar.pm,v 1.17 2009/05/07 12:42:17 bisitz Exp $
+# $Id: ar.pm,v 1.19 2010/05/03 10:53:20 bisitz Exp $
 #
 # Copyright i-Learning Limited Partnership Company
 #
@@ -34,7 +34,7 @@ use base qw(Apache::localize);
 %Lexicon=('_AUTO' => 1,
 'language_code' => 'ar',
 'char_encoding' => 'UTF-8',
-'date_locale'  => 
+'date_locale'  =>
       '$weekday, $day.$month.$year, $twentyfour:$minutes:$seconds',
 'date_months'  => ' يناير,فبراير,مارس,أبريل,مايو,يونيو,يوليو,أغسطس,سبتمبر,أكتوبر,نوفمبر,ديسمبر',
 'date_days'    => 'الأحد,الإثنين,الثلاثاء,الأربعاء,الخميس, الجمعة,السبت ',
@@ -891,7 +891,7 @@ use base qw(Apache::localize);
    'Create a new course'
 => ' إنشاء دورة جديدة',
 
-   'Customized right of use ...	'
+   'Customized right of use ...'
 => ' ... حق طلب استخدام',
 
    'Delete messages from bulletin boards'
@@ -1402,81 +1402,87 @@ use base qw(Apache::localize);
    '. . . for an individual student'
 => '. . . لطالب واحد',
 
-   '1 am'
-=> '1 صباحاً',
-
    '1 out of N multiple choice (radio button)'
 => 'واحدة من  خيارات',
 
-   '1 pm'
-=> '1 مساءً',
-
-   '10 am'
-=> '10 صباحاً',
-
-   '10 pm'
-=> '10 مساءً',
-
-   '11 am'
-=> '11 صباحاً',
-
-   '11 pm'
-=> '11 مساءً',
-
-   '12 am'
+   '12 am' # midnight
 => '12 قبل الظهرً',
 
-   '12 noon'
-=> '12 ظهراً',
+   'midnight'
+=> 'نصف الليل',
+
+   '1 am'
+=> '1 صباحاً',
 
    '2 am'
 => '2 مساءً',
 
-   '2 pm'
-=> '2 مساءً',
-
    '3 am'
 => '3 صباحاً',
 
-   '3 pm'
-=> '3 مساءً',
-
    '4 am'
 => '4 صباحاً',
 
-   '4 pm'
-=> '4 مساءً',
-
    '5 am'
 => '5 صباحاً',
 
-   '5 pm'
-=> '5 مساءً',
-
    '6 am'
 => '6 صباحاً',
 
-   '6 pm'
-=> '6 مساءً',
-
    '7 am'
 => '7 صباحاً',
 
-   '7 pm'
-=> '7 مساءً',
-
    '8 am'
 => '8 صباحاً',
 
-   '8 pm'
-=> '8 مساءً',
-
    '9 am'
 => '9 صباحاً',
 
+   '10 am'
+=> '10 صباحاً',
+
+   '11 am'
+=> '11 صباحاً',
+
+   '12 noon'
+=> '12 ظهراً',
+
+   'noon'
+=> 'الظهر',
+
+   '1 pm'
+=> '1 مساءً',
+
+   '2 pm'
+=> '2 مساءً',
+
+   '3 pm'
+=> '3 مساءً',
+
+   '4 pm'
+=> '4 مساءً',
+
+   '5 pm'
+=> '5 مساءً',
+
+   '6 pm'
+=> '6 مساءً',
+
+   '7 pm'
+=> '7 مساءً',
+
+   '8 pm'
+=> '8 مساءً',
+
    '9 pm'
 => '9 مساءً',
 
+   '10 pm'
+=> '10 مساءً',
+
+   '11 pm'
+=> '11 مساءً',
+
    '<- Previous'
 => '<- سابق',
 
@@ -3019,9 +3025,6 @@ use base qw(Apache::localize);
    'manage'
 => 'إدارة',
 
-   'midnight'
-=> 'نصف الليل',
-
    'minutes'
 => 'دقائق',
 
@@ -3037,9 +3040,6 @@ use base qw(Apache::localize);
    'name only visible to course faculty'
 => 'لا يمكن مشاهدة الاسم إلا للهيئة العلمية في الدورة',
 
-   'noon'
-=> 'الظهر',
-
    'notes'
 => 'مذكرات',
 
