@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Localization routines
 #
-# $Id: lonlocal.pm,v 1.60 2009/10/01 20:22:33 raeburn Exp $
+# $Id: lonlocal.pm,v 1.62 2011/03/28 21:10:41 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -295,13 +295,12 @@ sub get_genlanguages {
 
 sub current_encoding {
     my $default='UTF-8';
-# UTF-8 character encoding needed for the whole LON-CAPA system
-# (interface language and homework problem content)
-# See Bugzilla 5702 vs. 2189 and 4067
-#    if ($Apache::lonnet::env{'browser.os'} eq 'win' && 
-#	$Apache::lonnet::env{'browser.type'} eq 'explorer') {
-#        $default='ISO-8859-1';
-#    }
+    unless ($Apache::lonnet::env{'browser.unicode'}) {
+        if ($Apache::lonnet::env{'browser.os'} eq 'win' && 
+	    $Apache::lonnet::env{'browser.type'} eq 'explorer') {
+            $default='ISO-8859-1';
+        }
+    }
     if ($lh) {
 	my $enc=$lh->maketext('char_encoding');
 	return ($enc eq 'char_encoding'?$default:$enc);
@@ -335,12 +334,17 @@ sub texthash {
 # ========= Get a handle (do not invoke in vain, leave this to access handlers)
 
 sub get_language_handle {
-    my $r=shift;
+    my ($r,$chosen) = @_;
     if ($r) {
 	my $headers=$r->headers_in;
 	$ENV{'HTTP_ACCEPT_LANGUAGE'}=$headers->{'Accept-language'};
     }
-    my @languages=&preferred_languages();
+    my @languages;
+    if ($chosen ne '') {
+        @languages=($chosen);
+    } else {
+        @languages=&preferred_languages();
+    }
     $ENV{'HTTP_ACCEPT_LANGUAGE'}='';
     $lh=Apache::localize->get_handle(@languages);
     $current_language=&current_language();
@@ -570,6 +574,44 @@ sub mt_escape {
     $$str_ref =~s/([\[\]])/~$1/g;
 }
 
+=pod
+
+=item * choose_language
+
+choose_language prompts a user to enter a two letter language code via
+keyboard when running a script from the command line. Default is en.
+
+=cut
+
+sub choose_language {
+    my %languages = (
+                      ar => 'Arabic',
+                      de => 'German',
+                      en => 'English',
+                      es => 'Spanish',
+                      fa => 'Persian',
+                      fr => 'French',
+                      he => 'Hebrew',
+                      ja => 'Japanese',
+                      pt => 'Portuguese',
+                      ru => 'Russian',
+                      tr => 'Turkish',
+                      zh => 'Chinese (Simplified)'
+                   );
+    my @posslangs = sort(keys(%languages));
+    my $langlist = join('|',@posslangs);
+    my $lang = 'en';
+    print 'Language: English (en). Change? ['.$langlist.']? ';
+    my $langchoice = <STDIN>;
+    chomp($langchoice);
+    $langchoice =~ s/(^\s+|\s+$)//g;
+    $langchoice = lc($langchoice);
+    if (defined($languages{$langchoice})) {
+        $lang = $langchoice;
+    }
+    return $lang;
+}
+
 1;
 
 __END__
