@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Construction Space Page Wrapper for Construction
 #
-# $Id: lonconstruct.pm,v 1.34 2008/02/03 01:11:01 raeburn Exp $
+# $Id: lonconstruct.pm,v 1.35 2008/11/19 19:15:02 jms Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -27,17 +27,23 @@
 #
 #
 
-package Apache::lonconstruct;
 
-
-use strict;
-use Apache::Constants qw(:common :http :methods);
-use Apache::lonnet;
-use HTML::Entities();
-
-my $DEBUG = 0;
 =pod
 
+=head1
+
+=head1 NAME
+
+Apache::lonconstruct
+
+=head1 SYNOPSIS
+
+Page wrapper for handling construction space.
+
+This is part of the LearningOnline Network with CAPA project
+described at http://www.lon-capa.org.
+
+
 =item Debug($request, $message)
 
   If debugging is enabled puts out a debuggin message determined by the
@@ -59,6 +65,17 @@ my $DEBUG = 0;
 
 =cut
 
+package Apache::lonconstruct;
+
+
+use strict;
+use Apache::Constants qw(:common :http :methods);
+use Apache::lonnet;
+use HTML::Entities();
+
+my $DEBUG = 0;
+
+
 sub Debug {
     # Put out the indicated message but only if DEBUG is true.
     if ($DEBUG) {
