@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Construction Space Directory Lister
 #
-# $Id: lonpubdir.pm,v 1.114.2.2 2010/02/12 16:04:18 raeburn Exp $
+# $Id: lonpubdir.pm,v 1.125 2009/11/18 20:48:06 droeschl Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -105,15 +105,16 @@ sub handler {
   my $numres = 0;
   
   # Start off the directory table.
-  $r->print('<h3>'.&mt('Directory Contents:').'</h3>');
-  $r->print('<table id="LC_browser"><tr>'.
-            '<th>'.&mt('Type').'</th>'.
-            '<th>'.&mt('Actions').'</th>'.
-            '<th>'.&mt('Name').'</th>'.
-            '<th>'.&mt('Title').'</th>'.
-	    '<th>'.&mt('Status').'</th>'.
-            '<th>'.&mt('Last Modified').
-	    '</th></tr>'."\n");
+  $r->print(&Apache::loncommon::start_data_table()
+           .&Apache::loncommon::start_data_table_header_row()
+           .'<th>'.&mt('Type').'</th>'
+           .'<th>'.&mt('Actions').'</th>'
+           .'<th>'.&mt('Name').'</th>'
+           .'<th>'.&mt('Title').'</th>'
+           .'<th colspan="2">'.&mt('Status').'</th>'
+           .'<th>'.&mt('Last Modified').'</th>'
+           .&Apache::loncommon::end_data_table_header_row()
+  );
 
   my $filename;
   my $dirptr=16384;		# Mask indicating a directory in stat.cmode.
@@ -139,7 +140,9 @@ sub handler {
   }
   closedir(DIR);
 
-  $r->print('</table>'.&Apache::loncommon::end_page());
+  $r->print(&Apache::loncommon::end_data_table()
+           .&Apache::loncommon::end_page()
+  );
   return OK;  
 }
 #
@@ -156,8 +159,7 @@ sub getEffectiveUrl {
 	#   Replace the ~username of the URL with /home/username/public_html
 	#   so that we don't have to worry about ~ expansion internally.
 	#
-        $fn=~s/^https?\:\/\/[^\/]+\///;
-
+	$fn=~s/^https?\:\/\/[^\/]+\///;
         $fn=~s/^\///;
         $fn=~s{~($LONCAPA::username_re)}{/home/$1/public_html};
 	
@@ -197,26 +199,27 @@ sub startpage {
 
     my $formaction='/priv/'.$uname.$thisdisfn.'/';
     $formaction=~s|/+|/|g;
-    my $pagetitle .= &Apache::loncommon::help_open_menu('','',3,'Authoring').
-        '<font face="Arial, Helvetica, sans-serif" size="+1"><b>'.&mt('Construction Space').'</b>:</font>&nbsp;'.
-        '<form name="dirs" method="post" action="'.$formaction.
-        '" target="_parent"><tt><b>'.
-        &Apache::lonhtmlcommon::crumbs($uname.$thisdisfn.'/','_top','/priv','','+1',1)."</b></tt><br />".
-        &Apache::lonhtmlcommon::select_recent('construct','recent',
-                 'this.form.action=this.form.recent.value;this.form.submit()').
-              '</form>';
     &Apache::lonhtmlcommon::store_recent('construct',$formaction,$formaction);
+
+    &Apache::lonhtmlcommon::clear_breadcrumbs();
+    &Apache::lonhtmlcommon::add_breadcrumb({
+        'text'  => 'Construction Space',
+        'href'  => &Apache::loncommon::authorspace(),
+    });
+    # breadcrumbs (and tools) will be created 
+    # in start_page->bodytag->innerregister
+
     if ($env{'environment.remote'} eq 'off') {
-	$env{'request.noversionuri'}=$currdir.'/';
-	$r->print(&Apache::loncommon::start_page('Construction Space',undef,
-						 {'body_title' =>
-						      $pagetitle,}));
+        $env{'request.noversionuri'}=$currdir.'/';
+        $r->print(&Apache::loncommon::start_page('Construction Space',undef));
     } else {
-	$r->print(&Apache::loncommon::start_page('Construction Space',undef,
-						 { 'only_body' => 1,}));
-	$r->print($pagetitle);
+        $r->print(&Apache::loncommon::start_page('Construction Space',undef,
+                                                 { 'only_body' => 1,}));
     }
 
+    $r->print(&Apache::loncommon::head_subbox(
+                &Apache::loncommon::CSTR_pageheader(1)));
+
     my $esc_thisdisfn = &Apache::loncommon::escape_single($thisdisfn);
     my $doctitle = 'LON-CAPA '.&mt('Construction Space');
     my $newname = &mt('New Name');
@@ -373,42 +376,46 @@ sub dircontrols {
                                       );
     my $mytype = $lt{'type'}; # avoid conflict with " and ' in javascript
     $r->print(<<END);
-        <table id="LC_cstr_controls">
-         <tr>
-          <th>$lt{'acti'}</th>
-          <th>$lt{'updc'}</th>
-          <th>$lt{'crea'}</th>
-        </tr>
-        <tr>
-         <td>
-          <form name="curractions" method="post" action="">
-           <select name="dirtask" onchange="currdiract(this.form)">
+<div class="LC_columnSection">
+  <div>
+    <form name="curractions" method="post" action="">
+      <fieldset>
+        <legend>$lt{'acti'}</legend>
+        <select name="dirtask" onchange="currdiract(this.form)">
             <option>$lt{'sela'}</option>
             <option value="publish">$lt{'pubd'}</option>
             <option value="editmeta">$lt{'edit'}</option>
             <option value="printdir">$lt{'prnt'}</option>
             <option value="delete">$lt{'dedr'}</option>
-           </select>
-           <input type="hidden" name="filename" value="/~$uname$thisdisfn/" />
-          </form>
-          <form name="publishdir" method="post" action="/adm/publish" target="_parent">
-           <input type="hidden" name="pubrec" value="" />
-           <input type="hidden" name="filename" value="" />
-          </form>
-          <form name="printdir" method="post" action="/adm/printout" target="_parent">
-           <input type="hidden" name="postdata" value="" />
-          </form>
-         </td>
-         <td>
-	    <form name="upublisher" enctype="multipart/form-data" method="post" action="/adm/upload" target="_parent">
-	      <input type="hidden" name="filename" value="/~$uname$thisdisfn/" />
-	      <input type="file" name="upfile" size="20" />
-	      <input type="button" value="$lt{'uplo'}"  onclick="checkUpload(this.form)" />
-	    </form>
-	 </td>
-	 <td>
-	    <form name="fileaction" method="post" action="/adm/cfile" target="_parent">
-	      <span style="white-space: nowrap">
+        </select>
+        <input type="hidden" name="filename" value="/~$uname$thisdisfn/" />
+      </fieldset>
+    </form>
+    <form name="publishdir" method="post" action="/adm/publish" target="_parent">
+      <input type="hidden" name="pubrec" value="" />
+      <input type="hidden" name="filename" value="" />
+    </form>
+    <form name="printdir" method="post" action="/adm/printout" target="_parent">
+      <input type="hidden" name="postdata" value="" />
+    </form>
+  </div>
+
+  <div>
+    <form name="upublisher" enctype="multipart/form-data" method="post" action="/adm/upload" target="_parent">
+      <fieldset>
+        <legend>$lt{'updc'}</legend>
+        <input type="hidden" name="filename" value="/~$uname$thisdisfn/" />
+        <input type="file" name="upfile" size="20" />
+        <input type="button" value="$lt{'uplo'}"  onclick="checkUpload(this.form)" />
+      </fieldset>
+    </form>
+  </div>
+
+  <div>
+    <form name="fileaction" method="post" action="/adm/cfile" target="_parent">
+      <fieldset>
+              <legend>$lt{'crea'}</legend>
+	      <span class="LC_nobreak">
 		<input type="hidden" name="filename" value="/~$uname$thisdisfn/" />
                   <script type="text/javascript">
                     function validate_go() {
@@ -434,10 +441,10 @@ sub dircontrols {
 	            <option value="newdir">$lt{'nsub'}:</option>
 		  </select>&nbsp;<input type="text" name="newfilename" value="$lt{'type'}" onfocus="if (this.value == '$mytype') this.value=''" />&nbsp;<input type="button" value="Go" onclick="validate_go();" />
 		 </span>
-		</form>
-	  </td>
-         </tr>
-        </table>
+      </fieldset>
+    </form>
+  </div>
+</div>
 END
 }
 
@@ -562,11 +569,11 @@ sub putdirectory {
         }
 	$r->print('<tr class="LC_browser_folder">'.
 		  '<td><img src="'.
-		  $Apache::lonnet::perlvar{'lonIconsURL'}.'/folder_closed.gif" alt="folder" /></td>'.
+		  $Apache::lonnet::perlvar{'lonIconsURL'}.'/navmap.folder.closed.gif" alt="folder" /></td>'.
 		  '<td>'.$actionitem.'</td>'.
 		  '<td><span class="LC_filename"><a href="'.&HTML::Entities::encode($here.'/'.$dirname,'<>&"').'/" target="_parent">'.
 		  $disfilename.'</a></span></td>'.
-		        '<td colspan="2">'.($kaputt?&Apache::lonhtmlcommon::authorbombs($resdir.'/'.$disfilename.'/'):'').$Apache::lonpublisher::metadatafields{'title'});
+		        '<td colspan="3">'.($kaputt?&Apache::lonhtmlcommon::authorbombs($resdir.'/'.$disfilename.'/'):'').$Apache::lonpublisher::metadatafields{'title'});
 	if ($Apache::lonpublisher::metadatafields{'subject'} ne '') {
 	    $r->print(' <i>'.
 		      $Apache::lonpublisher::metadatafields{'subject'}.
@@ -696,7 +703,7 @@ sub putresource {
     }
     my $pub_select = '';
     &create_pubselect($r,\$pub_select,$udom,$uname,$thisdisfn,$filename,$resdir,$pubstatus,$publish_button,$numres);
-    $r->print('<tr class="LC_browser_file_'.$pubstatus.'">'.
+    $r->print(&Apache::loncommon::start_data_table_row().
 	      '<td>'.($filename=~/[\#\~]$/?'&nbsp;':
 		      '<img src="'.&Apache::loncommon::icon($filename).'" alt="" />').'</td>'.
               '<td>'.$pub_select.'</td>'.
@@ -705,9 +712,11 @@ sub putresource {
                $filename.'</a></span>'.$editlink2.$editlink.
 	      '</td>'.
 	      '<td>'.$title.'</td>'.
-	      '<td>'.$status.'</td>'.
+              '<td class="LC_browser_file_'.$pubstatus.'">&nbsp;&nbsp;</td>'. # Display publication status
+              '<td>'.$status.'</td>'.
 	      '<td>'.&Apache::lonlocal::locallocaltime($cmtime).'</td>'.
-	      "</tr>\n");
+	      &Apache::loncommon::end_data_table_row()
+    );
     return OK;
 }
 
