@@ -2,7 +2,7 @@
 # The LearningOnline Network with CAPA
 # Handler to upload files into construction space
 #
-# $Id: lonupload.pm,v 1.46.6.1 2009/10/07 21:09:21 raeburn Exp $
+# $Id: lonupload.pm,v 1.53 2010/12/26 03:09:11 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -70,7 +70,7 @@ Start page output
 
 =item *
 
-output relevant interface phase (phaseone or phasetwo or phasethree)
+output relevant interface phase (phaseone, phasetwo, phasethree or phasefour)
 
 =item *
 
@@ -99,6 +99,11 @@ as overwriting an existing file).
 Interface for handling secondary uploads of embedded objects
 in an html file.
 
+=item phasefour()
+
+Interface for handling optional renaming of links to embedded
+objects. 
+
 =item upfile_store()
 
 Store contents of uploaded file into temporary space.  Invoked
@@ -165,59 +170,74 @@ sub phaseone {
     } elsif ($mode eq 'imsimport') {
         $action = '/adm/imsimport';
     }
+
+    # Check for file to be uploaded
     $env{'form.upfile.filename'}=~s/\\/\//g;
     $env{'form.upfile.filename'}=~s/^.*\/([^\/]+)$/$1/;
-    if ($env{'form.upfile.filename'}) {
-	$fn=~s/\/[^\/]+$//;
-	$fn=~s/([^\/])$/$1\//;
-	$fn.=$env{'form.upfile.filename'};
-	$fn=~s/^\///;
-	$fn=~s/(\/)+/\//g;
+    if (!$env{'form.upfile.filename'}) {
+        $r->print('<p class="LC_warning">'.&mt('No upload file specified.').'</p>');
+        return;
+    }
 
-#    Fn is the full path to the destination filename.
-#    
+    $fn=~s/\/[^\/]+$//;
+    $fn=~s/([^\/])$/$1\//;
+    $fn.=$env{'form.upfile.filename'};
+    $fn=~s/^\///;
+    $fn=~s/(\/)+/\//g;
+    #    Fn is the full path to the destination filename.
 
-	&Debug($r, "Filename for upload: $fn");
-	if (($fn) && ($fn!~/\/$/)) {
-	    $r->print('<form action="'.$action.'" method="post" name="fileupload">'.
-		      '<input type="hidden" name="phase" value="two" />'.
-		      '<input type="hidden" name="datatoken" value="'.
-		      &upfile_store.'" />'.
-		      '<input type="hidden" name="uploaduname" value="'.$uname.
-		      '" />'.&mt('Save uploaded file as [_1]',
-                      "<span class='LC_filename'>/priv/$uname/</span>".
-                      '<input type="text" size="50" name="filename" value="'.$fn.
-                      '" />').
-                      '<br />'.
-		      '<br />'.&mt('Choose file type:').'
-<select name="filetype">
- <option value="standard" selected="selected">'.&mt('Regular file').'</option>
- <option value="testbank">'.&mt('Testbank file').'</option>
- <option value="imsimport">'.&mt('IMS package').'</option>
-</select>'.&Apache::loncommon::help_open_topic("Uploading_File_Options").'
-<br />
-<br />
-');
-            $r->print('<input type="button" value="'.&mt('Upload').'" onclick="javascript:verifyForm()"/></form>');
-	    # Check for bad extension and warn user
-	    if ($fn=~/\.(\w+)$/ && 
-		(&Apache::loncommon::fileembstyle($1) eq 'hdn')) {
+    # Check for illegal filename
+    &Debug($r, "Filename for upload: $fn");
+    if (!(($fn) && ($fn!~/\/$/))) {
+        $r->print('<p class="LC_warning">'.&mt('Illegal filename.').'</p>');
+        return;
+    }
+
+    # Display additional options for upload
+    # and upload button
+    $r->print(
+        '<form action="'.$action.'" method="post" name="fileupload">'
+       .'<input type="hidden" name="phase" value="two" />'
+       .'<input type="hidden" name="datatoken" value="'.&upfile_store.'" />'
+       .'<input type="hidden" name="uploaduname" value="'.$uname.'" />'
+    );
+    $r->print(
+        &Apache::lonhtmlcommon::start_pick_box()
+       .&Apache::lonhtmlcommon::row_title(&mt('Save uploaded file as'))
+       .'<span class="LC_filename">/priv/'.$uname.'/</span>'
+       .'<input type="text" size="50" name="filename" value="'.$fn.'" />'
+       .&Apache::lonhtmlcommon::row_closure()
+       .&Apache::lonhtmlcommon::row_title(&mt('File Type'))
+       .'<select name="filetype">'
+       .'<option value="standard" selected="selected">'.&mt('Regular file').'</option>'
+       .'<option value="testbank">'.&mt('Testbank file').'</option>'
+       .'<option value="imsimport">'.&mt('IMS package').'</option>'
+       .'</select>'.&Apache::loncommon::help_open_topic("Uploading_File_Options")
+       .&Apache::lonhtmlcommon::row_closure(1)
+       .&Apache::lonhtmlcommon::end_pick_box()
+    );
+    $r->print(
+        '<p>'
+       .'<input type="button" value="'.&mt('Upload').'" onclick="javascript:verifyForm()"/>'
+       .'</p>'
+       .'</form>'
+    );
+
+   # Check for bad extension and warn user
+    if ($fn=~/\.(\w+)$/ && 
+        (&Apache::loncommon::fileembstyle($1) eq 'hdn')) {
                 $r->print('<p class="LC_error">'
-                          .&mt('The extension on this file, [_1], is reserved internally by LON-CAPA.','"'.$1.'"')
+                          .&mt('The extension on this file, [_1], is reserved internally by LON-CAPA.',
+                               '<span class="LC_filename">'.$1.'</span>')
                           .' <br />'.&mt('Please change the extension.')
                           .'</p>');
-	    } elsif($fn=~/\.(\w+)$/ && 
-		    !defined(&Apache::loncommon::fileembstyle($1))) {
+    } elsif($fn=~/\.(\w+)$/ && 
+                    !defined(&Apache::loncommon::fileembstyle($1))) {
                 $r->print('<p class="LC_error">'
-                         .&mt('The extension on this file, [_1], is not recognized by LON-CAPA.','"'.$1.'"')
+                         .&mt('The extension on this file, [_1], is not recognized by LON-CAPA.',
+                              '<span class="LC_filename">'.$1.'</span>')
                          .' <br />'.&mt('Please change the extension.')
                          .'</p>');
-	    }
-	} else {
-	    $r->print('<span class="LC_error">'.&mt('Illegal filename.').'</span>');
-	}
-    } else {
-	$r->print('<span class="LC_error">'.&mt('No upload file specified.').'</span>');
     }
 }
 
@@ -250,17 +270,22 @@ sub phasetwo {
                 my $source=$r->dir_config('lonDaemons').'/tmp/'.$datatoken.'.tmp';
                 my $dirpath=$path.'/';
                 $dirpath=~s/\/+/\//g;
-                $output .= &mt('Upload cancelled.').'<br /><font size="+2"><a href="'.$dirpath.'">'.
-                          &mt('Back to Directory').'</a></font>';
-	    } elsif ((-e $target) && (!$env{'form.override'})) {
-		$output .= '<form action="'.$action.'" method="post">'.
-			  &mt('File [_1] exists. Overwrite?','<span class="LC_filename">'.$fn.'</span>').
-			  '<input type="hidden" name="phase" value="two" />'.
-			  '<input type="hidden" name="filename" value="'.$url.'" />'.
-			  '<input type="hidden" name="datatoken" value="'.$datatoken.'" />'.
-			  '<input type="submit" name="override" value="'.&mt('Yes').'" />'.
-                          '<input type="submit" name="cancel" value="'.&mt('Cancel').'" />'.
-                          '</form>';
+                $output .= '<p class="LC_warning">'.&mt('Upload cancelled.').'</p>'
+                          .'<p><a href="'.$dirpath.'">'.
+                          &mt('Back to Directory').'</a></p>';
+            } elsif ((-e $target) && (!$env{'form.override'})) {
+                $output .= '<form action="'.$action.'" method="post">'
+                          .'<p class="LC_warning">'
+                          .&mt('File [_1] already exists.',
+                               '<span class="LC_filename">'.$fn.'</span>')
+                         .'<input type="hidden" name="phase" value="two" />'
+                         .'<input type="hidden" name="filename" value="'.$url.'" />'
+                         .'<input type="hidden" name="datatoken" value="'.$datatoken.'" />'
+                         .'<p>'
+                         .'<input type="submit" name="cancel" value="'.&mt('Cancel').'" />'
+                         .' <input type="submit" name="override" value="'.&mt('Overwrite').'" />'
+                         .'</p>'
+                         .'</form>';
             } else {
 		my $source=$r->dir_config('lonDaemons').'/tmp/'.$datatoken.'.tmp';
 		my $dirpath=$path.'/';
@@ -289,31 +314,39 @@ sub check_extension {
     # Check for bad extension and disallow upload
     if ($fn=~/\.(\w+)$/ &&
         (&Apache::loncommon::fileembstyle($1) eq 'hdn')) {
-        $result .= &mt('File [_1] could not be copied.',
-                      '<span class="LC_filename">'.$fn.'</span> ').
-                  '<p class="LC_error">'.
-                  &mt('The extension on this file is reserved internally by LON-CAPA.').
-                  '</p>';
+        $result .= '<p class="LC_warning">'.
+                   &mt('File [_1] could not be copied.',
+                       '<span class="LC_filename">'.$fn.'</span> ').
+                   '<br />'.
+                   &mt('The extension on this file is reserved internally by LON-CAPA.').
+                   '</p>';
     } elsif ($fn=~/\.(\w+)$/ &&
              !defined(&Apache::loncommon::fileembstyle($1))) {
-        $result .= &mt('File [_1] could not be copied.',
-                      '<span class="LC_filename">'.$fn.'</span> ').
-                  '<p class="LC_error">'.
-                  &mt('The extension on this file is not recognized by LON-CAPA.').
-                  '</p>';
+        $result .= '<p class="LC_warning">'.
+                   &mt('File [_1] could not be copied.',
+                       '<span class="LC_filename">'.$fn.'</span> ').
+                   '<br />'.
+                   &mt('The extension on this file is not recognized by LON-CAPA.').
+                   '</p>';
     } elsif (-d $target) {
-        $result .= &mt('File [_1] could not be copied.',
-                      '<span class="LC_filename">'.$fn.'</span>').
-                  '<p class="LC_error">'.
-                  &mt('The target is an existing directory.').
-                  '</p>';
+        $result .= '<p class="LC_warning">'.
+                   &mt('File [_1] could not be copied.',
+                       '<span class="LC_filename">'.$fn.'</span>').
+                   '<br />'.
+                   &mt('The target is an existing directory.').
+                   '</p>';
     } elsif (copy($source,$target)) {
         chmod(0660, $target); # Set permissions to rw-rw---.
         if ($mode eq 'testbank' || $mode eq 'imsimport') {
             $returnflag = 'ok';
-            $result .= &mt('Your file - [_1] - was uploaded successfully',$fn).'<br /><br />';
+            $result .= '<p class="LC_success">'
+                      .&mt('Your file - [_1] - was uploaded successfully.',
+                           '<span class="LC_filename">'.$fn.'<span>')
+                      .'</p>';
         } else {
-            $result .= &mt('File copied.').'<br />';
+            $result .= '<p class="LC_success">'
+                      .&mt('File copied.')  
+                      .'</p>';
         }
         # Check for embedded objects.
         my (%allfiles,%codebase);
@@ -322,53 +355,105 @@ sub check_extension {
             my (%allfiles,%codebase);
             &Apache::lonnet::extract_embedded_items($target,\%allfiles,\%codebase);
             if (keys(%allfiles) > 0) {
-                my $state = <<STATE;
-    <input type="hidden" name="action"      value="upload_embedded" />
-    <input type="hidden" name="currentpath" value="$env{'form.currentpath'}" />
-    <input type="hidden" name="mode"        value="$mode" />
-    <input type="hidden" name="phase"       value="three" />
-    <input type="hidden" name="filename" value="$url" />
-STATE
-                $result .= "<h3>".&mt("Reference Warning")."</h3>".
-                           "<p>".&mt("Completed upload of the file. This file contained references to other files.")."</p>".
-                          "<p>".&mt("Please select the locations from which the referenced files are to be uploaded.")."</p>".
-                          &Apache::loncommon::ask_for_embedded_content($action,$state,\%allfiles,\%codebase,
-                                      {'error_on_invalid_names'   => 1,
-                                       'ignore_remote_references' => 1,});
-                if ($mode eq 'testbank') {
-                    $returnflag = 'embedded';
-                    $result .=  '<p>'.&mt('Or [_1]continue[_2] the testbank import without these files','<a href="javascript:document.testbankForm.submit();">','</a>').'</p>';
+                my ($currentpath) = ($url =~ m{^(.+)/[^/]+$});
+                my $state = &embedded_form_elems('upload_embedded',$url,$mode);
+                my ($embedded,$num,$pathchg) = 
+                    &Apache::loncommon::ask_for_embedded_content($action,$state,\%allfiles,
+                                                                 \%codebase,
+                                                                 {'error_on_invalid_names'   => 1,
+                                                                  'ignore_remote_references' => 1,
+                                                                  'current_path'             => $currentpath});
+                if ($embedded) {
+                    $result .= '<h3>'.&mt('Reference Warning').'</h3>';
+                    if ($num) {
+                        $result .= '<p>'.&mt('Completed upload of the file.').' '.&mt('This file contained references to other files.').'</p>'.
+                                   '<p>'.&mt('Please select the locations from which the referenced files are to be uploaded.').'</p>'.
+                                   $embedded;
+                        if ($mode eq 'testbank') {
+                            $returnflag = 'embedded';
+                            $result .=  '<p>'.&mt('Or [_1]continue[_2] the testbank import without these files.','<a href="javascript:document.testbankForm.submit();">','</a>').'</p>';
+                        }
+                    } else {
+                        $result .= '<p>'.&mt('Completed upload of the file.').'</p>'.$embedded;
+                        if ($pathchg) {
+                            if ($mode eq 'testbank') {
+                                $returnflag = 'embedded';
+                                $result .=  '<p>'.&mt('Or [_1]continue[_2] the testbank import without modifying the references(s).','<a href="javascript:document.testbankForm.submit();">','</a>').'</p>';
+                            }
+                        }
+                    }
                 }
             }
         }
         if (($mode ne 'imsimport') && ($mode ne 'testbank')) {
-            $result .= '<br /><font size="+2"><a href="'.$url.'">'.
-                        &mt('View file').'</a></font>';
+            $result .= '<br /><a href="'.$url.'">'.
+                        &mt('View file').'</a>';
         }
     } else {
         $result .= &mt('Failed to copy: [_1].',$!);
     }
     if ($mode ne 'imsimport' && $mode ne 'testbank') {
-        $result .= '<br /><font size="+2"><a href="'.$dirpath.'">'.
-                   &mt('Back to Directory').'</a></font><br />';
+        $result .= '<br /><a href="'.$dirpath.'">'.
+                   &mt('Back to Directory').'</a><br />';
     }
     return ($result,$returnflag);
 }
 
 sub phasethree {
     my ($r,$fn,$uname,$udom,$mode) = @_;
+    my $action = '/adm/upload'; 
+    if ($mode eq 'testbank') {
+        $action = '/adm/testbank';
+    } elsif ($mode eq 'imsimport') {
+        $action = '/adm/imsimport';
+    }
+    my $dir_root = '/home/'.$uname.'/public_html';
+    my $url_root = '/priv/'.$uname;
+    my $path = &File::Basename::dirname($fn);
+    my $filename = &HTML::Entities::encode($env{'form.filename'},'<>&"');
+    my $state = &embedded_form_elems('modify_orightml',$filename,$mode).
+                '<input type="hidden" name="phase" value="four" />';
+    my ($result,$returnflag) = 
+        &Apache::loncommon::upload_embedded($mode,$path,$uname,$udom,
+                                            $dir_root,$url_root,undef,
+                                            undef,undef,$state,$action);
+    if ($mode ne 'imsimport' && $mode ne 'testbank') {
+        $result .= '<br /><h3><a href="'.$url_root.$fn.'">'.
+                  &mt('View main file').'</a></h3>'.
+                  '<h3><a href="'.$url_root.$path.'">'.
+                  &mt('Back to Directory').'</a></h3><br />';
+    }
+    return ($result,$returnflag);
+}
+
+sub embedded_form_elems {
+    my ($action,$filename,$mode) = @_;
+    return <<STATE;
+    <input type="hidden" name="action" value="$action" />
+    <input type="hidden" name="mode" value="$mode" />
+    <input type="hidden" name="filename" value="$filename" />
+STATE
+}
+
+sub phasefour {
+    my ($r,$fn,$uname,$udom,$mode) = @_;
+    my $action = '/adm/upload';
+    if ($mode eq 'testbank') {
+        $action = '/adm/testbank';
+    } elsif ($mode eq 'imsimport') {
+        $action = '/adm/imsimport';
+    }
     my $result;
     my $dir_root = '/home/'.$uname.'/public_html';
     my $url_root = '/priv/'.$uname;
-    my $base = &File::Basename::basename($fn);
     my $path = &File::Basename::dirname($fn);
-    $result = &Apache::loncommon::upload_embedded($mode,$path,$uname,$udom,
-                                                  $dir_root,$url_root);
+    $result .= &Apache::loncommon::modify_html_refs($mode,$path,
+                              $uname,$udom,$dir_root);
     if ($mode ne 'imsimport' && $mode ne 'testbank') {
-        $result = '<br /><font size="+2"><a href="'.$url_root.$fn.'">'.
-                  &mt('View main file').'</a></font>'.
-                  '<br /><font size="+2"><a href="'.$url_root.$path.'">'.
-                  &mt('Back to Directory').'</a></font><br />';
+        $result .= '<br /><h3><a href="'.$url_root.$fn.'">'.
+                  &mt('View main file').'</a></h3>'.
+                  '<h3><a href="'.$url_root.$path.'">'.
+                  &mt('Back to Directory').'</a></h3><br />';
     }
     return $result;
 }
@@ -440,18 +525,29 @@ function verifyForm() {
    $javascript = "<script type=\"text/javascript\">\n//<!--\n".
 	$javascript."\n// --></script>\n";
 
+    # Breadcrumbs
+    my $brcrum = [{'href' => &Apache::loncommon::authorspace(),
+                   'text' => 'Construction Space'},
+                  {'href' => '/adm/upload',
+                   'text' => 'Upload file to Construction Space'}];
     $r->print(&Apache::loncommon::start_page('Upload file to Construction Space',
-					     $javascript));
+                                             $javascript,
+                                             {'bread_crumbs' => $brcrum,})
+             .&Apache::loncommon::head_subbox(
+                &Apache::loncommon::CSTR_pageheader())
+    );
   
     if (($uname ne $env{'user.name'}) || ($udom ne $env{'user.domain'})) {
-        $r->print('<p class="LC_warning">'
+        $r->print('<p class="LC_info">'
                  .&mt('Co-Author [_1]',$uname.':'.$udom)
                  .'</p>'
         );
     }
-
-    if ($env{'form.phase'} eq 'three') {
-        my $output = &phasethree($r,$fn,$uname,$udom,'author');
+    if ($env{'form.phase'} eq 'four') {
+        my $output = &phasefour($r,$fn,$uname,$udom,'author');
+        $r->print($output);
+    } elsif ($env{'form.phase'} eq 'three') {
+        my ($output,$rtnflag) = &phasethree($r,$fn,$uname,$udom,'author');
         $r->print($output);
     } elsif ($env{'form.phase'} eq 'two') {
 	my ($output,$returnflag) = &phasetwo($r,$fn,$uname,$udom);
