@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # XML Parser Module 
 #
-# $Id: lonxml.pm,v 1.494.4.5 2010/10/01 14:21:55 raeburn Exp $
+# $Id: lonxml.pm,v 1.505.2.4 2010/09/29 16:12:17 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -111,6 +111,7 @@ use Apache::loncacc();
 use Apache::lonmaxima();
 use Apache::lonr();
 use Apache::lonlocal;
+use Apache::lonhtmlcommon();
 
 #====================================   Main subroutine: xmlparse  
 
@@ -571,6 +572,10 @@ sub inner_xmlparse {
   if (($ENV{'QUERY_STRING'}) && ($target eq 'web')) {
     $finaloutput=&afterburn($finaloutput);
   }	    
+  if ($target eq 'modified') {
+# if modfied, handle startpart and endpart
+     $finaloutput=~s/\<startpartmarker[^\>]*\>(.*)\<endpartmarker[^\>]*\>/<part>$1<\/part>/gs;
+  }
   return $finaloutput;
 }
 
@@ -1043,7 +1048,7 @@ sub get_id {
     my ($parstack,$safeeval)=@_;
     my $id= &Apache::lonxml::get_param('id',$parstack,$safeeval);
     if ($env{'request.state'} eq 'construct' && $id =~ /([._]|[^\w\d\s[:punct:]])/) {
-	&error(&mt("ID [_1] contains invalid characters, IDs are only allowed to contain letters, numbers, spaces and -",'<tt>'.$id.'</tt>'));
+	&error(&mt('ID [_1] contains invalid characters. IDs are only allowed to contain letters, numbers, spaces and -','"<tt>'.$id.'</tt>"'));
     }
     if ($id =~ /^\s*$/) { $id = $Apache::lonxml::curdepth; }
     return $id;
@@ -1562,7 +1567,7 @@ sub renderingoptions {
            &Apache::loncommon::select_form(
                $env{'form.languages'},
                'languages',
-               &Apache::lonlocal::texthash(%langchoices)).
+               {&Apache::lonlocal::texthash(%langchoices)}).
            '</span>';
     }
     $output .=
@@ -1571,11 +1576,11 @@ sub renderingoptions {
        &Apache::loncommon::select_form(
            $env{'form.texengine'},
            'texengine',
-           &Apache::lonlocal::texthash
+           {&Apache::lonlocal::texthash
                (''        => '',
                 'tth'     => 'tth (TeX to HTML)',
                 'jsMath'  => 'jsMath',
-                'mimetex' => 'mimetex (Convert to Images)')).
+                'mimetex' => 'mimetex (Convert to Images)')}).
      '</span>';
     return $output;
 }
@@ -1589,47 +1594,27 @@ sub inserteditinfo {
       my $dragmath_button;
       my ($add_to_onload, $add_to_onresize);
       $initialize=&Apache::lonhtmlcommon::spellheader();
-      if ($filetype eq 'html' 
-	  && (!&Apache::lonhtmlcommon::htmlareablocked() &&
-	      &Apache::lonhtmlcommon::htmlareabrowser())) {
-	  $textarea_id .= '___Frame';
-	  my $lang = &Apache::lonhtmlcommon::htmlarea_lang();
-	  $initialize.=(<<FULLPAGE);
+      if (($filetype eq 'html') && (&Apache::lonhtmlcommon::htmlareabrowser())) {
+          my $lang = &Apache::lonhtmlcommon::htmlarea_lang();
+          my %textarea_args = (
+                                fullpage => 'true',
+                                dragmath => 'math',
+                              );
+          $initialize .= &Apache::lonhtmlcommon::htmlareaselectactive(\%textarea_args);
+      }
+      $initialize .= (<<FULLPAGE);
 <script type="text/javascript">
-lonca
+// <![CDATA[
     function initDocument() {
-        var oFCKeditor = new FCKeditor('filecont');
-	oFCKeditor.Config['CustomConfigurationsPath'] = '/fckeditor/loncapaconfig.js'  ;
-	oFCKeditor.Config['FullPage'] = true
-	oFCKeditor.Config['AutoDetectLanguage'] = false;
-        oFCKeditor.Config['DefaultLanguage'] = "$lang";
-	oFCKeditor.ReplaceTextarea();
-    }
-    function check_if_dirty(editor) {
-	if (editor.IsDirty()) {
-	    unClean();
-	}
-    }
-    function FCKeditor_OnComplete(editor) {
-	editor.Events.AttachEvent("OnSelectionChange",check_if_dirty);
-	resize_textarea('$textarea_id','LC_aftertextarea');
-    }
-</script>
-FULLPAGE
-      } else {
-	  $initialize.=(<<FULLPAGE);
-<script type="text/javascript">
-    function initDocument() {
 	resize_textarea('$textarea_id','LC_aftertextarea');
     }
+// ]]>
 </script>
 FULLPAGE
-          if ($filetype eq 'html') {
-              $initialize .= "\n".&Apache::lonhtmlcommon::dragmath_js('EditMathPopup');
-              $dragmath_button = &Apache::lonhtmlcommon::dragmath_button('filecont',1);
-          }
+      if ($filetype eq 'html') {
+          $dragmath_button = '<span id="math_filecont">'.&Apache::lonhtmlcommon::dragmath_button('filecont',1).'</span>';
+          $initialize .= "\n".&Apache::lonhtmlcommon::dragmath_js('EditMathPopup');
       }
-
       $add_to_onload = 'initDocument();';
       $add_to_onresize = "resize_textarea('$textarea_id','LC_aftertextarea');";
 
@@ -1638,12 +1623,13 @@ FULLPAGE
       }
 
       my $titledisplay=&display_title();
+      my $textareaclass;
       my %lt=&Apache::lonlocal::texthash('st' => 'Save and Edit',
 					 'vi' => 'Save and View',
 					 'dv' => 'Discard Edits and View',
 					 'un' => 'undo',
 					 'ed' => 'Edit');
-      my $spelllink .=&Apache::lonhtmlcommon::spelllink('xmledit','filecont');
+      my $spelllink = &Apache::lonhtmlcommon::spelllink('xmledit','filecont');
       my $textarea_events = &Apache::edit::element_change_detection();
       my $form_events     = &Apache::edit::form_change_detection();
       my $htmlerror;
@@ -1652,6 +1638,9 @@ FULLPAGE
           if ($htmlerror) {
               $htmlerror='<span class="LC_error">'.$htmlerror.'</span>';
           }
+          if (&Apache::lonhtmlcommon::htmlareabrowser()) {
+              $textareaclass = 'class="LC_richDefaultOff"';
+          }
       }
       my $editfooter=(<<ENDFOOTER);
 $initialize
@@ -1667,14 +1656,14 @@ $initialize
     <div class="LC_edit_problem_discards">
       <input type="submit" name="discardview" accesskey="d" value="$lt{'dv'}" />
       <input type="submit" name="Undo" accesskey="u" value="$lt{'un'}" />
-      $dragmath_button $spelllink $htmlerror
+      $htmlerror $dragmath_button
     </div>
     <div class="LC_edit_problem_saves">
       <input type="submit" name="savethisfile" accesskey="s" value="$lt{'st'}" />
       <input type="submit" name="viewmode" accesskey="v" value="$lt{'vi'}" />
     </div>
   </div>
-  <textarea $textarea_events style="width:100%" cols="80" rows="44" name="filecont" id="filecont">$filecontents</textarea>
+  <textarea $textarea_events style="width:100%" cols="80" rows="44" name="filecont" id="filecont" $textareaclass>$filecontents</textarea><br />$spelllink
   <div id="LC_aftertextarea">
     <br />
     $titledisplay
@@ -1724,8 +1713,8 @@ sub handler {
 	$request->set_last_modified(&Apache::lonnet::metadata($request->uri,
 							      'lastrevisiondate'));
     }
-    # Embedded Flash movies (e.g., from Camtasia) served from https will not display in IE
-    #   if XML config file has expired from cache.
+    # Embedded Flash movies from Camtasia served from https will not display in IE
+    #   if XML config file has expired from cache.    
     if ($ENV{'SERVER_PORT'} == 443) {
         if ($request->uri =~ /\.xml$/) {
             my ($httpbrowser,$clientbrowser) =
@@ -1745,12 +1734,25 @@ sub handler {
 
 
     my $file=&Apache::lonnet::filelocation("",$request->uri);
-    my $filetype;
-    if ($file =~ /\.(sty|css|js|txt)$/) {
+    my ($filetype,$breadcrumbtext);
+    if ($file =~ /\.(sty|css|js|txt|tex)$/) {
 	$filetype=$1;
     } else {
 	$filetype='html';
     }
+    if ($filetype eq 'sty') {
+        $breadcrumbtext = 'Style File Editor';
+    } elsif ($filetype eq 'js') {
+        $breadcrumbtext = 'Javascript Editor';
+    } elsif ($filetype eq 'css') {
+        $breadcrumbtext = 'CSS Editor';
+    } elsif ($filetype eq 'txt') {
+        $breadcrumbtext = 'Text Editor';
+    } elsif ($filetype eq 'tex') {
+        $breadcrumbtext = 'TeX Editor';
+    } else {
+        $breadcrumbtext = 'HTML Editor';
+    }
 
 #
 # Edit action? Save file.
@@ -1770,10 +1772,13 @@ sub handler {
     if ($filecontents eq -1) {
 	my $start_page=&Apache::loncommon::start_page('File Error');
 	my $end_page=&Apache::loncommon::end_page();
-	my $fnf=&mt('File not found');
+        my $errormsg='<p class="LC_error">'
+                    .&mt('File not found: [_1]'
+                        ,'<span class="LC_filename">'.$file.'</span>')
+                    .'</p>';
 	$result=(<<ENDNOTFOUND);
 $start_page
-<b>$fnf: $file</b>
+$errormsg
 $end_page
 ENDNOTFOUND
         $filecontents='';
@@ -1782,7 +1787,7 @@ ENDNOTFOUND
 		$filecontents=&createnewsty();
             } elsif ($filetype eq 'js') {
                 $filecontents=&createnewjs();
-            } elsif (($filetype ne 'css') && ($filetype ne 'txt')) {
+            } elsif ($filetype ne 'css' && $filetype ne 'txt' && $filetype ne 'tex') {
 		$filecontents=&createnewhtml();
 	    }
 	    $env{'form.editmode'}='Edit'; #force edit mode
@@ -1806,18 +1811,28 @@ ENDNOTFOUND
 	    # up if it did
 	        &Apache::structuretags::reset_problem_globals();
 	        &Apache::lonhomework::finished_parsing();
+            } elsif ($filetype eq 'tex') {
+                $result = &Apache::lontexconvert::converted(\$filecontents,
+                              $env{'form.texengine'});
+                if ($env{'form.return_only_error_and_warning_counts'}) {
+                    $result = "$errorcount:$warningcount";
+                }
             } else {
                 $result = $filecontents;
             }
 	    &Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},
 						    ['rawmode']);
 	    if ($env{'form.rawmode'}) { $result = $filecontents; }
-	    if ($filetype ne 'html') {
-                my $nochgview = 1; 
-		my $controls =
-		    ($env{'request.state'} eq 'construct') ? &Apache::londefdef::edit_controls($nochgview)
-		                                           : '';
-                if ($filetype ne 'sty') {
+            if (($filetype ne 'html') && 
+                (!$env{'form.return_only_error_and_warning_counts'})) {
+                my $nochgview = 1;
+                my $controls = '';
+                    if ($env{'request.state'} eq 'construct') {
+                        $controls = &Apache::loncommon::head_subbox(
+                                        &Apache::loncommon::CSTR_pageheader()
+                                       .&Apache::londefdef::edit_controls($nochgview));
+                    }
+                if ($filetype ne 'sty' && $filetype ne 'tex') {
                     $result =~ s/</&lt;/g;
                     $result =~ s/>/&gt;/g;
                     $result = '<table class="LC_sty_begin">'.
@@ -1825,17 +1840,27 @@ ENDNOTFOUND
                               '</pre></b></td></tr></table>';
                 }
                 if ($env{'environment.remote'} eq 'off') {
-                    my %options = ('bgcolor' => '#FFFFFF');
-		    $result = 
-		        &Apache::loncommon::start_page(undef,undef,\%options).
-		        $controls.
-		        $result.
-		        &Apache::loncommon::end_page();
+                    my $brcrum;
+                    if ($env{'request.state'} eq 'construct') {
+                        $brcrum = [{'href' => &Apache::loncommon::authorspace(),
+                                    'text' => 'Construction Space'},
+                                   {'href' => '',
+                                    'text' => $breadcrumbtext}];
+                    } else {
+                        $brcrum = ''; # FIXME: Where are we?
+                    }
+                    my %options = ('bread_crumbs' => $brcrum,
+                                   'bgcolor'      => '#FFFFFF');
+                    $result =
+                        &Apache::loncommon::start_page(undef,undef,\%options)
+                       .$controls
+                       .$result
+                       .&Apache::loncommon::end_page();
                 } else {
                     $result = $controls.$result;
                 }
             }
-	}
+        }
     }
 
 #
@@ -1852,9 +1877,18 @@ ENDNOTFOUND
 
 	    my %options = 
 		('add_entries' =>
-                   {'onresize' => $add_to_onresize,
-		    'onload'   => $add_to_onload,   });
-
+                   {'onresize'     => $add_to_onresize,
+                    'onload'       => $add_to_onload,   });
+            my $header;
+            if ($env{'request.state'} eq 'construct') {
+                $options{'bread_crumbs'} = [{
+                            'href' => &Apache::loncommon::authorspace(),
+                            'text' => 'Construction Space'},
+                           {'href' => '',
+                            'text' => $breadcrumbtext}];
+                $header = &Apache::loncommon::head_subbox(
+                              &Apache::loncommon::CSTR_pageheader());
+            }
 	    if ($env{'environment.remote'} ne 'off') {
 		$options{'bgcolor'}   = '#FFFFFF';
 		$options{'only_body'} = 1;
@@ -1864,14 +1898,15 @@ ENDNOTFOUND
 		&Apache::loncommon::resize_textarea_js();
 	    my $start_page = &Apache::loncommon::start_page(undef,$js,
 							    \%options);
-	    $result=$start_page.
-		&Apache::lonxml::message_location().
-		$edit_info.
-		&Apache::loncommon::end_page();
+            $result = $start_page
+                     .$header
+                     .&Apache::lonxml::message_location()
+                     .$edit_info
+                     .&Apache::loncommon::end_page();
         }
     }
     if ($filetype eq 'html') { &writeallows($request->uri); }
-    
+
     &Apache::lonxml::add_messages(\$result);
     $request->print($result);
     
@@ -2240,24 +2275,20 @@ sub get_tag {
 
 =pod
 
-=item &print_pdf_radiobutton(fieldname, value,  text)
+=item &print_pdf_radiobutton(fieldname, value)
 
-Returns a latexline to generate a PDF-Form-Radiobutton with Text.
+Returns a latexline to generate a PDF-Form-Radiobutton.
+Note: Radiobuttons with equal names are automaticly grouped
+      in a selection-group.
 
-$fieldname: PDF internalname of the radiobutton
-$value:     Value of radiobutton (read when dumping the PDF data)
-$text:      Text on the rightside of the radiobutton
+$fieldname: PDF internalname of the radiobutton(group)
+$value:     Value of radiobutton
 
 =cut
 sub print_pdf_radiobutton {
-    my $result = '';
-    my ($fieldName, $value, $text) = @_;
-    $result .= '\begin{tabularx}{\textwidth}{p{0cm}X}'."\n";
-    $result .= '\radioButton[\symbolchoice{circle}]{'. 
-               $fieldName.'}{10bp}{10bp}{'.$value.'}&'.$text."\n";
-    $result .= '\end{tabularx}' . "\n";
-    $result .= '\hspace{2mm}' . "\n";
-    return $result;
+    my ($fieldname, $value) = @_;
+    return '\radioButton[\symbolchoice{circle}]{'
+           .$fieldname.'}{10bp}{10bp}{'.$value.'}';
 }
 
 
