@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Page Handler
 #
-# $Id: lonpage.pm,v 1.94.2.1 2010/07/30 22:40:53 raeburn Exp $
+# $Id: lonpage.pm,v 1.94 2010/07/13 00:16:23 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -553,10 +553,6 @@ sub handler {
 sub get_buttons {
     my ($hash,$rid) = @_;
 
-    # which icons do we use?
-    my $extension='png';
-    if ($env{'environment.icons'} eq 'classic') { $extension='gif'; }
-
     my $metainfo = '';
     my $esrc=&Apache::lonnet::declutter($hash->{'src_'.$rid});
     my ($mapid,$resid)=split(/\./,$rid);
@@ -573,13 +569,13 @@ sub get_buttons {
 	    || !$hash->{'encrypted_'.$rid})) { 
 	$metainfo .='<a name="'.&escape($symb).'" />'.
 	    '<a href="'.$hash->{'src_'.$rid}.'.meta'.'" target="LONcatInfo">'.
-	    '<img src="/adm/lonMisc/cat_button.'.$extension.'" class="LC_icon" />'.
+	    '<img src="/adm/lonMisc/cat_button.png" class="LC_icon" />'.
 	    '</a>';
     }
     $metainfo .= '<a href="/adm/evaluate?postdata='.
 	&escape($esrc).
 	'" target="LONcatInfo">'.
-	'<img src="/adm/lonMisc/eval_button.'.$extension.'" class="LC_icon" />'.
+	'<img src="/adm/lonMisc/eval_button.png" class="LC_icon" />'.
 	'</a>';
     if (($hash->{'src_'.$rid}=~/\.(problem|exam|quiz|assess|survey|form)$/) &&
 	($hash->{'src_'.$rid} !~ m-^/uploaded/-)) {
@@ -589,12 +585,12 @@ sub get_buttons {
 		'<a href="/adm/grades?symb='.&escape($symb).
 #               '&command=submission" target="LONcatInfo">'.
 		'&command=submission">'.
-		'<img src="/adm/lonMisc/subm_button.'.$extension.'" class="LC_icon" />'.
+		'<img src="/adm/lonMisc/subm_button.png" class="LC_icon" />'.
 		'</a>'.
 		'<a href="/adm/grades?symb='.&escape($symb).
 #               '&command=gradingmenu" target="LONcatInfo">'.
 		'&command=gradingmenu">'.
-		'<img src="/adm/lonMisc/pgrd_button.'.$extension.'" class="LC_icon" />'.
+		'<img src="/adm/lonMisc/pgrd_button.png" class="LC_icon" />'.
 		'</a>';
 	}
 	if (&Apache::lonnet::allowed('opa',$env{'request.course.id'})) {
@@ -602,7 +598,7 @@ sub get_buttons {
 		'<a href="/adm/parmset?symb='.&escape($symb).
 #               '" target="LONcatInfo">'.
 		'" >'.
-		'<img src="/adm/lonMisc/pprm_button.'.$extension.'" class="LC_icon" />'.
+		'<img src="/adm/lonMisc/pprm_button.png" class="LC_icon" />'.
 		'</a>';
 	}
     }
