@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Edit Handler for RAT Maps
 #
-# $Id: lonratedt.pm,v 1.94.2.1 2009/08/14 02:16:31 raeburn Exp $
+# $Id: lonratedt.pm,v 1.98 2009/12/04 11:13:58 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -58,6 +58,7 @@ sub ratedt {
       &Apache::loncommon::start_page('Edit Sequence',$js,
 				     {'frameset'    => 1,
 				      'add_entries' => \%layout});
+
   my $end_page = 
       &Apache::loncommon::end_page({'frameset' => 1});
 
@@ -77,17 +78,27 @@ sub buttons {
     my $adv=shift;
     my $output='<form method="post">';     
     if ($adv==1) {
-	$output.='<input type="submit" name="forceadv" value="'.&mt('Edit').'" />'.
-	    &Apache::loncommon::help_open_topic('Sequence_Advanced_Editor_Creation');
+        $output.=
+            '<input type="submit" name="forceadv"'
+           .' value="'.&mt('Edit').'" />'
+           .&Apache::loncommon::help_open_topic(
+                'Sequence_Advanced_Editor_Creation');
     } else {
         unless ($adv==2) {
-           $output.='<input type="submit" name="forcesmp" value="'.&mt('Simple Edit').'" />'.
-	    &Apache::loncommon::help_open_topic('Sequence_Simple_Editor_Creation');
+           $output.=
+               '<input type="submit" name="forcesmp"'
+              .' value="'.&mt('Simple Edit').'" />'
+              .&Apache::loncommon::help_open_topic(
+                   'Sequence_Simple_Editor_Creation')
+              .' ';
         }
-	$output.='<input type="submit" name="forceadv" value="'.&mt('Advanced Edit').'" />'.
-	    &Apache::loncommon::help_open_topic('Sequence_Advanced_Editor_Creation');
+        $output.=
+            '<input type="submit" name="forceadv"'
+           .' value="'.&mt('Advanced Edit').'" />'
+           .&Apache::loncommon::help_open_topic(
+                'Sequence_Advanced_Editor_Creation');
     }
-    return $output.'</form><hr />';
+    return $output.'</form>';
 }
 
 # ----------------------------------------------------------------- Edit script
@@ -214,7 +225,6 @@ ENDSCRIPT
 
 sub smpedt {
    my ($r,$url,$errtext)=@_;
-   my $buttons=&buttons(2);
    my $tmpfn=&Apache::lonnet::filelocation('',$url).'.tmp';
    my $targetmsg='';
    if ($env{'form.save'}) {
@@ -540,15 +550,31 @@ sub smpedt {
 </script>
 ENDJS
 
-    my $start_page = &Apache::loncommon::start_page(undef,$js).
-        &Apache::loncommon::help_open_menu('Sequence_Simple_Editor_Creation',
-					   'Sequence_Simple_Editor_Creation',
-					   6,'RAT');    
+    &Apache::lonhtmlcommon::clear_breadcrumbs();
+    &Apache::lonhtmlcommon::add_breadcrumb({
+        text  => 'Construction Space',
+        href  => &Apache::loncommon::authorspace(),
+        faq   => 6,
+        bug   => 'RAT',
+        help  => 'Sequence_Simple_Editor_Creation',});
+    &Apache::lonhtmlcommon::add_breadcrumb({
+        text  => 'RAT',
+        title => 'Resource Assembly Tool',
+        href  => '',});
+    &Apache::lonhtmlcommon::add_breadcrumb({
+        text  => 'Editor',
+        title => 'Simple Editor',
+        href  => '',});
+
+    # Breadcrumbs are included by &start_page
+    my $start_page = &Apache::loncommon::start_page('Construction Space',$js)
+                    .&Apache::loncommon::head_subbox(
+                         &Apache::loncommon::CSTR_pageheader()
+                        .&buttons(2));
     my $end_page = &Apache::loncommon::end_page();
 
     $r->print(<<ENDSMPHEAD);
 $start_page
-$buttons
 <span class="LC_error">$errtext</span>
 <form name="simpleedit" method="post">
 <input type="hidden" name="forcesmp" value="1" />
@@ -624,23 +650,45 @@ ENDSMPHEAD
 sub nodir {
    my ($r,$dir)=@_;
    $dir=~s{^/home/$LONCAPA::username_re/public_html}{};
-   $r->print(&Apache::loncommon::start_page(undef,undef,
-					    {'only_body' => 1,
-					     'bgcolor'   => '#FFFFFF',}).
-             '<p class="LC_error">'.
-             &mt('No such directory: [_1]','<span class="LC_filename">'.$dir.'</span>').
-             '</p>'.
-	     &Apache::loncommon::end_page());
+   my $brcrum = [{'href' => &Apache::loncommon::authorspace(),
+                  'text' => 'Construction Space'}];
+#                 {'href' => '',
+#                  'text' => 'No such directory'}];
+   $r->print(&Apache::loncommon::start_page('Construction Space',
+                                            undef,
+                                            {'bread_crumbs' => $brcrum,})
+            .&Apache::loncommon::head_subbox(
+                 &Apache::loncommon::CSTR_pageheader())
+            .'<p class="LC_error">'
+            .&mt('No such directory: [_1]','<span class="LC_filename">'.$dir.'</span>'
+            .'</p>'
+            .&Apache::loncommon::end_page())
+   );
 }
 
 # ---------------------------------------------------------------- View Handler
 
 sub viewmap {
     my ($r,$url,$adv,$errtext)=@_;
-    $r->print(
-	      &Apache::loncommon::start_page('Edit Content of a Map').
-	      &Apache::loncommon::help_open_menu('','',6,'RAT').
-	      &buttons($adv));
+
+    &Apache::lonhtmlcommon::clear_breadcrumbs();
+    &Apache::lonhtmlcommon::add_breadcrumb({
+        text  => 'Construction Space',
+        href  => &Apache::loncommon::authorspace(),
+        faq   => 6,
+        bug   => 'RAT',
+        help  => 'Sequence_Simple_Editor_Creation',});
+    &Apache::lonhtmlcommon::add_breadcrumb({
+        text  => 'RAT',
+        title => 'Resource Assembly Tool',
+        href  => '',});
+
+    # Breadcrumbs are included by &start_page
+    $r->print(&Apache::loncommon::start_page('Edit Content of a Map')
+             .&Apache::loncommon::head_subbox(
+                  &Apache::loncommon::CSTR_pageheader()
+                 .&buttons($adv))
+    );
     if ($errtext) {
 	$r->print('<div class="LC_error">'
                  .$errtext
