@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Construct and maintain state and binary representation of course for user
 #
-# $Id: lonuserstate.pm,v 1.134 2009/12/03 19:01:33 www Exp $
+# $Id: lonuserstate.pm,v 1.137 2011/04/21 13:28:50 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -126,6 +126,15 @@ sub loadmap {
     my $lpc=$pc;
     $hash{'map_pc_'.$uri}=$lpc;
     $hash{'map_id_'.$lpc}=$uri;
+    if ($parent_rid =~ /^(\d+)\.\d+$/) {
+        my $parent_pc = $1;
+        if (defined($hash{'map_hierarchy_'.$parent_pc})) {
+            $hash{'map_hierarchy_'.$lpc}=$hash{'map_hierarchy_'.$parent_pc}.','.
+                                         $parent_pc;
+        } else {
+            $hash{'map_hierarchy_'.$lpc}=$parent_pc;
+        }
+    }
 
 # Determine and check filename
     my $fn=&Apache::lonnet::filelocation('',&putinversion($uri));
@@ -286,7 +295,7 @@ sub parse_resource {
 	$hash{'ids_'.$idsuri}=''.$rid;
     }
     
-    if ($turi=~/\/(syllabus|aboutme|navmaps|smppg|bulletinboard)$/) {
+    if ($turi=~/\/(syllabus|aboutme|navmaps|smppg|bulletinboard|viewclasslist)$/) {
 	$turi.='?register=1';
     }
     
@@ -897,7 +906,7 @@ sub build_tmp_hashes {
 
 sub unlink_tmpfiles {
     my ($fn) = @_;
-    if ($fn =~ m{^\Q$Apache::lonnet::perlvar{'lonUsersDir'}\E/tmp/}) {
+    if ($fn =~ m{^\Q$Apache::lonnet::perlvar{'lonDaemons'}\E/tmp/}) {
         my @files = qw (.db _symb.db .state _parms.db);
         foreach my $file (@files) {
             if (-e $fn.$file) {
